(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    453392,      12434]
NotebookOptionsPosition[    435489,      11867]
NotebookOutlinePosition[    436451,      11901]
CellTagsIndexPosition[    436408,      11898]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Supplemental material : \"Spin-stress and spin-strain coupling in \
diamond-based hybrid spin oscillator system\"\n\n",
 StyleBox["A. Barfuss, M. Kasperczyk, J. K\[ODoubleDot]lbl and P. Maletinsky\n\
Department of Physics, University of Basel, Klingelbergstrase 82, CH - 4056 \
Basel, Switzerland\n(Dated : September 11, 2018 )",
  FontSize->24],
 "\n\n",
 StyleBox["Download file from: \
https://quantum-sensing.physik.unibas.ch/publications/research-articles.html",
  FontSize->24],
 "\n\n\n\n\n\n"
}], "Title",
 CellChangeTimes->{{3.7456537801580243`*^9, 3.7456538935043635`*^9}, {
   3.7456542648863373`*^9, 3.745654276389572*^9}, 3.745654319399476*^9, {
   3.745659863150052*^9, 3.7456598641800723`*^9}, {3.745659941304713*^9, 
   3.7456599422247314`*^9}, {3.7456599802955256`*^9, 
   3.7456599807155333`*^9}, {3.7456626398526645`*^9, 
   3.7456626613635106`*^9}, {3.745668551936883*^9, 3.745668561887082*^9}}],

Cell["1. Calculate stress tensor for different stress directions", "Title",
 CellChangeTimes->{{3.7067028912268457`*^9, 3.706702930890114*^9}, {
  3.7098243659278383`*^9, 3.709824370514246*^9}, {3.709874596882258*^9, 
  3.709874598032281*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"clearing", " ", "all", " ", "variables"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.7098251989043055`*^9, 3.7098252217816143`*^9}}],

Cell[CellGroupData[{

Cell["Crystal coordinate system XYZ", "Subsection",
 CellChangeTimes->{{3.7067029340702963`*^9, 3.7067029408506837`*^9}, {
  3.70982438389907*^9, 3.709824387923877*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Z", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.706702942726791*^9, 3.7067030028592305`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculate stress tensor coordinates for an arbitrary stress direction\
\>", "Subsection",
 CellChangeTimes->{{3.7067030240764437`*^9, 3.706703032937951*^9}, {
  3.709824456922798*^9, 3.7098244840512457`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
  "P", " ", "denotes", " ", "the", " ", "applied", " ", "amount", " ", "of", 
   " ", 
   RowBox[{"stress", "."}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.7098245199313087`*^9, 3.7098245360305367`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"StressDir", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]XX", " ", "=", " ", 
   RowBox[{"P", "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "X"}], "]"}], "]"}], "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "X"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]XY", " ", "=", " ", 
   RowBox[{"P", "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "X"}], "]"}], "]"}], "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "Y"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]XZ", " ", "=", " ", 
   RowBox[{"P", "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "X"}], "]"}], "]"}], "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "Z"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]YY", " ", "=", " ", 
   RowBox[{"P", "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "Y"}], "]"}], "]"}], "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "Y"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]YZ", " ", "=", " ", 
   RowBox[{"P", "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "Y"}], "]"}], "]"}], "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "Z"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]ZZ", " ", "=", " ", 
   RowBox[{"P", "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "Z"}], "]"}], "]"}], "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"VectorAngle", "[", 
      RowBox[{"StressDir", ",", "Z"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]XYZTensor", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]XX", " ", ",", "\[Sigma]XY", ",", " ", "\[Sigma]XZ"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XY", ",", " ", "\[Sigma]YY", ",", " ", "\[Sigma]YZ"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XZ", ",", " ", "\[Sigma]YZ", ",", " ", "\[Sigma]ZZ"}], 
      " ", "}"}]}], "}"}], "//", "MatrixForm"}]}]}], "Input",
 CellChangeTimes->{{3.706702970278367*^9, 3.706702975786682*^9}, {
  3.706703005978409*^9, 3.7067030174430647`*^9}, {3.7067030482668276`*^9, 
  3.7067030494818974`*^9}, {3.7067031788012934`*^9, 3.7067032226648026`*^9}, {
  3.709824427438746*^9, 3.709824432617955*^9}, {3.7098244715556235`*^9, 
  3.7098244723200245`*^9}, {3.7098245421613474`*^9, 3.7098246439671264`*^9}, {
  3.709824710969244*^9, 3.7098247493765116`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["P", "3"], 
      FractionBox["P", "3"], 
      FractionBox["P", "3"]},
     {
      FractionBox["P", "3"], 
      FractionBox["P", "3"], 
      FractionBox["P", "3"]},
     {
      FractionBox["P", "3"], 
      FractionBox["P", "3"], 
      FractionBox["P", "3"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7098246167138786`*^9, 3.7098246445599275`*^9}, {
   3.7098247019368277`*^9, 3.7098247501877127`*^9}, 3.7300970443392067`*^9, 
   3.730627833800065*^9, 3.736825925649392*^9, 3.736828998483057*^9, 
   3.736829175465604*^9, 3.742896282561651*^9, 3.745649706600348*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stress tensors for some predefined stress directions", "Subsection",
 CellChangeTimes->{{3.7067033203293886`*^9, 3.706703335479255*^9}, {
  3.7098244939884624`*^9, 3.7098245057508836`*^9}, {3.709824682623994*^9, 
  3.709824683123195*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]100vec", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]x", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Sigma]y", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]z", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]110vec", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]x", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Sigma]y", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Sigma]z", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]m110vec", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]x", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"\[Sigma]y", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Sigma]z", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]m1m10vec", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]x", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"\[Sigma]y", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"\[Sigma]z", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]1m10vec", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]x", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Sigma]y", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"\[Sigma]z", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]111vec", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]x", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Sigma]y", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Sigma]z", "\[Rule]", "1"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7067034167809057`*^9, 3.706703518391717*^9}, {
  3.7067035654094067`*^9, 3.7067035722317963`*^9}, {3.7067040351242723`*^9, 
  3.706704041780653*^9}, {3.706704090460438*^9, 3.706704095795743*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Sigma]110", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]XX", ",", "\[Sigma]XY", ",", "\[Sigma]XZ"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XY", ",", "\[Sigma]YY", ",", "\[Sigma]YZ"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XZ", ",", "\[Sigma]YZ", ",", "\[Sigma]ZZ"}], "}"}]}], 
    "}"}], "/.", "\[Sigma]110vec"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]m110", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]XX", ",", "\[Sigma]XY", ",", "\[Sigma]XZ"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XY", ",", "\[Sigma]YY", ",", "\[Sigma]YZ"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XZ", ",", "\[Sigma]YZ", ",", "\[Sigma]ZZ"}], "}"}]}], 
    "}"}], "/.", "\[Sigma]m110vec"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]m1m10", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]XX", ",", "\[Sigma]XY", ",", "\[Sigma]XZ"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XY", ",", "\[Sigma]YY", ",", "\[Sigma]YZ"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XZ", ",", "\[Sigma]YZ", ",", "\[Sigma]ZZ"}], "}"}]}], 
    "}"}], "/.", "\[Sigma]m1m10vec"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]1m10", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]XX", ",", "\[Sigma]XY", ",", "\[Sigma]XZ"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XY", ",", "\[Sigma]YY", ",", "\[Sigma]YZ"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]XZ", ",", "\[Sigma]YZ", ",", "\[Sigma]ZZ"}], "}"}]}], 
    "}"}], "/.", "\[Sigma]1m10vec"}]}]}], "Input",
 CellChangeTimes->{{3.7067033415706034`*^9, 3.706703406736331*^9}, {
  3.70670348539983*^9, 3.706703532824543*^9}, {3.706703577136077*^9, 
  3.7067035845195*^9}, {3.706704045252852*^9, 3.7067040502761393`*^9}, {
  3.7067041001159897`*^9, 3.7067041051482773`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.706703490403116*^9, 3.706703502273795*^9}, 
   3.7067035343996325`*^9, 3.706703587907693*^9, 3.7067040551374173`*^9, 
   3.706704106432351*^9, 3.709824303746129*^9, 3.730097044359207*^9, 
   3.7306278338200645`*^9, 3.7368259256993933`*^9, 3.7368289985130577`*^9, 
   3.7368291754956045`*^9, 3.7428962866117325`*^9, 3.7456497066103487`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.706703490403116*^9, 3.706703502273795*^9}, 
   3.7067035343996325`*^9, 3.706703587907693*^9, 3.7067040551374173`*^9, 
   3.706704106432351*^9, 3.709824303746129*^9, 3.730097044359207*^9, 
   3.7306278338200645`*^9, 3.7368259256993933`*^9, 3.7368289985130577`*^9, 
   3.7368291754956045`*^9, 3.7428962866117325`*^9, 3.7456497066103487`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.706703490403116*^9, 3.706703502273795*^9}, 
   3.7067035343996325`*^9, 3.706703587907693*^9, 3.7067040551374173`*^9, 
   3.706704106432351*^9, 3.709824303746129*^9, 3.730097044359207*^9, 
   3.7306278338200645`*^9, 3.7368259256993933`*^9, 3.7368289985130577`*^9, 
   3.7368291754956045`*^9, 3.7428962866117325`*^9, 3.7456497066203485`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"], ",", 
     FractionBox["P", "3"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.706703490403116*^9, 3.706703502273795*^9}, 
   3.7067035343996325`*^9, 3.706703587907693*^9, 3.7067040551374173`*^9, 
   3.706704106432351*^9, 3.709824303746129*^9, 3.730097044359207*^9, 
   3.7306278338200645`*^9, 3.7368259256993933`*^9, 3.7368289985130577`*^9, 
   3.7368291754956045`*^9, 3.7428962866117325`*^9, 3.7456497066203485`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Stress- and strain-induced level shifts for all four NV orientations\
\>", "Title",
 CellChangeTimes->{{3.702123148151004*^9, 3.7021231706714544`*^9}, {
  3.709874138752553*^9, 3.709874168763153*^9}, {3.7098746022023644`*^9, 
  3.7098746093525076`*^9}}],

Cell[CellGroupData[{

Cell["\<\
To include all four NV orientations, we keep the NV orientation fixed and \
rotate the crystal coordinate system. Essentially, we rotate the stress \
tensor using a passive coordinate system transformation.\
\>", "Item",
 CellChangeTimes->{{3.702123176411569*^9, 3.7021232689434195`*^9}, {
  3.709824998014247*^9, 3.7098250637995625`*^9}, {3.7368288977980394`*^9, 
  3.7368289007980995`*^9}}],

Cell["\<\
The formalism here employs an NV center, whose coordinate system xyz is \
defined such that the y-axis is contained by one of the three mirror planes.\
\>", "Item",
 CellChangeTimes->{{3.702123176411569*^9, 3.7021232689434195`*^9}, {
  3.709824998014247*^9, 3.7098251036732326`*^9}, {3.74564894950819*^9, 
  3.7456489498781977`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"clearing", " ", "all", " ", "variables"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.7098251989043055`*^9, 3.7098252217816143`*^9}}],

Cell[CellGroupData[{

Cell["2.1 Defining NV orientations", "Section",
 CellChangeTimes->{{3.7021250841477246`*^9, 3.702125093867919*^9}, {
  3.7098746119025583`*^9, 3.7098746146526136`*^9}}],

Cell["\<\
Here we determine possible xyz of the four NV orientations in a \
[001]-oriented diamond. As stated above, the NV coordinate systems xyz are \
defined such that the y-axes are contained by one of the three mirror planes.\
\>", "Text",
 CellChangeTimes->{{3.7098254111839633`*^9, 3.709825500026119*^9}, {
  3.736828914464374*^9, 3.7368289226595383`*^9}, {3.745648965290506*^9, 
  3.7456489692805853`*^9}}],

Cell[CellGroupData[{

Cell["Schematic NV center", "Subsection",
 CellChangeTimes->{{3.7021234288796186`*^9, 3.7021234344797306`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"radiuslattice", "=", " ", "0.0025"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"radiusatoms", " ", "=", " ", "0.04"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lengthlatticecoordsys", " ", "=", " ", "0.5"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"box", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nitrogen", " ", "=", " ", 
   RowBox[{"Sphere", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "radiusatoms"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vacancy", " ", "=", " ", 
   RowBox[{"Sphere", "[", 
    RowBox[{
     RowBox[{"0.5", "*", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", "radiusatoms"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Carbons", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sphere", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", "radiusatoms"}], "]"}],
      ",", " ", 
     RowBox[{"Sphere", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", "radiusatoms"}], "]"}],
      ",", " ", 
     RowBox[{"Sphere", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", "radiusatoms"}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NNNconncection", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cylinder", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.5", ",", " ", "0.5", ",", "0.5"}], "}"}]}], "}"}], ",", 
       "radiuslattice"}], "]"}], ",", 
     RowBox[{"Cylinder", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.5", ",", "0.5", ",", "0.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", " ", "0", ",", "1"}], "}"}]}], "}"}], ",", 
       "radiuslattice"}], "]"}], ",", 
     RowBox[{"Cylinder", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.5", ",", "0.5", ",", "0.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "1", ",", "1"}], "}"}]}], "}"}], ",", 
       "radiuslattice"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Cylinder", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.5", ",", "0.5", ",", "0.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", " ", "1", ",", "0"}], "}"}]}], "}"}], ",", 
       "radiuslattice"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"planeCarbons", " ", "=", " ", 
   RowBox[{"Polygon", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LatticeCoordSys", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"1", "*", "lengthlatticecoordsys", "*", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"lengthlatticecoordsys", "*", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"lengthlatticecoordsys", "*", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}], "}"}], "]"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7021234571601844`*^9, 3.7021234573501883`*^9}, 
   3.7021238348007374`*^9, 3.7021238715314717`*^9, {3.7049535385830193`*^9, 
   3.704953549751136*^9}, {3.730097766970151*^9, 3.730097767090152*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Orientations of NV1 - 4 (the y axis always lies in a mirror plane of the \
defect)\
\>", "Subsection",
 CellChangeTimes->{{3.70212328344371*^9, 3.702123294063922*^9}, {
  3.702123334014721*^9, 3.702123368407409*^9}, {3.7098251132672496`*^9, 
  3.709825114577652*^9}, {3.736828934409773*^9, 3.73682894374996*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"shortenz", " ", "=", " ", "0.82"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shortenx", " ", "=", " ", 
   RowBox[{"1", "*", "shortenz"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shorteny", " ", "=", " ", "shortenx"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"start1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV1x", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", "0"}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV1y", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", "2"}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "6", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV1z", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "3", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NVCoordSys1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start1", ",", 
        RowBox[{"start1", "+", 
         RowBox[{"shortenx", "*", "NV1x"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start1", ",", 
        RowBox[{"start1", "+", 
         RowBox[{"shorteny", " ", "*", "NV1y"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start1", ",", 
        RowBox[{"start1", "+", 
         RowBox[{"shortenz", "*", "NV1z"}]}]}], "}"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"start2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV2x", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", "0"}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV2y", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "2"}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "6", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NV2z", "=", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], "/", 
     RowBox[{"Sqrt", "[", "3", "]"}]}]}], ";"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NVCoordSys2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start2", ",", 
        RowBox[{"start2", "+", 
         RowBox[{"shortenx", "*", "NV2x"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start2", ",", 
        RowBox[{"start2", "+", 
         RowBox[{"shorteny", " ", "*", "NV2y"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start2", ",", 
        RowBox[{"start2", "+", 
         RowBox[{"shortenz", "*", "NV2z"}]}]}], "}"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"start3", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV3x", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "0"}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV3y", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "2"}]}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "6", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NV3z", "=", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], "/", 
     RowBox[{"Sqrt", "[", "3", "]"}]}]}], ";"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NVCoordSys3", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start3", ",", 
        RowBox[{"start3", "+", 
         RowBox[{"shortenx", "*", "NV3x"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start3", ",", 
        RowBox[{"start3", "+", 
         RowBox[{"shorteny", " ", "*", "NV3y"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start3", ",", 
        RowBox[{"start3", "+", 
         RowBox[{"shortenz", "*", "NV3z"}]}]}], "}"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"start4", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV4x", " ", "=", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", "0"}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV4y", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", 
      RowBox[{"-", "2"}]}], "}"}], "/", 
    RowBox[{"Sqrt", "[", "6", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NV4z", "=", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], "/", 
     RowBox[{"Sqrt", "[", "3", "]"}]}]}], ";"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NVCoordSys4", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start4", ",", 
        RowBox[{"start4", "+", 
         RowBox[{"shortenx", "*", "NV4x"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start4", ",", 
        RowBox[{"start4", "+", 
         RowBox[{"shorteny", " ", "*", "NV4y"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"{", 
       RowBox[{"start4", ",", 
        RowBox[{"start4", "+", 
         RowBox[{"shortenz", "*", "NV4z"}]}]}], "}"}], "]"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.702123297803997*^9, 3.7021233318746786`*^9}, {
   3.7021233714474697`*^9, 3.702123387547792*^9}, {3.702123681206665*^9, 
   3.7021237961499643`*^9}, 3.7021238278905993`*^9, {3.7021239339627204`*^9, 
   3.702123964193325*^9}, {3.7021240179564004`*^9, 3.702124041736876*^9}, {
   3.7021241141193237`*^9, 3.702124186690775*^9}, {3.702124234981741*^9, 
   3.7021242727224956`*^9}, 3.7021243763565683`*^9, {3.702124414738336*^9, 
   3.7021244327986975`*^9}, {3.702124553021102*^9, 3.702124586371769*^9}, {
   3.702124618182405*^9, 3.702124620372449*^9}, {3.702124804229126*^9, 
   3.7021249778745995`*^9}, {3.702125028725616*^9, 3.702125040515852*^9}, {
   3.7021253368228073`*^9, 3.7021253937749467`*^9}, {3.7300970252090054`*^9, 
   3.730097028389042*^9}, {3.7300971553903503`*^9, 3.7300972082648983`*^9}, {
   3.730097420077075*^9, 3.730097446921348*^9}, {3.730097573391652*^9, 
   3.730097621470144*^9}, {3.7300977939934263`*^9, 3.730097796453451*^9}, {
   3.730552819815322*^9, 3.730552824675582*^9}, {3.7305537348878736`*^9, 
   3.7305537631046143`*^9}, {3.73407056066744*^9, 3.734070568337593*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Graphical representation of NV coordinates xyz and crystal coordinates XYZ\
\>", "Subsection",
 CellChangeTimes->{{3.702123473410509*^9, 3.7021234839907207`*^9}, {
  3.7021237131673045`*^9, 3.7021237173873887`*^9}, {3.7368289502300897`*^9, 
  3.736828961122309*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graph", " ", "=", " ", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Black", ",", "Nitrogen", ",", "\[IndentingNewLine]", "Black", ",", 
      RowBox[{"Opacity", "[", "1", "]"}], ",", "Vacancy", ",", " ", 
      "\[IndentingNewLine]", "Black", ",", 
      RowBox[{"Opacity", "[", "1", "]"}], ",", "Carbons", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"EdgeForm", "[", "]"}], ",", 
      RowBox[{"Opacity", "[", "1", "]"}], ",", "Black", ",", "Thick", ",", 
      "LatticeCoordSys", ",", "\[IndentingNewLine]", 
      RowBox[{"Opacity", "[", "1", "]"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"z", "-", 
        RowBox[{"axes", ":", " ", "solid"}]}], "*)"}], "\[IndentingNewLine]", 
      "Thick", ",", "Green", ",", 
      RowBox[{"NVCoordSys1", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Red", ",", 
      RowBox[{"NVCoordSys2", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Blue", ",", 
      RowBox[{"NVCoordSys3", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Orange", ",", 
      RowBox[{"NVCoordSys4", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"x", "-", 
        RowBox[{"axes", ":", " ", "dashed"}]}], "*)"}], "\[IndentingNewLine]",
       "Thick", ",", "Green", ",", "Dashed", ",", " ", 
      RowBox[{"NVCoordSys1", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Red", ",", "Dashed", ",", " ", 
      RowBox[{"NVCoordSys2", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Blue", ",", "Dashed", ",", " ", 
      RowBox[{"NVCoordSys3", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Orange", ",", "Dashed", ",", " ", 
      RowBox[{"NVCoordSys4", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"y", "-", 
        RowBox[{"axes", ":", " ", "dotted"}]}], "*)"}], "\[IndentingNewLine]",
       "Thick", ",", "Green", ",", "Dotted", ",", " ", 
      RowBox[{"NVCoordSys1", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Red", ",", "Dotted", ",", " ", 
      RowBox[{"NVCoordSys2", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Blue", ",", "Dotted", ",", " ", 
      RowBox[{"NVCoordSys3", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", "\[IndentingNewLine]", "Thick", 
      ",", "Orange", ",", "Dotted", ",", " ", 
      RowBox[{"NVCoordSys4", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"Opacity", "[", "0.4", "]"}], ",", "Black", ",", 
      RowBox[{"Dashing", "[", "0.005", "]"}], ",", "box"}], "}"}], ",", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"Boxed", "\[Rule]", " ", "False"}], ",", 
    RowBox[{"Background", "\[Rule]", " ", "White"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7021238385508122`*^9, 3.7021238393608284`*^9}, {
  3.7021238924318895`*^9, 3.7021239118122773`*^9}, {3.7021241947609367`*^9, 
  3.7021241957609563`*^9}, {3.7021242820826826`*^9, 3.702124291472871*^9}, {
  3.702124595831958*^9, 3.70212460743219*^9}, {3.730097051889282*^9, 
  3.730097059700365*^9}, {3.7300971198999844`*^9, 3.7300971261500473`*^9}, {
  3.7300973865927253`*^9, 3.730097397660841*^9}, {3.7300976990524464`*^9, 
  3.7300977373188467`*^9}, {3.7300991189808598`*^9, 3.7300991209792643`*^9}, {
  3.7300993872551174`*^9, 3.7300993883742294`*^9}, {3.742896381094759*^9, 
  3.7428963907899537`*^9}, {3.742896577894817*^9, 3.742896761858717*^9}, {
  3.7428968712680464`*^9, 3.742896901554658*^9}, {3.7428969995686283`*^9, 
  3.742897161512943*^9}, {3.7428972005387745`*^9, 3.7428972578639326`*^9}, {
  3.742897290790597*^9, 3.742897309297969*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0], SphereBox[{0, 0, 0}, 0.04]}, 
   {GrayLevel[0], Opacity[1], SphereBox[{0.5, 0.5, 0.5}, 0.04]}, 
   {GrayLevel[0], Opacity[1], SphereBox[{1, 1, 0}, 0.04], 
    SphereBox[{0, 1, 1}, 0.04], SphereBox[{1, 0, 1}, 0.04]}, 
   {GrayLevel[0], Thickness[Large], Opacity[1], EdgeForm[
    None], {Arrow3DBox[{{0, 0, 0}, {0.5, 0., 0.}}], 
     Arrow3DBox[{{0, 0, 0}, {0., 0.5, 0.}}], 
     Arrow3DBox[{{0, 0, 0}, {0., 0., 0.5}}]}, 
    {RGBColor[0, 1, 0], Thickness[Large], Opacity[1], 
     Arrow3DBox[{{0, 0, 0}, {0.47342722073549315`, 0.47342722073549315`, 
       0.47342722073549315`}}], 
     {RGBColor[1, 0, 0], Thickness[Large], 
      Arrow3DBox[{{1, 1, 0}, {0.5265727792645069, 0.5265727792645069, 
        0.47342722073549315`}}]}, 
     {RGBColor[0, 0, 1], Thickness[Large], 
      Arrow3DBox[{{1, 0, 1}, {0.5265727792645069, 0.47342722073549315`, 
        0.5265727792645069}}]}, 
     {RGBColor[1, 0.5, 0], Thickness[Large], 
      Arrow3DBox[{{0, 1, 1}, {0.47342722073549315`, 0.5265727792645069, 
        0.5265727792645069}}]}, 
     {RGBColor[0, 1, 0], Thickness[Large], Dashing[{Small, Small}], 
      Arrow3DBox[{{0, 0, 0}, {-0.5798275605729689, 0.5798275605729689, 0.}}]}, 
     {RGBColor[1, 0, 0], Thickness[Large], Dashing[{Small, Small}], 
      Arrow3DBox[{{1, 1, 0}, {1.5798275605729688`, 0.4201724394270311, 0.}}]}, 
     {RGBColor[0, 0, 1], Thickness[Large], Dashing[{Small, Small}], 
      Arrow3DBox[{{1, 0, 1}, {1.5798275605729688`, 0.5798275605729689, 1.}}]}, 
     {RGBColor[1, 0.5, 0], Thickness[Large], Dashing[{Small, Small}], 
      Arrow3DBox[{{0, 1, 1}, {-0.5798275605729689, 0.4201724394270311, 1.}}]}, 
     {RGBColor[0, 1, 0], Thickness[Large], Dashing[{0, Small}], 
      Arrow3DBox[{{0, 0, 0}, {-0.3347635981803677, -0.3347635981803677, 
        0.6695271963607353}}]}, 
     {RGBColor[1, 0, 0], Thickness[Large], Dashing[{0, Small}], 
      Arrow3DBox[{{1, 1, 0}, {1.3347635981803676`, 1.3347635981803676`, 
        0.6695271963607353}}]}, 
     {RGBColor[0, 0, 1], Thickness[Large], Dashing[{0, Small}], 
      Arrow3DBox[{{1, 0, 1}, {1.3347635981803676`, -0.3347635981803677, 
        0.3304728036392647}}]}, 
     {RGBColor[1, 0.5, 0], Thickness[Large], Dashing[{0, Small}], 
      Arrow3DBox[{{0, 1, 1}, {-0.3347635981803677, 1.3347635981803676`, 
        0.3304728036392647}}], 
      {GrayLevel[0], Opacity[0.4], Dashing[0.005], 
       Line3DBox[{{0, 0, 0}, {1, 0, 0}, {1, 1, 0}, {0, 1, 0}, {0, 0, 0}, {0, 
        0, 1}, {1, 0, 1}, {1, 1, 1}, {0, 1, 1}, {0, 0, 1}}], 
       Line3DBox[{{0, 1, 0}, {0, 1, 1}}], Line3DBox[{{1, 1, 0}, {1, 1, 1}}], 
       Line3DBox[{{1, 0, 0}, {1, 0, 1}}]}}}}},
  Background->GrayLevel[1],
  Boxed->False,
  ImageSize->{683.6253798865924, 658.},
  ViewPoint->{1.011350891471796, -2.7633071039688057`, 1.670719373047056},
  ViewVertical->{0.10191132038340617`, -0.27841596781620337`, 
   1.9421522490236123`}]], "Output",
 CellChangeTimes->{
  3.702123841350868*^9, 3.7021239129322996`*^9, {3.702123948493011*^9, 
   3.7021239676933947`*^9}, 3.702124196470971*^9, {3.7021242865127716`*^9, 
   3.7021243006630545`*^9}, 3.7021243788566184`*^9, {3.702124607992201*^9, 
   3.7021246230025015`*^9}, 3.702124912031282*^9, 3.702125044385929*^9, 
   3.7021253969050093`*^9, 3.7021317091570244`*^9, 3.702276064907078*^9, 
   3.7047864686007814`*^9, 3.704893949226763*^9, 3.704894904212549*^9, 
   3.7049494637160163`*^9, 3.704978558505641*^9, 3.7049823986700134`*^9, 
   3.7049870974365997`*^9, 3.706703734838097*^9, 3.7081734763426857`*^9, 
   3.7081854279190345`*^9, {3.709793438272453*^9, 3.709793461854925*^9}, 
   3.709825834397507*^9, {3.7300970603903713`*^9, 3.730097068540453*^9}, {
   3.730097121109997*^9, 3.730097130300089*^9}, 3.730097169013491*^9, 
   3.7300972127499437`*^9, 3.7300973986608515`*^9, 3.7300974708195963`*^9, 
   3.7300976329632635`*^9, {3.730097700192458*^9, 3.730097738008854*^9}, {
   3.730097771430195*^9, 3.7300978013234997`*^9}, 3.730099121599314*^9, 
   3.7300993892632833`*^9, 3.730548792155367*^9, 3.730549109284663*^9, {
   3.7305528278616886`*^9, 3.7305528556260624`*^9}, {3.7305537428622046`*^9, 
   3.730553766608858*^9}, 3.7306278232524443`*^9, 3.7306278578036337`*^9, 
   3.730629427919068*^9, 3.7306358328018117`*^9, 3.732010074146674*^9, 
   3.7340705897130213`*^9, 3.7365891810073833`*^9, 3.7368259258293962`*^9, 
   3.736828998663061*^9, 3.7368291756556077`*^9, 3.742896386032858*^9, {
   3.7428966667977533`*^9, 3.742896765758795*^9}, {3.7428968887013984`*^9, 
   3.7428969026546803`*^9}, {3.7428970028056955`*^9, 
   3.7428970634659185`*^9}, {3.7428971271742525`*^9, 3.742897162282958*^9}, {
   3.7428972122000113`*^9, 3.7428972582509413`*^9}, {3.7428973016778164`*^9, 
   3.7428973096779766`*^9}, {3.7456497162785425`*^9, 3.7456497445821085`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Graphical representation of coordinate systems xyz showing only the \
quantization axes\
\>", "Subsection",
 CellChangeTimes->{{3.704953417627925*^9, 3.7049534296571274`*^9}, {
  3.736828968964466*^9, 3.736828976914625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graph", " ", "=", " ", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Black", ",", "Nitrogen", ",", "Black", ",", "Vacancy", ",", " ", 
      "Black", ",", 
      RowBox[{"Opacity", "[", "1", "]"}], ",", "Carbons", ",", 
      RowBox[{"EdgeForm", "[", "]"}], ",", 
      RowBox[{"Opacity", "[", "0", "]"}], ",", "Gray", ",", "NNNconncection", 
      ",", 
      RowBox[{"Opacity", "[", "1", "]"}], ",", 
      RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Green", ",", " ", 
      RowBox[{"Arrowheads", "[", "0.05", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{"start1", ",", 
         RowBox[{"start1", "+", 
          RowBox[{"shortenz", "*", "NV1z"}]}]}], "}"}], "]"}], ",", "Red", 
      ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{"start2", ",", 
         RowBox[{"start2", "+", 
          RowBox[{"shortenz", "*", "NV2z"}]}]}], "}"}], "]"}], ",", "Blue", 
      ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{"start3", ",", 
         RowBox[{"start3", "+", 
          RowBox[{"shortenz", "*", "NV3z"}]}]}], "}"}], "]"}], ",", "Orange", 
      ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{"start4", ",", 
         RowBox[{"start4", "+", 
          RowBox[{"shortenz", "*", "NV4z"}]}]}], "}"}], "]"}], ",", 
      RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
      RowBox[{"Opacity", "[", "1", "]"}], ",", "Black", ",", " ", 
      RowBox[{"Dashing", "[", "0.01", "]"}], ",", "box"}], "}"}], ",", " ", 
    RowBox[{"Boxed", "\[Rule]", " ", "False"}], ",", 
    RowBox[{"Background", "\[Rule]", " ", "White"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.704953457163878*^9, 3.7049535247586365`*^9}, {
  3.7049535802971897`*^9, 3.704953826059764*^9}, {3.704953883476505*^9, 
  3.704954029197076*^9}, {3.7049549622223687`*^9, 3.7049549623733835`*^9}, {
  3.730097298361821*^9, 3.7300973615004706`*^9}, {3.7300974538464217`*^9, 
  3.730097464899537*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0], SphereBox[{0, 0, 0}, 0.04]}, 
   {GrayLevel[0], SphereBox[{0.5, 0.5, 0.5}, 0.04]}, 
   {GrayLevel[0], Opacity[1], SphereBox[{1, 1, 0}, 0.04], 
    SphereBox[{0, 1, 1}, 0.04], SphereBox[{1, 0, 1}, 0.04]}, 
   {GrayLevel[0.5], Opacity[0], EdgeForm[
    None], {CylinderBox[{{0, 0, 0}, {0.5, 0.5, 0.5}}, 0.0025], 
     CylinderBox[{{0.5, 0.5, 0.5}, {1, 0, 1}}, 0.0025], 
     CylinderBox[{{0.5, 0.5, 0.5}, {0, 1, 1}}, 0.0025], 
     CylinderBox[{{0.5, 0.5, 0.5}, {1, 1, 0}}, 0.0025]}, 
    {RGBColor[0, 1, 0], Thickness[0.01], Opacity[1], Arrowheads[0.05], 
     Arrow3DBox[{{0, 0, 0}, {0.47342722073549315`, 0.47342722073549315`, 
       0.47342722073549315`}}], 
     {RGBColor[1, 0, 0], 
      Arrow3DBox[{{1, 1, 0}, {0.5265727792645069, 0.5265727792645069, 
        0.47342722073549315`}}]}, 
     {RGBColor[0, 0, 1], 
      Arrow3DBox[{{1, 0, 1}, {0.5265727792645069, 0.47342722073549315`, 
        0.5265727792645069}}]}, 
     {RGBColor[1, 0.5, 0], 
      Arrow3DBox[{{0, 1, 1}, {0.47342722073549315`, 0.5265727792645069, 
        0.5265727792645069}}]}, 
     {GrayLevel[0], Thickness[0.005], Opacity[1], Dashing[0.01], 
      Line3DBox[{{0, 0, 0}, {1, 0, 0}, {1, 1, 0}, {0, 1, 0}, {0, 0, 0}, {0, 0,
        1}, {1, 0, 1}, {1, 1, 1}, {0, 1, 1}, {0, 0, 1}}], 
      Line3DBox[{{0, 1, 0}, {0, 1, 1}}], Line3DBox[{{1, 1, 0}, {1, 1, 1}}], 
      Line3DBox[{{1, 0, 0}, {1, 0, 1}}]}}}},
  Background->GrayLevel[1],
  Boxed->False,
  ImageSize->{351.23651479950354`, 368.7033036039374},
  ViewPoint->{1.0358514939457146`, -2.8288964576648894`, 1.540894712269943},
  ViewVertical->{0.07448733622239091, -0.142070267534995, 
   0.9870499864875272}]], "Output",
 CellChangeTimes->{
  3.7049534401271744`*^9, {3.7049534885460157`*^9, 3.704953608948055*^9}, {
   3.7049536519903584`*^9, 3.704953826440802*^9}, {3.7049538944746046`*^9, 
   3.704954029562112*^9}, 3.704954963267473*^9, 3.7049785585368414`*^9, 
   3.704982398716813*^9, 3.7049870974833994`*^9, 3.7067037348791*^9, 
   3.708173476373886*^9, 3.708185427981435*^9, {3.7097934382924533`*^9, 
   3.709793461884926*^9}, 3.709825834413107*^9, 3.7300970686704545`*^9, 
   3.730097282504657*^9, {3.7300973313921614`*^9, 3.730097362522481*^9}, {
   3.730097466129549*^9, 3.7300974745596333`*^9}, 3.730548792175367*^9, 
   3.7305491093146634`*^9, {3.730552847426916*^9, 3.7305528557020698`*^9}, 
   3.730627823282447*^9, 3.730627857843637*^9, 3.7306294279590683`*^9, 
   3.730635832831812*^9, 3.732010074166674*^9, 3.736589181037384*^9, 
   3.7368259258493967`*^9, 3.7368289987130623`*^9, 3.736829175705609*^9, 
   3.7456497162885427`*^9, 3.7456497468921547`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 Defining rotation matrices for NV1 to NV2-4", "Section",
 CellChangeTimes->{{3.702125099218026*^9, 3.702125108768217*^9}, {
  3.709825274870924*^9, 3.709825280424534*^9}, {3.7098746172926664`*^9, 
  3.7098746179926805`*^9}}],

Cell["\<\
The index denotes the vector about which the rotation is performed. An active \
rotation is a rotation of a vector in a fixed coordinate system. A rotation \
is positive if performed clockwise (observed along the rotation vector). If \
the active transformation is known, the passive transformation is simply the \
inverse (with Inverse[Rx[xdeg].Ry[ydeg].Rz[zdeg]] == \
Rz[-zdeg].Ry[-ydeg].Rx[-xdeg]). \[LineSeparator]In the following, active \
rotations rotate vector NV1 to NV2-4. For a coordinate transformation of xyz \
of NV1 into xyz of NV2-4, we need to employ the inverse of the active \
rotation!\
\>", "Text",
 CellChangeTimes->{{3.7098254111839633`*^9, 3.709825417938775*^9}, {
  3.730551725980571*^9, 3.730551748906878*^9}, {3.730551782122921*^9, 
  3.7305518467086153`*^9}, {3.7305519122248764`*^9, 3.730551963050108*^9}, {
  3.734072512720667*^9, 3.734072552518468*^9}}],

Cell[CellGroupData[{

Cell["General definitions of rotation matrices (in 3x3 form)", "Subsection",
 CellChangeTimes->{{3.702125117468391*^9, 3.702125140988861*^9}, {
  3.7021252759715905`*^9, 3.7021252802716765`*^9}, {3.70982529529136*^9, 
  3.7098253101425858`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Rx", "[", "xdeg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xdeg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ry", "[", "ydeg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ydeg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rz", "[", "zdeg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"zdeg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rm1p10", "[", "deg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"deg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", "0"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rp1p10", "[", "deg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"deg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R111", "[", "deg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"deg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rpar111", " ", "[", "vec_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{"{", 
    RowBox[{"vec", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.702125146808978*^9, 3.7021251474889917`*^9}, 
   3.702125185737786*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Passive rotation NV1 to NV2: KNV2passive = Rz[-180]", "Subsection",
 CellChangeTimes->{{3.702125289651864*^9, 3.7021252946219635`*^9}, {
   3.7021318266096306`*^9, 3.702131849494871*^9}, {3.709825258272495*^9, 
   3.7098252609868994`*^9}, {3.7306278922510543`*^9, 3.7306279071611814`*^9}, 
   3.7343416535243635`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"KNV2active", " ", "=", " ", 
   RowBox[{"Rz", "[", "180", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV2xcalc", " ", "=", " ", 
   RowBox[{"KNV2active", ".", "NV1x"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV2ycalc", " ", "=", " ", 
   RowBox[{"KNV2active", ".", "NV1y"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV2zcalc", " ", "=", " ", 
   RowBox[{"KNV2active", ".", "NV1z"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV2passive", " ", "=", " ", 
   RowBox[{"Inverse", "[", "KNV2active", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.702125301792107*^9, 3.7021253179924307`*^9}, {
   3.70212540344514*^9, 3.702125471976511*^9}, {3.7021255040671525`*^9, 
   3.702125508547242*^9}, {3.702125634701765*^9, 3.702125643991951*^9}, {
   3.704895059463505*^9, 3.7048950913811607`*^9}, {3.7305519695159645`*^9, 
   3.730552037755535*^9}, {3.734071800864362*^9, 3.734071856799488*^9}, {
   3.7343416295448833`*^9, 3.734341649984293*^9}, 3.734341689181079*^9, {
   3.7456490434410706`*^9, 3.7456490439510803`*^9}, {3.7456497794578075`*^9, 
   3.745649788881996*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Passive rotation NV1 to NV3: KNV3passive = Rz[90].Rp1p10[-180]\
\>", "Subsection",
 CellChangeTimes->{{3.7021254811066933`*^9, 3.7021254926169233`*^9}, {
   3.702131839854054*^9, 3.702131848683669*^9}, 3.7098252676793113`*^9, {
   3.7306279313304653`*^9, 3.730627950634326*^9}, {3.734341655654406*^9, 
   3.7343416573144393`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"KNV3active", " ", "=", " ", 
   RowBox[{
    RowBox[{"Rp1p10", "[", "180", "]"}], ".", 
    RowBox[{"Rz", "[", 
     RowBox[{"-", "90"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV3xcalc", " ", "=", " ", 
   RowBox[{"KNV3active", ".", "NV1x"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV3ycalc", " ", "=", " ", 
   RowBox[{"KNV3active", ".", "NV1y"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV3zcalc", " ", "=", " ", 
   RowBox[{"KNV3active", ".", "NV1z"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV3passive", " ", "=", " ", 
   RowBox[{"Inverse", "[", "KNV3active", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.702125496637004*^9, 3.7021255303176775`*^9}, {
   3.7021256215615025`*^9, 3.7021256514121*^9}, {3.702125708674245*^9, 
   3.702125767175415*^9}, {3.730552045690797*^9, 3.7305521098672953`*^9}, {
   3.7340718621695957`*^9, 3.734071890403165*^9}, {3.7343416608265095`*^9, 
   3.7343417024423456`*^9}, 3.7343417399841027`*^9, {3.7368289871728315`*^9, 
   3.736828988542858*^9}, {3.7456490532602673`*^9, 3.745649053800278*^9}, {
   3.745649794472108*^9, 3.745649799882216*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Passive rotation NV1 to NV4: KNV4passive = Rz[-90].Rp1p10[-180]\
\>", "Subsection",
 CellChangeTimes->{{3.7021317320890646`*^9, 3.7021317398578787`*^9}, {
   3.702131842864859*^9, 3.702131847950468*^9}, 3.709825269395314*^9, {
   3.730627970059429*^9, 3.7306279848110657`*^9}, {3.73434171054451*^9, 
   3.7343417109145174`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"KNV4active", " ", "=", " ", 
   RowBox[{
    RowBox[{"Rp1p10", "[", "180", "]"}], ".", 
    RowBox[{"Rz", "[", "90", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV4xcalc", "=", " ", 
   RowBox[{"KNV4active", ".", "NV1x"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV4ycalc", "=", " ", 
   RowBox[{"KNV4active", ".", "NV1y"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NV4zcalc", "=", " ", 
   RowBox[{"KNV4active", ".", "NV1z"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV4passive", " ", "=", " ", 
   RowBox[{"Inverse", "[", "KNV4active", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7021317473926916`*^9, 3.702131804831992*^9}, {
  3.730627995467677*^9, 3.730628036012958*^9}, {3.7340719012763824`*^9, 
  3.7340719601205654`*^9}, {3.7343417161146216`*^9, 3.734341736683037*^9}, {
  3.745649059440391*^9, 3.7456490597903976`*^9}, {3.7456498183775864`*^9, 
  3.7456498227616744`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.3 Stress-induced coupling amplitudes Mx, My, Mz, Nx and Ny for all four NV \
orientations NV1-4 \[LineSeparator](with the stress tensor \[Sigma]XYZ \
defined in crystal coordinates XYZ)\
\>", "Section",
 CellChangeTimes->{{3.7021318909952435`*^9, 3.7021319285445094`*^9}, {
  3.7021388209528646`*^9, 3.702138827608246*^9}, {3.709825536748584*^9, 
  3.7098255742666492`*^9}, {3.7098746197527156`*^9, 3.7098746202027245`*^9}, {
  3.730548709065618*^9, 3.7305487260791607`*^9}, {3.7340738771374106`*^9, 
  3.7340738803174744`*^9}, {3.7368290106513014`*^9, 3.7368290148163857`*^9}}],

Cell["\<\
Approach :
We want to obtain coupling amplitudes Mx,My,Mz,Nx,Ny for all four NV \
orientations, expressed in terms of stress tensor components \[Sigma]IJ. To \
that end we could either rotate the defect orientation and keep the stress \
tensor fixed in position. Or we keep the defect fixed and perform a \
corresponding coordinate system transformation on the stress tensor. We \
decided to go for the latter.

Such a coordinate system transformation is performed by \[Sigma]XYZNVk = \
RotPassive1k.\[Sigma]XYZNV1.Transpose[RotPassive1k]. The resulting stress \
tensor then describes how stress of a certain direction is perceived by the \
NV of orientation k. What might be confusing in the formalism is that the \
initial coupling amplitudes Mx,My,Mz,Nx,Ny are valid for NV1. Therefore, \
\[Sigma]XYZ is the stress tensor seen by NV1.

Note:\[LineSeparator]The expressions for the coupling amplitudes are taken \
from Udvarhelyi2018.\
\>", "Text",
 CellChangeTimes->{{3.7340725776669717`*^9, 3.734072917699794*^9}, {
  3.7368290244875793`*^9, 3.7368290390298705`*^9}, {3.745649093949082*^9, 
  3.7456491098794003`*^9}}],

Cell[CellGroupData[{

Cell["\<\
2.3.1 Define stress tensor in crystal coordinates XYZ with X||[100], Y||[010] \
and Z||[001]\
\>", "Subsection",
 CellChangeTimes->{{3.7021319375769253`*^9, 3.7021319784333973`*^9}, {
  3.734072951061465*^9, 3.7340729524914937`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]XYZ", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]XX", ",", " ", "\[Sigma]XY", ",", " ", "\[Sigma]XZ"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]YX", ",", " ", "\[Sigma]YY", ",", " ", "\[Sigma]YZ"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]ZX", ",", " ", "\[Sigma]ZY", ",", " ", "\[Sigma]ZZ"}], 
      "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.702131981693803*^9, 3.7021320409895067`*^9}, {
  3.702279144371361*^9, 3.7022791714374084`*^9}, {3.734072947110386*^9, 
  3.734072948470413*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3.2 Calculate coupling amplitudes for all NV orientations", \
"Subsection",
 CellChangeTimes->{{3.734072956454577*^9, 3.7340729934613185`*^9}}],

Cell["\[Sigma]XYZNVk = RotPassive1k.\[Sigma]XYZNV1.Transpose[RotPassive1k]", \
"Text",
 CellChangeTimes->{{3.734073006131572*^9, 3.734073009591641*^9}}],

Cell[CellGroupData[{

Cell["NV1", "Subsubsection",
 CellChangeTimes->{{3.7021320554975324`*^9, 3.7021320882887897`*^9}, {
  3.7021330814489346`*^9, 3.702133104770975*^9}, {3.7305506784110928`*^9, 
  3.730550717307665*^9}, {3.7340728799820375`*^9, 3.7340728803320436`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]XYZNV1", " ", "=", " ", "\[Sigma]XYZ"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV1", "=", 
   RowBox[{
    RowBox[{"b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV1", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV1", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV1", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV1", " ", "=", " ", 
   RowBox[{
    RowBox[{"a1", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"2", "*", "a2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV1", "=", 
   RowBox[{
    RowBox[{"d", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV1", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"e", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV1", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NyNV1", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "d", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "e", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV1", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "\[Sigma]XYZNV1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"{", 
   RowBox[{
   "MxNV1", ",", "MyNV1", ",", "MzNV1", ",", "NxNV1", " ", ",", "NyNV1"}], 
   "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7021320975864067`*^9, 3.7021321205028467`*^9}, {
  3.702132301369564*^9, 3.7021323613516693`*^9}, {3.7021330638053036`*^9, 
  3.702133076612926*^9}, {3.7021331085461817`*^9, 3.702133201865546*^9}, {
  3.702133232129599*^9, 3.7021333190217514`*^9}, {3.7098256072763076`*^9, 
  3.709825673607624*^9}, {3.709825769922594*^9, 3.7098257830734167`*^9}, {
  3.7305487483099346`*^9, 3.730548783343914*^9}, {3.730548839933409*^9, 
  3.730548846083471*^9}, {3.7305491363397007`*^9, 3.730549139916919*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\[Sigma]XX", "\[Sigma]XY", "\[Sigma]XZ"},
     {"\[Sigma]YX", "\[Sigma]YY", "\[Sigma]YZ"},
     {"\[Sigma]ZX", "\[Sigma]ZY", "\[Sigma]ZZ"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7021333200981536`*^9, 3.702276064985078*^9, 3.7047864687207813`*^9, 
   3.7048939493515625`*^9, 3.704894904259349*^9, 3.7049494637800164`*^9, 
   3.7049785586928415`*^9, 3.7049823988104134`*^9, 3.7049870975613995`*^9, 
   3.706703735006107*^9, 3.7081734764674864`*^9, 3.7081854281062346`*^9, {
   3.709793438382455*^9, 3.709793461934927*^9}, {3.709825613079518*^9, 
   3.7098256419239683`*^9}, 3.709825674715226*^9, 3.7098257853978214`*^9, 
   3.709825834491107*^9, {3.730548834515168*^9, 3.730548846705513*^9}, {
   3.7305491252480993`*^9, 3.730549140536967*^9}, 3.730627823619481*^9, 
   3.7306278717609663`*^9, 3.7306294345754623`*^9, 3.7306358448699694`*^9, 
   3.732010074516681*^9, 3.734073017575803*^9, 3.7365891812173877`*^9, 
   3.7365895632194943`*^9, 3.7365896562094603`*^9, 3.736825925989399*^9, 
   3.736828998833064*^9, 3.7368291758356113`*^9, 3.745649716338544*^9, 
   3.7456497609074354`*^9, 3.7456498436220913`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "-", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XX"}], "-", "\[Sigma]YY", "+", 
           RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XZ"}], "+", "\[Sigma]YZ"}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"2", " ", "a2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XY", "+", "\[Sigma]XZ", "+", "\[Sigma]YZ"}], 
          ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
          ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "-", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XX"}], "-", "\[Sigma]YY", "+", 
           RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", "e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XZ"}], "+", "\[Sigma]YZ"}], ")"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7021333200981536`*^9, 3.702276064985078*^9, 3.7047864687207813`*^9, 
   3.7048939493515625`*^9, 3.704894904259349*^9, 3.7049494637800164`*^9, 
   3.7049785586928415`*^9, 3.7049823988104134`*^9, 3.7049870975613995`*^9, 
   3.706703735006107*^9, 3.7081734764674864`*^9, 3.7081854281062346`*^9, {
   3.709793438382455*^9, 3.709793461934927*^9}, {3.709825613079518*^9, 
   3.7098256419239683`*^9}, 3.709825674715226*^9, 3.7098257853978214`*^9, 
   3.709825834491107*^9, {3.730548834515168*^9, 3.730548846705513*^9}, {
   3.7305491252480993`*^9, 3.730549140536967*^9}, 3.730627823619481*^9, 
   3.7306278717609663`*^9, 3.7306294345754623`*^9, 3.7306358448699694`*^9, 
   3.732010074516681*^9, 3.734073017575803*^9, 3.7365891812173877`*^9, 
   3.7365895632194943`*^9, 3.7365896562094603`*^9, 3.736825925989399*^9, 
   3.736828998833064*^9, 3.7368291758356113`*^9, 3.745649716338544*^9, 
   3.7456497609074354`*^9, 3.7456498436220913`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV2", "Subsubsection",
 CellChangeTimes->{{3.702133373902648*^9, 3.702133384807067*^9}, 
   3.7098259779821596`*^9, {3.734073087197241*^9, 3.7340730883972645`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]XYZNV2", " ", "=", " ", 
   RowBox[{"KNV2passive", ".", "\[Sigma]XYZ", ".", 
    RowBox[{"Transpose", "[", "KNV2passive", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV2", "=", 
   RowBox[{
    RowBox[{"b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV2", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV2", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV2", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV2", " ", "=", " ", 
   RowBox[{
    RowBox[{"a1", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"2", "*", "a2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV2", "=", 
   RowBox[{
    RowBox[{"d", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV2", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"e", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV2", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NyNV2", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "d", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "e", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV2", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "\[Sigma]XYZNV2", "]"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"{", 
   RowBox[{
   "MxNV2", ",", "MyNV2", ",", "MzNV2", ",", " ", "NxNV2", ",", " ", 
    "NyNV2"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7021333884886737`*^9, 3.702133418737127*^9}, {
  3.704949458285016*^9, 3.7049494882960167`*^9}, {3.7098257942430363`*^9, 
  3.7098258494827337`*^9}, {3.730549528006997*^9, 3.730549594860114*^9}, {
  3.7306279199267044`*^9, 3.7306279228927393`*^9}, {3.7365896697797346`*^9, 
  3.7365896750648413`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\[Sigma]XX", "\[Sigma]XY", 
      RowBox[{"-", "\[Sigma]XZ"}]},
     {"\[Sigma]YX", "\[Sigma]YY", 
      RowBox[{"-", "\[Sigma]YZ"}]},
     {
      RowBox[{"-", "\[Sigma]ZX"}], 
      RowBox[{"-", "\[Sigma]ZY"}], "\[Sigma]ZZ"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.702133422512334*^9, 3.702276065000678*^9, 3.704786468740782*^9, 
   3.704893949382763*^9, 3.704894904274949*^9, {3.7049494637880163`*^9, 
   3.7049494894350166`*^9}, 3.704978558724042*^9, 3.7049823988260136`*^9, 
   3.7049870975926*^9, 3.7067037350321083`*^9, 3.7081734764986863`*^9, 
   3.7081854281218348`*^9, {3.709793438392455*^9, 3.7097934619549274`*^9}, {
   3.709825826207493*^9, 3.7098258500297346`*^9}, 3.730549506041935*^9, {
   3.730549571702758*^9, 3.7305495955801215`*^9}, 3.7306278241685357`*^9, 
   3.7306278722809715`*^9, 3.730627925920411*^9, 3.730629434601714*^9, 
   3.7306358449099693`*^9, 3.732010074556682*^9, 3.7340730244179397`*^9, 
   3.736589182127406*^9, 3.7365895640395107`*^9, 3.7365896770248804`*^9, 
   3.7368259260193996`*^9, 3.736828998863065*^9, 3.736829175865612*^9, 
   3.745649717208561*^9, {3.7456498350019193`*^9, 3.745649843652092*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Sigma]XY"}], "+", "\[Sigma]XZ", "+", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XX"}], "-", "\[Sigma]YY", "+", 
           RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XZ", "-", "\[Sigma]YZ"}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"2", " ", "a2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XY", "-", "\[Sigma]XZ", "-", "\[Sigma]YZ"}], 
          ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
          ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Sigma]XY"}], "+", "\[Sigma]XZ", "+", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XX"}], "-", "\[Sigma]YY", "+", 
           RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", "e", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XZ", "-", "\[Sigma]YZ"}], ")"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.702133422512334*^9, 3.702276065000678*^9, 3.704786468740782*^9, 
   3.704893949382763*^9, 3.704894904274949*^9, {3.7049494637880163`*^9, 
   3.7049494894350166`*^9}, 3.704978558724042*^9, 3.7049823988260136`*^9, 
   3.7049870975926*^9, 3.7067037350321083`*^9, 3.7081734764986863`*^9, 
   3.7081854281218348`*^9, {3.709793438392455*^9, 3.7097934619549274`*^9}, {
   3.709825826207493*^9, 3.7098258500297346`*^9}, 3.730549506041935*^9, {
   3.730549571702758*^9, 3.7305495955801215`*^9}, 3.7306278241685357`*^9, 
   3.7306278722809715`*^9, 3.730627925920411*^9, 3.730629434601714*^9, 
   3.7306358449099693`*^9, 3.732010074556682*^9, 3.7340730244179397`*^9, 
   3.736589182127406*^9, 3.7365895640395107`*^9, 3.7365896770248804`*^9, 
   3.7368259260193996`*^9, 3.736828998863065*^9, 3.736829175865612*^9, 
   3.745649717208561*^9, {3.7456498350019193`*^9, 3.745649843652092*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV3", "Subsubsection",
 CellChangeTimes->{{3.702133439219963*^9, 3.702133443868771*^9}, {
  3.7098259797761626`*^9, 3.709825980072563*^9}, {3.7340730911273193`*^9, 
  3.7340730931673603`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]XYZNV3", " ", "=", " ", 
   RowBox[{"KNV3passive", ".", "\[Sigma]XYZ", ".", 
    RowBox[{"Transpose", "[", "KNV3passive", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV3", "=", 
   RowBox[{
    RowBox[{"b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV3", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV3", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV3", "=", 
   RowBox[{
    RowBox[{"a1", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"2", "*", "a2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV3", "=", 
   RowBox[{
    RowBox[{"d", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV3", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"e", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV3", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NyNV3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "d", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "e", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV3", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "\[Sigma]XYZNV3", "]"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"{", 
   RowBox[{
   "MxNV3", ",", "MyNV3", ",", "MzNV3", ",", " ", "NxNV3", ",", " ", 
    "NyNV3"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.70213344898558*^9, 3.7021335017448726`*^9}, {
  3.709825863866959*^9, 3.7098259088262377`*^9}, {3.730550815248146*^9, 
  3.7305508820302205`*^9}, {3.730627960035904*^9, 3.7306279637911234`*^9}, {
  3.736589681585972*^9, 3.7365896861760635`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\[Sigma]XX", 
      RowBox[{"-", "\[Sigma]XY"}], "\[Sigma]XZ"},
     {
      RowBox[{"-", "\[Sigma]YX"}], "\[Sigma]YY", 
      RowBox[{"-", "\[Sigma]YZ"}]},
     {"\[Sigma]ZX", 
      RowBox[{"-", "\[Sigma]ZY"}], "\[Sigma]ZZ"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7021335400117397`*^9, 3.7022760650162783`*^9, 3.7047864687607813`*^9, 
   3.704893949398363*^9, 3.7048949042905493`*^9, 3.7049494637990165`*^9, 
   3.7049785587396417`*^9, 3.7049823988416133`*^9, 3.7049870976082*^9, 
   3.70670373506111*^9, 3.7081734765298862`*^9, 3.708185428137435*^9, {
   3.7097934384124556`*^9, 3.7097934619649277`*^9}, 3.7098258345379076`*^9, {
   3.709825897469418*^9, 3.709825909294239*^9}, 3.730550885180252*^9, 
   3.7306278248975816`*^9, 3.7306278728109765`*^9, 3.7306279648371716`*^9, 
   3.730629434621716*^9, 3.73063584493997*^9, 3.732010074576682*^9, 
   3.734073076531026*^9, 3.7365891830574245`*^9, 3.736589564839527*^9, 
   3.736589687149083*^9, 3.7368259260494003`*^9, 3.7368289988930655`*^9, 
   3.7368291758956127`*^9, 3.745649718088578*^9, {3.7456498370319595`*^9, 
   3.745649843692093*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "+", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XX"}], "-", "\[Sigma]YY", "+", 
           RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XZ"}], "-", "\[Sigma]YZ"}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"2", " ", "a2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XY"}], "+", "\[Sigma]XZ", "-", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
          ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "+", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XX"}], "-", "\[Sigma]YY", "+", 
           RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", "e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XZ"}], "-", "\[Sigma]YZ"}], ")"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7021335400117397`*^9, 3.7022760650162783`*^9, 3.7047864687607813`*^9, 
   3.704893949398363*^9, 3.7048949042905493`*^9, 3.7049494637990165`*^9, 
   3.7049785587396417`*^9, 3.7049823988416133`*^9, 3.7049870976082*^9, 
   3.70670373506111*^9, 3.7081734765298862`*^9, 3.708185428137435*^9, {
   3.7097934384124556`*^9, 3.7097934619649277`*^9}, 3.7098258345379076`*^9, {
   3.709825897469418*^9, 3.709825909294239*^9}, 3.730550885180252*^9, 
   3.7306278248975816`*^9, 3.7306278728109765`*^9, 3.7306279648371716`*^9, 
   3.730629434621716*^9, 3.73063584493997*^9, 3.732010074576682*^9, 
   3.734073076531026*^9, 3.7365891830574245`*^9, 3.736589564839527*^9, 
   3.736589687149083*^9, 3.7368259260494003`*^9, 3.7368289988930655`*^9, 
   3.7368291758956127`*^9, 3.745649718088578*^9, {3.7456498370319595`*^9, 
   3.745649843692093*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV4", "Subsubsection",
 CellChangeTimes->{{3.7021334680800133`*^9, 3.7021334705760183`*^9}, 
   3.709825981741766*^9, {3.7340730958754263`*^9, 3.734073111977848*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]XYZNV4", " ", "=", " ", 
   RowBox[{"KNV4passive", ".", "\[Sigma]XYZ", ".", 
    RowBox[{"Transpose", "[", "KNV4passive", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV4", "=", 
   RowBox[{
    RowBox[{"b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV4", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV4", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV4", "=", 
   RowBox[{
    RowBox[{"a1", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"2", "*", "a2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV4", "=", 
   RowBox[{
    RowBox[{"d", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV4", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"e", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"\[Sigma]XYZNV4", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NyNV4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "d", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "e", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XYZNV4", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "\[Sigma]XYZNV4", "]"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"{", 
   RowBox[{
   "MxNV4", ",", "MyNV4", ",", "MzNV4", ",", " ", "NxNV4", ",", " ", 
    "NyNV4"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7021335110112886`*^9, 3.702133535799732*^9}, {
  3.709825921821061*^9, 3.7098259620857315`*^9}, {3.7305509044762626`*^9, 
  3.7305509477146688`*^9}, {3.7306280448018723`*^9, 3.730628047731902*^9}, {
  3.736589692610196*^9, 3.736589696920282*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\[Sigma]XX", 
      RowBox[{"-", "\[Sigma]XY"}], 
      RowBox[{"-", "\[Sigma]XZ"}]},
     {
      RowBox[{"-", "\[Sigma]YX"}], "\[Sigma]YY", "\[Sigma]YZ"},
     {
      RowBox[{"-", "\[Sigma]ZX"}], "\[Sigma]ZY", "\[Sigma]ZZ"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7021335422737436`*^9, 3.7022760650162783`*^9, 3.7047864687807817`*^9, 
   3.7048939494139633`*^9, 3.7048949043061495`*^9, 3.7049494638100166`*^9, 
   3.7049785587552414`*^9, 3.7049823988572135`*^9, 3.7049870976238003`*^9, 
   3.706703735085111*^9, 3.7081734765454865`*^9, 3.708185428168635*^9, {
   3.709793438422456*^9, 3.709793461974928*^9}, 3.7098258345535073`*^9, 
   3.709825962569332*^9, 3.7305509495546875`*^9, 3.730627824927582*^9, 
   3.730627872900977*^9, 3.730628050482929*^9, 3.730629434641718*^9, 
   3.7306358449799705`*^9, 3.732010074606683*^9, 3.734073081413124*^9, 
   3.736589183887441*^9, 3.7365895656895437`*^9, 3.736589697770299*^9, 
   3.736825926079401*^9, 3.736828998923066*^9, 3.7368291759256134`*^9, 
   3.7456497189185953`*^9, {3.7456498389819984`*^9, 3.7456498437220936`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "\[Sigma]XY"}], "+", "\[Sigma]XZ", "-", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XX"}], "-", "\[Sigma]YY", "+", 
           RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"2", " ", "a2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "+", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
          ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "\[Sigma]XY"}], "+", "\[Sigma]XZ", "-", 
           "\[Sigma]YZ"}], ")"}]}], "+", 
        RowBox[{"d", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XX"}], "-", "\[Sigma]YY", "+", 
           RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", "e", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7021335422737436`*^9, 3.7022760650162783`*^9, 3.7047864687807817`*^9, 
   3.7048939494139633`*^9, 3.7048949043061495`*^9, 3.7049494638100166`*^9, 
   3.7049785587552414`*^9, 3.7049823988572135`*^9, 3.7049870976238003`*^9, 
   3.706703735085111*^9, 3.7081734765454865`*^9, 3.708185428168635*^9, {
   3.709793438422456*^9, 3.709793461974928*^9}, 3.7098258345535073`*^9, 
   3.709825962569332*^9, 3.7305509495546875`*^9, 3.730627824927582*^9, 
   3.730627872900977*^9, 3.730628050482929*^9, 3.730629434641718*^9, 
   3.7306358449799705`*^9, 3.732010074606683*^9, 3.734073081413124*^9, 
   3.736589183887441*^9, 3.7365895656895437`*^9, 3.736589697770299*^9, 
   3.736825926079401*^9, 3.736828998923066*^9, 3.7368291759256134`*^9, 
   3.7456497189185953`*^9, {3.7456498389819984`*^9, 3.745649843732094*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.3.3 Calculate stress-induced level shifts for all four NV orientations\
\>", "Subsection",
 CellChangeTimes->{{3.702133573676599*^9, 3.70213360300465*^9}, {
  3.734073359454851*^9, 3.7340733916464977`*^9}, {3.7456491859169226`*^9, 
  3.745649186036925*^9}}],

Cell[CellGroupData[{

Cell["\<\
Definition of stress tensors for stress along main directions (see section \
1); P=1GPa for simplicity\
\>", "Subsubsection",
 CellChangeTimes->{{3.7021337443308983`*^9, 3.702133757840522*^9}, {
  3.7340733958465815`*^9, 3.7340734171110077`*^9}, {3.7368291045291834`*^9, 
  3.7368291150313935`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fixedpar100", " ", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Sigma]XX", "\[Rule]", " ", "1"}], ",", 
      RowBox[{"\[Sigma]XY", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]XZ", "\[Rule]", " ", "0"}], ",", " ", 
      RowBox[{"\[Sigma]YX", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]YY", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]YZ", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZX", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZY", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZZ", "\[Rule]", " ", "0"}]}], "}"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fixedpar110", " ", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Sigma]XX", "\[Rule]", " ", "0.5"}], ",", 
      RowBox[{"\[Sigma]XY", "\[Rule]", " ", "0.5"}], ",", 
      RowBox[{"\[Sigma]XZ", "\[Rule]", " ", "0"}], ",", " ", 
      RowBox[{"\[Sigma]YX", "\[Rule]", " ", "0.5"}], ",", 
      RowBox[{"\[Sigma]YY", "\[Rule]", " ", "0.5"}], ",", 
      RowBox[{"\[Sigma]YZ", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZX", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZY", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZZ", "\[Rule]", " ", "0"}]}], "}"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fixedparm110", " ", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Sigma]XX", "\[Rule]", " ", "0.5"}], ",", 
      RowBox[{"\[Sigma]XY", "\[Rule]", " ", 
       RowBox[{"-", "0.5"}]}], ",", 
      RowBox[{"\[Sigma]XZ", "\[Rule]", " ", "0"}], ",", " ", 
      RowBox[{"\[Sigma]YX", "\[Rule]", " ", 
       RowBox[{"-", "0.5"}]}], ",", 
      RowBox[{"\[Sigma]YY", "\[Rule]", " ", "0.5"}], ",", 
      RowBox[{"\[Sigma]YZ", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZX", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZY", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"\[Sigma]ZZ", "\[Rule]", " ", "0"}]}], "}"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fixedpar111", " ", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Sigma]XX", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}], ",", 
      RowBox[{"\[Sigma]XY", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}], ",", 
      RowBox[{"\[Sigma]XZ", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}], ",", " ", 
      RowBox[{"\[Sigma]YX", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}], ",", 
      RowBox[{"\[Sigma]YY", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}], ",", 
      RowBox[{"\[Sigma]YZ", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}], ",", 
      RowBox[{"\[Sigma]ZX", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}], ",", 
      RowBox[{"\[Sigma]ZY", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}], ",", 
      RowBox[{"\[Sigma]ZZ", "\[Rule]", " ", 
       RowBox[{"1", "/", "3"}]}]}], "}"}]}], ";"}], " "}]}], "Input",
 CellChangeTimes->{{3.7021336056566553`*^9, 3.702133812674618*^9}, 
   3.702133850535885*^9, {3.702138146398283*^9, 3.702138149687471*^9}, {
   3.70213850808397*^9, 3.702138528524139*^9}, {3.7022879057945795`*^9, 
   3.7022879059973803`*^9}, {3.7067037675449677`*^9, 3.7067038061821775`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculate Mx, My and Mz of NV1-4 for stresses along [100], [110] and [111] \
\>", "Subsubsection",
 CellChangeTimes->{{3.7081736107225122`*^9, 3.7081736223265314`*^9}, {
  3.7098260582287006`*^9, 3.7098260873539515`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"M100", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "MxNV1", ",", "MyNV1", ",", "MzNV1", ",", " ", "NxNV1", ",", " ", 
         "NyNV1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV2", ",", " ", "MyNV2", ",", " ", "MzNV2", ",", " ", "NxNV2", ",",
          " ", "NyNV2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV3", ",", " ", "MyNV3", ",", " ", "MzNV3", ",", " ", "NxNV3", ",",
          " ", "NyNV3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV4", ",", " ", "MyNV4", ",", "MzNV4", ",", " ", "NxNV4", ",", " ",
          "NyNV4"}], "}"}]}], "}"}], "/.", "fixedpar100"}], "//", 
    "FullSimplify"}], "//", "TableForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"M110", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "MxNV1", ",", "MyNV1", ",", "MzNV1", ",", " ", "NxNV1", ",", " ", 
         "NyNV1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV2", ",", " ", "MyNV2", ",", " ", "MzNV2", ",", " ", "NxNV2", ",",
          " ", "NyNV2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV3", ",", " ", "MyNV3", ",", " ", "MzNV3", ",", " ", "NxNV3", ",",
          " ", "NyNV3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV4", ",", " ", "MyNV4", ",", "MzNV4", ",", " ", "NxNV4", ",", " ",
          "NyNV4"}], "}"}]}], "}"}], "/.", "fixedpar110"}], "//", 
    "FullSimplify"}], "//", "TableForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"M111", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "MxNV1", ",", "MyNV1", ",", "MzNV1", ",", " ", "NxNV1", ",", " ", 
         "NyNV1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV2", ",", " ", "MyNV2", ",", " ", "MzNV2", ",", " ", "NxNV2", ",",
          " ", "NyNV2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV3", ",", " ", "MyNV3", ",", " ", "MzNV3", ",", " ", "NxNV3", ",",
          " ", "NyNV3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "MxNV4", ",", " ", "MyNV4", ",", "MzNV4", ",", " ", "NxNV4", ",", " ",
          "NyNV4"}], "}"}]}], "}"}], "/.", "fixedpar111"}], "//", 
    "FullSimplify"}], "//", "TableForm"}]}]}], "Input",
 CellChangeTimes->{{3.7081736314993477`*^9, 3.708173698868664*^9}, {
   3.708173732274717*^9, 3.70817374740314*^9}, {3.708182211813526*^9, 
   3.708182313926103*^9}, {3.7305510210042906`*^9, 3.7305510267960825`*^9}, {
   3.730551058553653*^9, 3.730551130066945*^9}, 3.7340734669620085`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"-", "b"}], 
     RowBox[{
      SqrtBox["3"], " ", "b"}], "a1", 
     RowBox[{"-", "d"}], 
     RowBox[{
      SqrtBox["3"], " ", "d"}]},
    {
     RowBox[{"-", "b"}], 
     RowBox[{
      SqrtBox["3"], " ", "b"}], "a1", 
     RowBox[{"-", "d"}], 
     RowBox[{
      SqrtBox["3"], " ", "d"}]},
    {
     RowBox[{"-", "b"}], 
     RowBox[{
      SqrtBox["3"], " ", "b"}], "a1", 
     RowBox[{"-", "d"}], 
     RowBox[{
      SqrtBox["3"], " ", "d"}]},
    {
     RowBox[{"-", "b"}], 
     RowBox[{
      SqrtBox["3"], " ", "b"}], "a1", 
     RowBox[{"-", "d"}], 
     RowBox[{
      SqrtBox["3"], " ", "d"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7081736533525853`*^9, 3.708173699336665*^9}, 
   3.7081737477631407`*^9, 3.708182321648117*^9, 3.7081854281998353`*^9, {
   3.709793438482457*^9, 3.7097934619949284`*^9}, 3.7098258345847073`*^9, 
   3.7098261173216043`*^9, {3.7305510332252026`*^9, 3.730551082989622*^9}, 
   3.730551130944955*^9, 3.730611791954394*^9, 3.7306278254275866`*^9, 
   3.730627873410982*^9, 3.7306294350179977`*^9, 3.730707015333761*^9, 
   3.732010150619656*^9, 3.73407346854204*^9, 3.736589449681135*^9, 
   3.736589557299376*^9, 3.7365896424791803`*^9, 3.7365897405661674`*^9, 
   3.7368260038609567`*^9, 3.736829074520581*^9, 3.7368292518441334`*^9, 
   3.745649719598609*^9, 3.7456498437620945`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.`"}], " ", "b"}], "+", 
      RowBox[{"1.`", " ", "c"}]}], "0.`", 
     RowBox[{
      RowBox[{"1.`", " ", "a1"}], "+", 
      RowBox[{"1.`", " ", "a2"}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.`"}], " ", "d"}], "+", 
      RowBox[{"1.`", " ", "e"}]}], "0.`"},
    {
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.`"}], " ", "b"}], "+", 
      RowBox[{"1.`", " ", "c"}]}], "0.`", 
     RowBox[{
      RowBox[{"1.`", " ", "a1"}], "+", 
      RowBox[{"1.`", " ", "a2"}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.`"}], " ", "d"}], "+", 
      RowBox[{"1.`", " ", "e"}]}], "0.`"},
    {
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.`"}], " ", "b"}], "-", 
      RowBox[{"1.`", " ", "c"}]}], "0.`", 
     RowBox[{
      RowBox[{"1.`", " ", "a1"}], "-", 
      RowBox[{"1.`", " ", "a2"}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.`"}], " ", "d"}], "-", 
      RowBox[{"1.`", " ", "e"}]}], "0.`"},
    {
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.`"}], " ", "b"}], "-", 
      RowBox[{"1.`", " ", "c"}]}], "0.`", 
     RowBox[{
      RowBox[{"1.`", " ", "a1"}], "-", 
      RowBox[{"1.`", " ", "a2"}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.`"}], " ", "d"}], "-", 
      RowBox[{"1.`", " ", "e"}]}], "0.`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7081736533525853`*^9, 3.708173699336665*^9}, 
   3.7081737477631407`*^9, 3.708182321648117*^9, 3.7081854281998353`*^9, {
   3.709793438482457*^9, 3.7097934619949284`*^9}, 3.7098258345847073`*^9, 
   3.7098261173216043`*^9, {3.7305510332252026`*^9, 3.730551082989622*^9}, 
   3.730551130944955*^9, 3.730611791954394*^9, 3.7306278254275866`*^9, 
   3.730627873410982*^9, 3.7306294350179977`*^9, 3.730707015333761*^9, 
   3.732010150619656*^9, 3.73407346854204*^9, 3.736589449681135*^9, 
   3.736589557299376*^9, 3.7365896424791803`*^9, 3.7365897405661674`*^9, 
   3.7368260038609567`*^9, 3.736829074520581*^9, 3.7368292518441334`*^9, 
   3.745649719598609*^9, 3.7456498437620945`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"0", "0", 
     RowBox[{"a1", "+", 
      RowBox[{"2", " ", "a2"}]}], "0", "0"},
    {
     FractionBox[
      RowBox[{"4", " ", "c"}], "3"], "0", 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}], 
     FractionBox[
      RowBox[{"4", " ", "e"}], "3"], "0"},
    {
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "c"}], "3"]}], 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "c"}], 
       SqrtBox["3"]]}], 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}], 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "e"}], "3"]}], 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "e"}], 
       SqrtBox["3"]]}]},
    {
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "c"}], "3"]}], 
     FractionBox[
      RowBox[{"2", " ", "c"}], 
      SqrtBox["3"]], 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}], 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "e"}], "3"]}], 
     FractionBox[
      RowBox[{"2", " ", "e"}], 
      SqrtBox["3"]]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7081736533525853`*^9, 3.708173699336665*^9}, 
   3.7081737477631407`*^9, 3.708182321648117*^9, 3.7081854281998353`*^9, {
   3.709793438482457*^9, 3.7097934619949284`*^9}, 3.7098258345847073`*^9, 
   3.7098261173216043`*^9, {3.7305510332252026`*^9, 3.730551082989622*^9}, 
   3.730551130944955*^9, 3.730611791954394*^9, 3.7306278254275866`*^9, 
   3.730627873410982*^9, 3.7306294350179977`*^9, 3.730707015333761*^9, 
   3.732010150619656*^9, 3.73407346854204*^9, 3.736589449681135*^9, 
   3.736589557299376*^9, 3.7365896424791803`*^9, 3.7365897405661674`*^9, 
   3.7368260038609567`*^9, 3.736829074520581*^9, 3.7368292518441334`*^9, 
   3.745649719598609*^9, 3.7456498437720947`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculate level shifts for Bz=0: \\Delta_\\pm/h = (E_|\\pm\\rangle - \
E_|0\\rangle)/h = Mz \\pm Sqrt[Mx^2 + My^2] of NV1-4 for stresses along \
[100], [110] and [111] \
\>", "Subsubsection",
 CellChangeTimes->{{3.7021338619863048`*^9, 3.702133872360323*^9}, {
  3.7021379757366495`*^9, 3.7021379836458635`*^9}, {3.709826216834179*^9, 
  3.709826252636242*^9}, {3.730706927865614*^9, 3.7307069915142035`*^9}, {
  3.734073477953228*^9, 3.734073491084491*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"comp100", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"MxNV1", "^", "2"}], "+", " ", 
           RowBox[{"MyNV1", "^", "2"}]}], "]"}], ",", " ", "MzNV1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"MxNV2", "^", "2"}], "+", " ", 
           RowBox[{"MyNV2", "^", "2"}]}], "]"}], ",", " ", "MzNV2"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"MxNV3", "^", "2"}], "+", " ", 
           RowBox[{"MyNV3", "^", "2"}]}], "]"}], ",", " ", "MzNV3"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"MxNV4", "^", "2"}], "+", " ", 
           RowBox[{"MyNV4", "^", "2"}]}], "]"}], ",", " ", "MzNV4"}], "}"}]}],
       "}"}], "/.", "fixedpar100"}], "//", "FullSimplify"}], "//", 
   "TableForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"comp110", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"MxNV1", "^", "2"}], "+", " ", 
          RowBox[{"MyNV1", "^", "2"}]}], "]"}], ",", " ", "MzNV1"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"MxNV2", "^", "2"}], "+", " ", 
          RowBox[{"MyNV2", "^", "2"}]}], "]"}], ",", " ", "MzNV2"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"MxNV3", "^", "2"}], "+", " ", 
          RowBox[{"MyNV3", "^", "2"}]}], "]"}], ",", " ", "MzNV3"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"MxNV4", "^", "2"}], "+", " ", 
          RowBox[{"MyNV4", "^", "2"}]}], "]"}], ",", " ", "MzNV4"}], "}"}]}], 
     "}"}], "/.", "fixedpar110"}], "//", 
   "TableForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"comp111", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"MxNV1", "^", "2"}], "+", " ", 
           RowBox[{"MyNV1", "^", "2"}]}], "]"}], ",", " ", "MzNV1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"MxNV2", "^", "2"}], "+", " ", 
           RowBox[{"MyNV2", "^", "2"}]}], "]"}], ",", " ", "MzNV2"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"MxNV3", "^", "2"}], "+", " ", 
           RowBox[{"MyNV3", "^", "2"}]}], "]"}], ",", " ", "MzNV3"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"MxNV4", "^", "2"}], "+", " ", 
           RowBox[{"MyNV4", "^", "2"}]}], "]"}], ",", " ", "MzNV4"}], "}"}]}],
       "}"}], "/.", "fixedpar111"}], "//", "FullSimplify"}], "//", 
   "TableForm"}]}]}], "Input",
 CellChangeTimes->{{3.7021338978507676`*^9, 3.7021340185949793`*^9}, {
  3.7021385350515127`*^9, 3.702138540707836*^9}, {3.702282537310031*^9, 
  3.702282612299362*^9}, {3.70670375341716*^9, 3.7067037614726205`*^9}, {
  3.708173595162885*^9, 3.7081735957556863`*^9}, {3.7342422805148153`*^9, 
  3.7342422808678317`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}], "a1"},
    {
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}], "a1"},
    {
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}], "a1"},
    {
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}], "a1"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.702133966880889*^9, 3.7021340192501807`*^9}, {
   3.7021385412448664`*^9, 3.702138547308213*^9}, 3.702276065063078*^9, {
   3.702282564251278*^9, 3.7022826130013638`*^9}, 3.704786468880782*^9, 
   3.704893949507563*^9, 3.704894904337349*^9, 3.7049494638650165`*^9, 
   3.7049785588488417`*^9, 3.7049823989664135`*^9, 3.7049870977174*^9, 
   3.7067037351611156`*^9, 3.706703811953508*^9, 3.7081734766234865`*^9, 
   3.7081735966760883`*^9, 3.708185428262235*^9, {3.7097934385424585`*^9, 
   3.709793462014929*^9}, 3.7098258346627073`*^9, 3.7306117960846214`*^9, 
   3.7306278272663894`*^9, 3.730627875126006*^9, 3.7306294350917535`*^9, 
   3.730707017995931*^9, 3.732010150669657*^9, 3.734073504639764*^9, 
   3.734242282037859*^9, 3.7365896443692183`*^9, 3.7365897513713894`*^9, 
   3.7368260039509583`*^9, 3.7368290745805817`*^9, 3.7368292518941345`*^9, 
   3.745649721928655*^9, 3.7456498438120956`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     SqrtBox[
      RowBox[{"0.`", "\[VeryThinSpace]", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1.`"}], " ", "b"}], "+", 
          RowBox[{"1.`", " ", "c"}]}], ")"}], "2"]}]], 
     RowBox[{
      RowBox[{"1.`", " ", "a1"}], "+", 
      RowBox[{"1.`", " ", "a2"}]}]},
    {
     SqrtBox[
      RowBox[{"0.`", "\[VeryThinSpace]", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1.`"}], " ", "b"}], "+", 
          RowBox[{"1.`", " ", "c"}]}], ")"}], "2"]}]], 
     RowBox[{
      RowBox[{"1.`", " ", "a1"}], "+", 
      RowBox[{"1.`", " ", "a2"}]}]},
    {
     SqrtBox[
      RowBox[{"0.`", "\[VeryThinSpace]", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1.`"}], " ", "b"}], "-", 
          RowBox[{"1.`", " ", "c"}]}], ")"}], "2"]}]], 
     RowBox[{
      RowBox[{"1.`", " ", "a1"}], "-", 
      RowBox[{"1.`", " ", "a2"}]}]},
    {
     SqrtBox[
      RowBox[{"0.`", "\[VeryThinSpace]", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1.`"}], " ", "b"}], "-", 
          RowBox[{"1.`", " ", "c"}]}], ")"}], "2"]}]], 
     RowBox[{
      RowBox[{"1.`", " ", "a1"}], "-", 
      RowBox[{"1.`", " ", "a2"}]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.702133966880889*^9, 3.7021340192501807`*^9}, {
   3.7021385412448664`*^9, 3.702138547308213*^9}, 3.702276065063078*^9, {
   3.702282564251278*^9, 3.7022826130013638`*^9}, 3.704786468880782*^9, 
   3.704893949507563*^9, 3.704894904337349*^9, 3.7049494638650165`*^9, 
   3.7049785588488417`*^9, 3.7049823989664135`*^9, 3.7049870977174*^9, 
   3.7067037351611156`*^9, 3.706703811953508*^9, 3.7081734766234865`*^9, 
   3.7081735966760883`*^9, 3.708185428262235*^9, {3.7097934385424585`*^9, 
   3.709793462014929*^9}, 3.7098258346627073`*^9, 3.7306117960846214`*^9, 
   3.7306278272663894`*^9, 3.730627875126006*^9, 3.7306294350917535`*^9, 
   3.730707017995931*^9, 3.732010150669657*^9, 3.734073504639764*^9, 
   3.734242282037859*^9, 3.7365896443692183`*^9, 3.7365897513713894`*^9, 
   3.7368260039509583`*^9, 3.7368290745805817`*^9, 3.7368292518941345`*^9, 
   3.745649721928655*^9, 3.745649843822096*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"0", 
     RowBox[{"a1", "+", 
      RowBox[{"2", " ", "a2"}]}]},
    {
     FractionBox[
      RowBox[{"4", " ", 
       SqrtBox[
        SuperscriptBox["c", "2"]]}], "3"], 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}]},
    {
     FractionBox[
      RowBox[{"4", " ", 
       SqrtBox[
        SuperscriptBox["c", "2"]]}], "3"], 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}]},
    {
     FractionBox[
      RowBox[{"4", " ", 
       SqrtBox[
        SuperscriptBox["c", "2"]]}], "3"], 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.702133966880889*^9, 3.7021340192501807`*^9}, {
   3.7021385412448664`*^9, 3.702138547308213*^9}, 3.702276065063078*^9, {
   3.702282564251278*^9, 3.7022826130013638`*^9}, 3.704786468880782*^9, 
   3.704893949507563*^9, 3.704894904337349*^9, 3.7049494638650165`*^9, 
   3.7049785588488417`*^9, 3.7049823989664135`*^9, 3.7049870977174*^9, 
   3.7067037351611156`*^9, 3.706703811953508*^9, 3.7081734766234865`*^9, 
   3.7081735966760883`*^9, 3.708185428262235*^9, {3.7097934385424585`*^9, 
   3.709793462014929*^9}, 3.7098258346627073`*^9, 3.7306117960846214`*^9, 
   3.7306278272663894`*^9, 3.730627875126006*^9, 3.7306294350917535`*^9, 
   3.730707017995931*^9, 3.732010150669657*^9, 3.734073504639764*^9, 
   3.734242282037859*^9, 3.7365896443692183`*^9, 3.7365897513713894`*^9, 
   3.7368260039509583`*^9, 3.7368290745805817`*^9, 3.7368292518941345`*^9, 
   3.745649721928655*^9, 3.745649843822096*^9}]
}, Open  ]],

Cell["\<\
We find that:

[100] : NV1 - 4 show identical reaction
[110] : NVs split into two families with identical reaction. NVA = NV1 and \
NV2. NVB = NV3 and NV4.
[111] : NV1 has a different reaction to stress than NV2 - 4\
\>", "Text",
 CellChangeTimes->{{3.7340734811632924`*^9, 3.7340734811632924`*^9}, {
  3.7340735134129395`*^9, 3.734073525762236*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.4 Strain - induced coupling amplitudes Mx, My, Mz, Nx and Ny for all four \
NV orientations NV1-4 
(with the strain tensor \[Epsilon]XYZ defined in crystal coordinates XYZ)\
\>", "Section",
 CellChangeTimes->{{3.732009820216498*^9, 3.7320098386008663`*^9}, {
  3.734073872737323*^9, 3.7340738863775954`*^9}, {3.7368291257816086`*^9, 
  3.7368291280816545`*^9}}],

Cell["\<\
To convert stress into strain, we rely on Hooke' s law, i.e. \[Sigma]=C*\
\[Epsilon]. The approach is rather simple:
1) Define stress tensor in Kelvin notation in order to write the stiffness \
tensor as a matrix of rank two.
2) Convert \[Sigma]XYZ into \[Epsilon]XYZ for NV1
3) Replace \[Sigma]XYZ in Mx,My,Mz,Nx,Ny with components from \[Epsilon]XYZ \
for NV1
4) Include NV orientations NV2-4 as in 2.3)

In Kelvin notation:
\[Sigma]XYZKelvin = {\[Sigma]1,\[Sigma]2,\[Sigma]3,\[Sigma]4,\[Sigma]5,\
\[Sigma]6} = {\[Sigma]XX,\[Sigma]YY,\[Sigma]ZZ,Sqrt(2)\[Sigma]YZ,Sqrt(2)\
\[Sigma]XZ,Sqrt(2)\[Sigma]XY};
\[Epsilon]XYZKelvin = {\[Epsilon]1,\[Epsilon]2,\[Epsilon]3,\[Epsilon]4,\
\[Epsilon]5,\[Epsilon]6} = {\[Epsilon]XX,\[Epsilon]YY, \[Epsilon]ZZ, Sqrt(2)\
\[Epsilon]YZ, Sqrt(2)\[Epsilon]XZ, Sqrt(2)\[Epsilon]XY}; 
CXYZKelvin = {{C11, C12, C12, 0, 0, 0},{C12, C11, C12, 0, 0, 0},{C12, C12, \
C11, 0, 0, 0},{0, 0, 0, 2 C44, 0, 0},{0, 0, 0, 0, 2C44, 0},{0, 0, 0, 0, 0, \
2C44}}\
\>", "Text",
 CellChangeTimes->{{3.7320098472710395`*^9, 3.732009994826995*^9}, {
  3.7320103842557416`*^9, 3.73201039113588*^9}, {3.732010602907203*^9, 
  3.7320106073202915`*^9}, {3.732013237128878*^9, 3.7320132509572935`*^9}, {
  3.7320134749260674`*^9, 3.732013605195738*^9}, {3.732014400170335*^9, 
  3.7320144019403706`*^9}, {3.7331294767794027`*^9, 3.733129607587021*^9}, {
  3.7365890302792797`*^9, 3.7365891253291926`*^9}, {3.736825056748559*^9, 
  3.736825082559075*^9}, {3.7368291347267876`*^9, 3.7368291352467985`*^9}, {
  3.7456492491621885`*^9, 3.7456492548623023`*^9}}],

Cell[CellGroupData[{

Cell["\<\
2.4.1 Define stiffness tensor and strain/stress Kelvin vectors\
\>", "Subsection",
 CellChangeTimes->{{3.732010349162039*^9, 3.73201035619718*^9}, {
   3.7320105884469137`*^9, 3.7320105941170273`*^9}, {3.73312961105709*^9, 
   3.7331296117771044`*^9}, {3.734073916849209*^9, 3.7340739208712893`*^9}, {
   3.734074010725189*^9, 3.7340740108351912`*^9}, 3.736825086019144*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CXYZKelvin", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"C11", ",", "C12", ",", "C12", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"C12", ",", "C11", ",", "C12", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"C12", ",", "C12", ",", "C11", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"2", "C44"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"2", "C44"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"2", "C44"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]XYZKelvin", "=", " ", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]XX", ",", "\[Epsilon]YY", ",", "\[Epsilon]ZZ", ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Epsilon]YZ"}], ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Epsilon]XZ"}], ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Epsilon]XY"}]}], "}"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]XYZKelvin", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]XX", ",", "\[Sigma]YY", ",", "\[Sigma]ZZ", ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "\[Sigma]YZ"}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "\[Sigma]XZ"}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "\[Sigma]XY"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.732010597147088*^9, 3.7320105979971046`*^9}, {
  3.7320106702035513`*^9, 3.7320106826888013`*^9}, {3.7320154526555433`*^9, 
  3.732015496035411*^9}, {3.7320184461897154`*^9, 3.7320184638020687`*^9}, {
  3.733129618629242*^9, 3.733129638422638*^9}, {3.734074314372411*^9, 
  3.734074314602415*^9}, {3.7340743566033115`*^9, 3.734074357073321*^9}, {
  3.7340745949591856`*^9, 3.734074611687525*^9}, {3.7342406986050415`*^9, 
  3.7342407047671676`*^9}, {3.7368250947413187`*^9, 3.7368250982813897`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4.2 Express coupling amplitudes in terms of \[Epsilon]XYZ", \
"Subsection",
 CellChangeTimes->{{3.7320103610472765`*^9, 3.732010370024457*^9}, {
  3.7340744472081814`*^9, 3.734074473908718*^9}}],

Cell["\<\
Note : The \[Epsilon]IJ in the following expressions are defined in the \
reference frame of NV1.\
\>", "Text",
 CellChangeTimes->{{3.734242396260292*^9, 3.7342424070345097`*^9}}],

Cell[CellGroupData[{

Cell["NV1", "Subsubsection",
 CellChangeTimes->{{3.734074467348587*^9, 3.73407446999864*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]XYZKelvinNV1", " ", "=", " ", 
   RowBox[{
    RowBox[{"CXYZKelvin", ".", "\[Epsilon]XYZKelvin"}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]XYZNV1calc", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", 
       RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", 
       RowBox[{"\[Sigma]XYZKelvinNV1", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV1strain", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV1strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV1strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"2", "*", "a2", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV1strain", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"e", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NyNV1strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "d", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "e", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"{", 
   RowBox[{
   "MxNV1strain", ",", "MyNV1strain", ",", "MzNV1strain", ",", "NxNV1strain", 
    " ", ",", "NyNV1strain"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7320103733555236`*^9, 3.7320104083972254`*^9}, {
   3.732010691428976*^9, 3.7320106993011336`*^9}, {3.7320107815317793`*^9, 
   3.7320108431820164`*^9}, {3.7320108966570873`*^9, 
   3.7320109375619073`*^9}, {3.7320136361133566`*^9, 
   3.7320137373128347`*^9}, {3.7320137873698378`*^9, 
   3.7320137874998407`*^9}, {3.7320154564666195`*^9, 3.732015471082912*^9}, {
   3.732015505160594*^9, 3.732015550578503*^9}, {3.7320159674270735`*^9, 
   3.7320160019387646`*^9}, {3.732016111664961*^9, 3.7320161138460045`*^9}, {
   3.7331296580680313`*^9, 3.7331296731383324`*^9}, {3.7340739379226303`*^9, 
   3.7340739791065006`*^9}, {3.7340741942789125`*^9, 3.734074231391695*^9}, {
   3.7340743601614337`*^9, 3.734074422846694*^9}, {3.7365891410065765`*^9, 
   3.7365891463766837`*^9}, 3.736593820941145*^9, {3.7368251042915096`*^9, 
   3.7368251242979107`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"2", " ", "c", " ", "C44", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Epsilon]XY"}], "-", "\[Epsilon]XZ", "-", 
           "\[Epsilon]YZ"}], ")"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "-", 
           RowBox[{"2", " ", "\[Epsilon]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XX", "-", "\[Epsilon]YY"}], ")"}]}], "+", 
          RowBox[{"2", " ", "c", " ", "C44", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Epsilon]XZ"}], "+", "\[Epsilon]YZ"}], ")"}]}]}], 
         ")"}]}]},
      {
       RowBox[{
        RowBox[{"4", " ", "a2", " ", "C44", " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XY", "+", "\[Epsilon]XZ", "+", "\[Epsilon]YZ"}], 
          ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"C11", "+", 
           RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "+", "\[Epsilon]ZZ"}], 
          ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"2", " ", "C44", " ", "e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Epsilon]XY"}], "-", "\[Epsilon]XZ", "-", 
           "\[Epsilon]YZ"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "-", 
           RowBox[{"2", " ", "\[Epsilon]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}], " ", "d", " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XX", "-", "\[Epsilon]YY"}], ")"}]}], "+", 
          RowBox[{"2", " ", "C44", " ", "e", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Epsilon]XZ"}], "+", "\[Epsilon]YZ"}], ")"}]}]}], 
         ")"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7320161701771345`*^9, {3.734073981897557*^9, 3.7340739909687386`*^9}, 
   3.734074201434094*^9, 3.7340742337517424`*^9, 3.7340744264667664`*^9, 
   3.7365892297923737`*^9, 3.7368260042009635`*^9, 3.736829074805587*^9, 
   3.7368292521341395`*^9, 3.745649724210701*^9, 3.745649852708274*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV2", "Subsubsection",
 CellChangeTimes->{{3.734240818848657*^9, 3.7342408232427483`*^9}}],

Cell["\<\
Approach :
We take \[Sigma]XYZ obtained from \[Epsilon]XYZ of the NV1 reference frame \
(the one we used for NV1) and replace the \[Sigma]IJ in Mx, y, z for NV2 - 4. \
Or, we always start from Mx, y, z of NV1 and obtain \[Epsilon]XYZ for NV1 - 4 \
from \[Sigma]XYZ. In both approaches, the final results depends on the \
\[Epsilon]IJ defined in the NV1 reference frame.\
\>", "Text",
 CellChangeTimes->{{3.734241367605414*^9, 3.7342414107693834`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV2strain", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV2strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV2strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"2", "*", "a2", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV2strain", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"e", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NyNV2strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "d", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "e", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"{", 
   RowBox[{
   "MxNV2strain", ",", "MyNV2strain", ",", "MzNV2strain", ",", "NxNV2strain", 
    " ", ",", "NyNV2strain"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7342411042256246`*^9, 3.734241236146701*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"2", " ", "c", " ", "C44", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Epsilon]XY"}], "+", "\[Epsilon]XZ", "+", 
           "\[Epsilon]YZ"}], ")"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "-", 
           RowBox[{"2", " ", "\[Epsilon]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XX", "-", "\[Epsilon]YY"}], ")"}]}], "+", 
          RowBox[{"2", " ", "c", " ", "C44", " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XZ", "-", "\[Epsilon]YZ"}], ")"}]}]}], ")"}]}]},
      {
       RowBox[{
        RowBox[{"4", " ", "a2", " ", "C44", " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XY", "-", "\[Epsilon]XZ", "-", "\[Epsilon]YZ"}], 
          ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"C11", "+", 
           RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "+", "\[Epsilon]ZZ"}], 
          ")"}]}]}]},
      {
       RowBox[{
        RowBox[{"2", " ", "C44", " ", "e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Epsilon]XY"}], "+", "\[Epsilon]XZ", "+", 
           "\[Epsilon]YZ"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "-", 
           RowBox[{"2", " ", "\[Epsilon]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}], " ", "d", " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XX", "-", "\[Epsilon]YY"}], ")"}]}], "+", 
          RowBox[{"2", " ", "C44", " ", "e", " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XZ", "-", "\[Epsilon]YZ"}], ")"}]}]}], ")"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.734241237736733*^9, 3.7365892737903457`*^9, 
  3.7368260043509665`*^9, 3.7368290749965906`*^9, 3.7368292522941427`*^9, 
  3.745649724350704*^9, 3.7456498528482766`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV3", "Subsubsection",
 CellChangeTimes->{{3.734241885954057*^9, 3.7342418883511095`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV3strain", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV3strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV3strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"2", "*", "a2", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"{", 
   RowBox[{"MxNV3strain", ",", "MyNV3strain", ",", "MzNV3strain"}], "}"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.734241895387273*^9, 3.734241975449074*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "c", " ", "C44", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Epsilon]XY"}], "+", "\[Epsilon]XZ", "-", 
           "\[Epsilon]YZ"}], ")"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "-", 
           RowBox[{"2", " ", "\[Epsilon]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XX", "-", "\[Epsilon]YY"}], ")"}]}], "-", 
          RowBox[{"2", " ", "c", " ", "C44", " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XZ", "+", "\[Epsilon]YZ"}], ")"}]}]}], ")"}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "a2", " ", "C44", " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XY", "-", "\[Epsilon]XZ", "+", "\[Epsilon]YZ"}], 
          ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"C11", "+", 
           RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "+", "\[Epsilon]ZZ"}], 
          ")"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7342419776491175`*^9, 3.7365892793304567`*^9, 
  3.7368260044309683`*^9, 3.7368290750765924`*^9, 3.7368292523741446`*^9, 
  3.745649724410705*^9, 3.7456498529182777`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV4", "Subsubsection",
 CellChangeTimes->{{3.734242103157879*^9, 3.7342421064779453`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV4strain", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], "*", 
         RowBox[{"\[Sigma]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV4strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV4strain", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"2", "*", "a2", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", 
  RowBox[{"{", 
   RowBox[{"MxNV4strain", ",", "MyNV4strain", ",", "MzNV4strain"}], "}"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.734242111668049*^9, 3.734242164009224*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "c", " ", "C44", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Epsilon]XY"}], "-", "\[Epsilon]XZ", "+", 
           "\[Epsilon]YZ"}], ")"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "-", 
           RowBox[{"2", " ", "\[Epsilon]ZZ"}]}], ")"}]}]}]},
      {
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XX", "-", "\[Epsilon]YY"}], ")"}]}], "+", 
          RowBox[{"2", " ", "c", " ", "C44", " ", 
           RowBox[{"(", 
            RowBox[{"\[Epsilon]XZ", "+", "\[Epsilon]YZ"}], ")"}]}]}], ")"}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "a2", " ", "C44", " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XY", "+", "\[Epsilon]XZ", "-", "\[Epsilon]YZ"}], 
          ")"}]}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{"C11", "+", 
           RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]XX", "+", "\[Epsilon]YY", "+", "\[Epsilon]ZZ"}], 
          ")"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.73424216828232*^9, 3.736589282210514*^9, 
  3.73682600452097*^9, 3.736829075146594*^9, 3.7368292524441457`*^9, 
  3.7456497244607058`*^9, 3.745649852978279*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4.3 Calculate strain-induced level shifts", "Subsection",
 CellChangeTimes->{{3.7320183067909203`*^9, 3.7320183213592124`*^9}, {
  3.7320183765143175`*^9, 3.732018404676883*^9}, {3.7340744780708017`*^9, 
  3.7340744937521152`*^9}}],

Cell["\<\
To compare, we derive \[Epsilon]XYZNV1 from \[Sigma]XYZNV1 = \[Sigma]XYZ and \
replace all \[Epsilon]IJ in 2.4.2. The subsequently calculated level shifts \
should be similar to the ones from 2.3.4. Note that we introduced new \
coupling constants 
\ta1strain = a1*(C11+2 C12)
\ta2strain = 2*a2*C44
\tbstrain = b*(C11 - C12)
\tcstrain = c*C44.
These constants are obtained from the M_i in 2.4.2 by comparison. \t\
\>", "Text",
 CellChangeTimes->{{3.734074496172164*^9, 3.734074577769802*^9}, {
   3.734074732945004*^9, 3.734074887972124*^9}, {3.734241440364151*^9, 
   3.7342414701117954`*^9}, {3.7365898751010265`*^9, 
   3.7365899290771155`*^9}, {3.7366545711749105`*^9, 
   3.7366545751613092`*^9}, {3.7368291460330143`*^9, 3.7368291468830314`*^9}, 
   3.7456493033322725`*^9}],

Cell[CellGroupData[{

Cell["NV1", "Subsubsection",
 CellChangeTimes->{{3.732018777382472*^9, 3.7320187893927126`*^9}, {
  3.7340745825818987`*^9, 3.7340745829419055`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", "\[Sigma]XYZKelvin"}], 
    "//", "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]XYZNV1calc", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
       RowBox[{
        RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
       RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", "2"}], ",", 
       RowBox[{
        RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", "2"}], ",", 
       RowBox[{"\[Epsilon]XYZNV1Kelvincalc", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV1straincalc", " ", "=", " ", 
   RowBox[{
    RowBox[{"cstrain", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"\[Epsilon]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}], "-", 
    RowBox[{"bstrain", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"\[Epsilon]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV1straincalc", "=", 
   RowBox[{
    SqrtBox["3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bstrain", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
      RowBox[{"cstrain", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"\[Epsilon]XYZNV1calc", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "+", 
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV1straincalc", "=", 
   RowBox[{
    RowBox[{"2", " ", "a2strain", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"a1strain", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"comp100strain", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"MxNV1straincalc", "^", "2"}], "+", " ", 
          RowBox[{"MyNV1straincalc", "^", "2"}]}], "]"}], ",", " ", 
        "MzNV1straincalc"}], "}"}], "}"}], "/.", "fixedpar100"}], "//", 
    "FullSimplify"}], "//", "TableForm"}]}]}], "Input",
 CellChangeTimes->{{3.7320184195151806`*^9, 3.7320184293163767`*^9}, {
   3.7320184822694383`*^9, 3.73201857910542*^9}, {3.732018646529771*^9, 
   3.7320186611520634`*^9}, {3.732018770572336*^9, 3.7320187723223705`*^9}, {
   3.7340746256078033`*^9, 3.734074649786334*^9}, {3.734074688423109*^9, 
   3.734074707985503*^9}, 3.734075025368881*^9, {3.7340753176378465`*^9, 
   3.73407533078811*^9}, 3.736589294769767*^9, {3.73658935587508*^9, 
   3.736589361610197*^9}, {3.7365938260052853`*^9, 3.7365938286753387`*^9}, {
   3.736825166440753*^9, 3.7368251938453026`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"2", " ", 
      SqrtBox[
       FractionBox[
        SuperscriptBox["bstrain", "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], "2"]]]}], 
     FractionBox["a1strain", 
      RowBox[{"C11", "+", 
       RowBox[{"2", " ", "C12"}]}]]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7340750263789015`*^9, 3.7340753466304264`*^9, 
  3.736589364350252*^9, 3.736589507122297*^9, 3.736589934576227*^9, 
  3.736826004630972*^9, 3.7368290752465963`*^9, 3.7368292525541477`*^9, 
  3.7456497245707083`*^9, 3.7456498530782814`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV2", "Subsubsection",
 CellChangeTimes->{{3.734240424656352*^9, 3.734240427136402*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV2straincalc", " ", "=", " ", 
   RowBox[{
    RowBox[{"cstrain", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"\[Epsilon]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}], "-", 
    RowBox[{"bstrain", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"\[Epsilon]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV2straincalc", "=", 
   RowBox[{
    SqrtBox["3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bstrain", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
      RowBox[{"cstrain", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", 
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV2straincalc", "=", 
   RowBox[{
    RowBox[{"2", " ", "a2strain", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"a1strain", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7342413352337327`*^9, 3.7342413554741554`*^9}, {
   3.734241488936229*^9, 3.734241546462525*^9}, 3.7342418622394514`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV3", "Subsubsection",
 CellChangeTimes->{{3.7342419867323413`*^9, 3.734241989194393*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV3straincalc", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "cstrain"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"\[Epsilon]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}], "-", 
    RowBox[{"bstrain", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"\[Epsilon]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV3straincalc", "=", 
   RowBox[{
    SqrtBox["3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bstrain", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "-", 
      RowBox[{"cstrain", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV3straincalc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "a2strain", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"a1strain", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.734241994550515*^9, 3.73424204327164*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV4", "Subsubsection",
 CellChangeTimes->{{3.734242178871642*^9, 3.734242181031685*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV4straincalc", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "cstrain"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"\[Epsilon]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "-", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}], "-", 
    RowBox[{"bstrain", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"\[Epsilon]XYZNV1calc", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV4straincalc", "=", 
   RowBox[{
    SqrtBox["3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bstrain", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}], "+", 
      RowBox[{"cstrain", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}], "+", 
         RowBox[{"\[Epsilon]XYZNV1calc", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV4straincalc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "a2strain", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}], "-", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"a1strain", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "+", 
       RowBox[{"\[Epsilon]XYZNV1calc", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}]}], ")"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7342421834017324`*^9, 3.734242232608796*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
By replacing strain coupling constants, we find the same results as in 2.3.4. \
- signs of b and c are changed though, presumeably due to the ()^2\
\>", "Subsubsection",
 CellChangeTimes->{{3.7322460740691767`*^9, 3.732246139962509*^9}, {
  3.7340749042634506`*^9, 3.7340749184777365`*^9}, {3.734075042721268*^9, 
  3.734075053747489*^9}, {3.734242347338295*^9, 3.7342423585665216`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"comp100strain", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV1straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV1straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV1straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV2straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV2straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV2straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV3straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV3straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV3straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV4straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV4straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV4straincalc"}], "}"}]}], "}"}], "/.", "fixedpar100"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a1strain", "\[Rule]", 
        RowBox[{"a1", "*", 
         RowBox[{"(", 
          RowBox[{"C11", "+", 
           RowBox[{"2", " ", "C12"}]}], ")"}]}]}], ",", " ", 
       RowBox[{"a2strain", "\[Rule]", " ", 
        RowBox[{"2", "*", "a2", "*", "C44"}]}], ",", " ", 
       RowBox[{"bstrain", "\[Rule]", 
        RowBox[{"b", "*", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}]}], ",", " ", 
       RowBox[{"cstrain", "\[Rule]", 
        RowBox[{"c", "*", "C44"}]}]}], "}"}]}], "//", "FullSimplify"}], "//", 
   "TableForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"comp110strain", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV1straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV1straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV1straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV2straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV2straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV2straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV3straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV3straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV3straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV4straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV4straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV4straincalc"}], "}"}]}], "}"}], "/.", "fixedpar110"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a1strain", "\[Rule]", 
        RowBox[{"a1", "*", 
         RowBox[{"(", 
          RowBox[{"C11", "+", 
           RowBox[{"2", " ", "C12"}]}], ")"}]}]}], ",", " ", 
       RowBox[{"a2strain", "\[Rule]", " ", 
        RowBox[{"2", "*", "a2", "*", "C44"}]}], ",", " ", 
       RowBox[{"bstrain", "\[Rule]", 
        RowBox[{"b", "*", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}]}], ",", " ", 
       RowBox[{"cstrain", "\[Rule]", 
        RowBox[{"c", "*", "C44"}]}]}], "}"}]}], "//", "FullSimplify"}], "//", 
   "TableForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"comp111strain", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV1straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV1straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV1straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV2straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV2straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV2straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV3straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV3straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV3straincalc"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV4straincalc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV4straincalc", "^", "2"}]}], "]"}], ",", " ", 
          "MzNV4straincalc"}], "}"}]}], "}"}], "/.", "fixedpar111"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a1strain", "\[Rule]", 
        RowBox[{"a1", "*", 
         RowBox[{"(", 
          RowBox[{"C11", "+", 
           RowBox[{"2", " ", "C12"}]}], ")"}]}]}], ",", " ", 
       RowBox[{"a2strain", "\[Rule]", " ", 
        RowBox[{"2", "*", "a2", "*", "C44"}]}], ",", " ", 
       RowBox[{"bstrain", "\[Rule]", 
        RowBox[{"b", "*", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}]}], ",", " ", 
       RowBox[{"cstrain", "\[Rule]", 
        RowBox[{"c", "*", "C44"}]}]}], "}"}]}], "//", "FullSimplify"}], "//", 
   "TableForm"}]}]}], "Input",
 CellChangeTimes->{{3.7340749284579363`*^9, 3.7340750158986917`*^9}, {
  3.7340750681677837`*^9, 3.734075081640109*^9}, {3.734075129934078*^9, 
  3.734075142595331*^9}, {3.7340752113637104`*^9, 3.7340752205908966`*^9}, {
  3.734241556512746*^9, 3.7342415756161346`*^9}, {3.7342420591399603`*^9, 
  3.7342420920346527`*^9}, {3.7365899440404186`*^9, 3.736589957300685*^9}, {
  3.736829154913192*^9, 3.7368291612433186`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}], "a1"},
    {
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}], "a1"},
    {
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}], "a1"},
    {
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox["b", "2"]]}], "a1"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.734075016558705*^9, 3.7340750310889955`*^9}, 
   3.734075082600128*^9, 3.734075135285185*^9, 3.73407523026309*^9, 
   3.7340752610067077`*^9, 3.7340753490145135`*^9, 3.734241577676176*^9, 
   3.734241867017559*^9, 3.7342422543122873`*^9, 3.7365895391300087`*^9, {
   3.7365899472484837`*^9, 3.7365899584207077`*^9}, 3.7368260047409744`*^9, 
   3.7368290752965965`*^9, 3.736829252604149*^9, 3.7456497246307096`*^9, 
   3.7456498531182823`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"1.`", " ", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.`", " ", "b"}], "-", 
          RowBox[{"0.5`", " ", "c"}]}], ")"}], "2"]]}], 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.`", " ", "a1"}], "+", 
      RowBox[{"1.`", " ", "a2"}]}]},
    {
     RowBox[{"1.`", " ", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.`", " ", "b"}], "-", 
          RowBox[{"0.5`", " ", "c"}]}], ")"}], "2"]]}], 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.`", " ", "a1"}], "+", 
      RowBox[{"1.`", " ", "a2"}]}]},
    {
     RowBox[{"1.`", " ", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.`", " ", "b"}], "+", 
          RowBox[{"0.5`", " ", "c"}]}], ")"}], "2"]]}], 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.`", " ", "a1"}], "-", 
      RowBox[{"1.`", " ", "a2"}]}]},
    {
     RowBox[{"1.`", " ", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.`", " ", "b"}], "+", 
          RowBox[{"0.5`", " ", "c"}]}], ")"}], "2"]]}], 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.`", " ", "a1"}], "-", 
      RowBox[{"1.`", " ", "a2"}]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.734075016558705*^9, 3.7340750310889955`*^9}, 
   3.734075082600128*^9, 3.734075135285185*^9, 3.73407523026309*^9, 
   3.7340752610067077`*^9, 3.7340753490145135`*^9, 3.734241577676176*^9, 
   3.734241867017559*^9, 3.7342422543122873`*^9, 3.7365895391300087`*^9, {
   3.7365899472484837`*^9, 3.7365899584207077`*^9}, 3.7368260047409744`*^9, 
   3.7368290752965965`*^9, 3.736829252604149*^9, 3.7456497246307096`*^9, 
   3.7456498531482825`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"0", 
     RowBox[{"a1", "+", 
      RowBox[{"2", " ", "a2"}]}]},
    {
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox[
        SuperscriptBox["c", "2"]]}], "3"], 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}]},
    {
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox[
        SuperscriptBox["c", "2"]]}], "3"], 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}]},
    {
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox[
        SuperscriptBox["c", "2"]]}], "3"], 
     RowBox[{"a1", "-", 
      FractionBox[
       RowBox[{"2", " ", "a2"}], "3"]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.734075016558705*^9, 3.7340750310889955`*^9}, 
   3.734075082600128*^9, 3.734075135285185*^9, 3.73407523026309*^9, 
   3.7340752610067077`*^9, 3.7340753490145135`*^9, 3.734241577676176*^9, 
   3.734241867017559*^9, 3.7342422543122873`*^9, 3.7365895391300087`*^9, {
   3.7365899472484837`*^9, 3.7365899584207077`*^9}, 3.7368260047409744`*^9, 
   3.7368290752965965`*^9, 3.736829252604149*^9, 3.7456497246307096`*^9, 
   3.745649853178283*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.5 Express coupling amplitudes Mx, My, Mz and Nx, Ny in terms of strain - \
tensor components \[Epsilon]xyz, i.e. defined in NV coordinates xyz)\
\>", "Section",
 CellChangeTimes->{{3.732250435319336*^9, 3.732250502410693*^9}}],

Cell["\<\
Approach : 
1) Define rotations LKelvin, such that XYZ is converted into xyz of NV1-4
2) Express \[Sigma]XYZ in terms of \[Epsilon]xyz using the relation \
\[Sigma]XYZKelvin = CXYZKelvin*LKelvin^T*\[Epsilon]xyzKelvin
3) Calculate coupling amplitudes Mx,My,Mz,Nx,Ny in terms of \[Epsilon]xyz by \
replacing \[Sigma]XYZ\
\>", "Text",
 CellChangeTimes->{{3.7322506492617073`*^9, 3.7322508287952795`*^9}, {
  3.733129447454816*^9, 3.7331294648781643`*^9}, {3.736829198591067*^9, 
  3.73682921113332*^9}, {3.745649320053608*^9, 3.745649336913945*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"clearing", " ", "all", " ", "variables"}], "*)"}]}]], "Input"],

Cell[CellGroupData[{

Cell["2.5.1 General definitions", "Subsection",
 CellChangeTimes->{{3.7322525993285265`*^9, 3.7322526066286726`*^9}, {
  3.7331299282314415`*^9, 3.733129929581468*^9}, {3.733736462826952*^9, 
  3.7337364650669966`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]NV", " ", "=", " ", 
   RowBox[{"ArcCos", "[", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "3", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xunit", " ", "=", " ", 
   RowBox[{"UnitVector", "[", 
    RowBox[{"3", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yunit", " ", "=", " ", 
   RowBox[{"UnitVector", "[", 
    RowBox[{"3", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zunit", " ", "=", " ", 
   RowBox[{"UnitVector", "[", 
    RowBox[{"3", ",", "3"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7322536838821263`*^9, 3.732253714623742*^9}, {
  3.734780227922951*^9, 3.7347802309650126`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.5.2 Define 3 x3 rotation matrices, including K: NV1 to NV4 (passive \
rotation)\
\>", "Subsection",
 CellChangeTimes->{{3.7322526168358817`*^9, 3.732252654128642*^9}, {
  3.733736468767071*^9, 3.733736469767091*^9}, {3.7337382674374156`*^9, 
  3.733738286474797*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Rz", "[", "zdeg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"zdeg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rm1p10", "[", "deg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"deg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", "0"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rp1p10", "[", "deg_", "]"}], ":=", 
  RowBox[{"RotationMatrix", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"deg", "/", "180"}], "*", "\[Pi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV2active", " ", "=", " ", 
   RowBox[{"Rz", "[", "180", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV2passive", "=", 
   RowBox[{"Inverse", "[", "KNV2active", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV3active", " ", "=", " ", 
   RowBox[{
    RowBox[{"Rp1p10", "[", "180", "]"}], ".", 
    RowBox[{"Rz", "[", 
     RowBox[{"-", "90"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV3passive", " ", "=", 
   RowBox[{"Inverse", "[", "KNV3active", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV4active", "=", 
   RowBox[{
    RowBox[{"Rp1p10", "[", "180", "]"}], ".", 
    RowBox[{"Rz", "[", "90", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV4passive", "=", 
   RowBox[{"Inverse", "[", "KNV4active", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7322534170387816`*^9, 3.7322534176187935`*^9}, {
  3.732256910058383*^9, 3.7322569133824887`*^9}, {3.733738290185871*^9, 
  3.7337384056851826`*^9}, {3.7343418786219697`*^9, 3.734341932011042*^9}, {
  3.7343419681037664`*^9, 3.734341986974144*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.5.3 Define 6x6 rotation matrices for Kelvin notation (following \
Mehrabadi1995)\
\>", "Subsection",
 CellChangeTimes->{{3.7322509602622824`*^9, 3.7322509736155496`*^9}, {
  3.732252635007249*^9, 3.732252649269538*^9}, {3.7331294067700005`*^9, 
  3.7331294073300123`*^9}, {3.733736471867133*^9, 3.733736473351163*^9}, {
  3.736683370002673*^9, 3.7366833711857915`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PKelvin", "[", 
    RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "0", ",", " ", "0", ",", " ", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p2"}], ",", " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", " ", "0", ",", " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p1"}], ",", "0", ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p1"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p2"}], ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p1"}], ",", " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p1"}], ",", "0", ",", "p3", 
       ",", 
       RowBox[{"-", "p2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p2"}], ",", "0", ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p2"}], ",", 
       RowBox[{"-", "p3"}], ",", "0", ",", "p1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p3"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p3"}], ",", "0", ",", "p2", 
       ",", 
       RowBox[{"-", "p1"}], ",", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RotMat", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "\[Theta]_"}], "]"}], ":=", 
    " ", 
    RowBox[{
     RowBox[{"IdentityMatrix", "[", "6", "]"}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "*", 
      RowBox[{"PKelvin", "[", 
       RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], 
      RowBox[{
       RowBox[{"PKelvin", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
       RowBox[{"PKelvin", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"PKelvin", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], "+", 
         RowBox[{
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}]}], ")"}], "/", 
       "3"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], "^", "2"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}]}], ")"}], "/", 
       "6"}]}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"rotation", " ", "matrix", " ", "as", " ", "in", " ", 
    RowBox[{"eq", ".", 
     RowBox[{"(", "4", ")"}]}], " ", "from", " ", "Mehrabadi1995"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rm1p106x6", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{"RotMat", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "0", ",", "\[Theta]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rp1p106x6", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{"RotMat", "[", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "0", ",", "\[Theta]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Rz6x6", "[", "\[Theta]_", "]"}], ":=", 
   RowBox[{"RotMat", "[", 
    RowBox[{"0", ",", "0", ",", "1", ",", "\[Theta]"}], "]"}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"check", " ", "whether", " ", "unitary"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"Rz6x6", "[", "\[Theta]", "]"}], "]"}], ".", 
     RowBox[{"Rz6x6", "[", "\[Theta]", "]"}]}], "//", "FullSimplify"}], "//", 
   "MatrixForm"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"Rm1p106x6", "[", "\[Theta]", "]"}], "]"}], ".", 
     RowBox[{"Rm1p106x6", "[", "\[Theta]", "]"}]}], "//", "FullSimplify"}], "//",
    "MatrixForm"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"Rp1p106x6", "[", "\[Theta]", "]"}], "]"}], ".", 
     RowBox[{"Rp1p106x6", "[", "\[Theta]", "]"}]}], "//", "FullSimplify"}], "//",
    "MatrixForm"}], ";"}]}], "Input",
 CellChangeTimes->{{3.732251015099391*^9, 3.732251191689974*^9}, {
   3.7322512382609177`*^9, 3.7322513860259113`*^9}, {3.7322514382359676`*^9, 
   3.7322515768447733`*^9}, {3.7322516397901287`*^9, 
   3.7322516672786865`*^9}, {3.732251705847464*^9, 3.732251739715152*^9}, {
   3.7322517793519526`*^9, 3.732251990831234*^9}, 3.7322520354531784`*^9, {
   3.7322520951734257`*^9, 3.7322520986934958`*^9}, {3.732252330440961*^9, 
   3.732252338941131*^9}, 3.7322525321390715`*^9, {3.732252591114319*^9, 
   3.7322526382193136`*^9}, {3.732253145338175*^9, 3.7322532700927153`*^9}, {
   3.7322536048095427`*^9, 3.732253631960086*^9}, {3.7322567150003443`*^9, 
   3.7322567229205027`*^9}, {3.732256931133844*^9, 3.7322569425350723`*^9}, {
   3.7322599517863607`*^9, 3.732259976043846*^9}, {3.732260164883096*^9, 
   3.732260166223123*^9}, {3.7322602033988676`*^9, 3.7322602135990715`*^9}, {
   3.7331294131181283`*^9, 3.733129440438675*^9}, {3.734242658959287*^9, 
   3.7342426599893084`*^9}, {3.7368252343521132`*^9, 3.7368252551145287`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.5.4 Define rotation matrices Lpassive and Lactive to transform XYZ into xyz \
of NV1-4\
\>", "Subsection",
 CellChangeTimes->{{3.732250530024251*^9, 3.7322505472806005`*^9}, {
  3.73225083279968*^9, 3.7322508370251026`*^9}, {3.732253651890486*^9, 
  3.732253667450797*^9}, {3.732256955979342*^9, 3.7322569591094046`*^9}, {
  3.732257935296177*^9, 3.732257939086253*^9}, {3.7337364824313445`*^9, 
  3.733736483431364*^9}, {3.7342426763576593`*^9, 3.7342426764476604`*^9}, {
  3.7342427253146534`*^9, 3.734242775547675*^9}}],

Cell[CellGroupData[{

Cell["\<\
NV1 (XYZ into x || [-110], y || [-1-12], z || [111]): Rm1p10[\[Alpha]NV].Rz[3\
\[Pi]/4];\
\>", "Subsubsection",
 CellChangeTimes->{{3.732250843644765*^9, 3.732250846649065*^9}, {
  3.7322515835559072`*^9, 3.732251630105888*^9}, {3.732253670010848*^9, 
  3.7322536757119627`*^9}, {3.732257078062837*^9, 3.7322570808728952`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LNV1active", " ", "=", " ", 
   RowBox[{
    RowBox[{"Rm1p10", "[", 
     RowBox[{"\[Alpha]NV", "*", 
      RowBox[{"180", "/", "\[Pi]"}]}], "]"}], ".", 
    RowBox[{"Rz", "[", "135", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV1active", ".", "xunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV1active", ".", "yunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV1active", ".", "zunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV1passive", " ", "=", " ", 
   RowBox[{"Inverse", "[", " ", "LNV1active", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7322516719787807`*^9, 3.732251697567299*^9}, {
  3.732251746231282*^9, 3.7322517915192003`*^9}, {3.7322521169188704`*^9, 
  3.7322521258790493`*^9}, {3.732253725674963*^9, 3.7322537523964987`*^9}, {
  3.7322558670438967`*^9, 3.7322558714439845`*^9}, {3.732256329203689*^9, 
  3.7322563342437897`*^9}, {3.732256401356133*^9, 3.7322564653014135`*^9}, {
  3.7342427392489395`*^9, 3.7342427481031184`*^9}, {3.7456493775137577`*^9, 
  3.7456493779537663`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["2"]]}], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.732252127459081*^9, {3.732253747406399*^9, 3.7322537527665057`*^9}, 
   3.732255872183999*^9, 3.7322564697215023`*^9, 3.732256923073683*^9, {
   3.732259989168109*^9, 3.7322599977882814`*^9}, 3.732260129941394*^9, 
   3.732260221510231*^9, 3.733042304135788*^9, 3.7331299482438416`*^9, 
   3.733737221217086*^9, 3.733743705986309*^9, 3.7340641016049433`*^9, 
   3.7342426998441343`*^9, 3.73432745250161*^9, 3.7343279715094104`*^9, 
   3.7343441303230143`*^9, 3.734780281312027*^9, 3.7348562105817523`*^9, 
   3.735623951366504*^9, 3.7365899970196056`*^9, 3.7366824405937414`*^9, 
   3.736826004930978*^9, 3.736829075556602*^9, 3.736829252814153*^9, 
   3.7456497248107133`*^9, 3.7456498600054207`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["6"]]}], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["6"]]}], ",", 
   SqrtBox[
    FractionBox["2", "3"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.732252127459081*^9, {3.732253747406399*^9, 3.7322537527665057`*^9}, 
   3.732255872183999*^9, 3.7322564697215023`*^9, 3.732256923073683*^9, {
   3.732259989168109*^9, 3.7322599977882814`*^9}, 3.732260129941394*^9, 
   3.732260221510231*^9, 3.733042304135788*^9, 3.7331299482438416`*^9, 
   3.733737221217086*^9, 3.733743705986309*^9, 3.7340641016049433`*^9, 
   3.7342426998441343`*^9, 3.73432745250161*^9, 3.7343279715094104`*^9, 
   3.7343441303230143`*^9, 3.734780281312027*^9, 3.7348562105817523`*^9, 
   3.735623951366504*^9, 3.7365899970196056`*^9, 3.7366824405937414`*^9, 
   3.736826004930978*^9, 3.736829075556602*^9, 3.736829252814153*^9, 
   3.7456497248107133`*^9, 3.7456498600154204`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["3"]], ",", 
   FractionBox["1", 
    SqrtBox["3"]], ",", 
   FractionBox["1", 
    SqrtBox["3"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.732252127459081*^9, {3.732253747406399*^9, 3.7322537527665057`*^9}, 
   3.732255872183999*^9, 3.7322564697215023`*^9, 3.732256923073683*^9, {
   3.732259989168109*^9, 3.7322599977882814`*^9}, 3.732260129941394*^9, 
   3.732260221510231*^9, 3.733042304135788*^9, 3.7331299482438416`*^9, 
   3.733737221217086*^9, 3.733743705986309*^9, 3.7340641016049433`*^9, 
   3.7342426998441343`*^9, 3.73432745250161*^9, 3.7343279715094104`*^9, 
   3.7343441303230143`*^9, 3.734780281312027*^9, 3.7348562105817523`*^9, 
   3.735623951366504*^9, 3.7365899970196056`*^9, 3.7366824405937414`*^9, 
   3.736826004930978*^9, 3.736829075556602*^9, 3.736829252814153*^9, 
   3.7456497248107133`*^9, 3.7456498600154204`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
NV2 (XYZ into x || [1 - 10], y || [112], z || [-1 - 11]) : Rz[\[Pi]].Rm1p10[\
\[Alpha]NV].Rz[3 \[Pi]/4];\
\>", "Subsubsection",
 CellChangeTimes->{{3.7322559068348026`*^9, 3.732255927136264*^9}, {
  3.7322559967136583`*^9, 3.7322560121739674`*^9}, {3.732257072952735*^9, 
  3.7322570762328005`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LNV2active", " ", "=", " ", 
   RowBox[{"KNV2active", ".", "LNV1active"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV2active", ".", "xunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV2active", ".", "yunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV2active", ".", "zunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV2passive", " ", "=", " ", 
   RowBox[{"Inverse", "[", " ", "LNV2active", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7322560160740457`*^9, 3.7322560322143693`*^9}, {
  3.7322563219535437`*^9, 3.7322563374338536`*^9}, {3.7322564808677254`*^9, 
  3.732256502759164*^9}, {3.73433953835295*^9, 3.734339542303029*^9}, {
  3.7343421589026413`*^9, 3.7343421934243355`*^9}, {3.734845750258298*^9, 
  3.7348457751488104`*^9}, {3.7348459215877953`*^9, 3.734845936246103*^9}, {
  3.7456493836298804`*^9, 3.7456493839698873`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["2"]]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.734845926657897*^9, 3.7348459372761235`*^9}, 
   3.7348562106017523`*^9, 3.7356239514365053`*^9, 3.736589997079607*^9, 
   3.7366824406537476`*^9, 3.736826004980979*^9, 3.7368290755866027`*^9, 
   3.7368292528841543`*^9, 3.7456497248307133`*^9, 3.745649860025421*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["6"]], ",", 
   FractionBox["1", 
    SqrtBox["6"]], ",", 
   SqrtBox[
    FractionBox["2", "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.734845926657897*^9, 3.7348459372761235`*^9}, 
   3.7348562106017523`*^9, 3.7356239514365053`*^9, 3.736589997079607*^9, 
   3.7366824406537476`*^9, 3.736826004980979*^9, 3.7368290755866027`*^9, 
   3.7368292528841543`*^9, 3.7456497248307133`*^9, 3.745649860025421*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["3"]]}], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["3"]]}], ",", 
   FractionBox["1", 
    SqrtBox["3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.734845926657897*^9, 3.7348459372761235`*^9}, 
   3.7348562106017523`*^9, 3.7356239514365053`*^9, 3.736589997079607*^9, 
   3.7366824406537476`*^9, 3.736826004980979*^9, 3.7368290755866027`*^9, 
   3.7368292528841543`*^9, 3.7456497248307133`*^9, 3.745649860025421*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
NV3 (XYZ into x || [110], y || [1 - 1 - 2], z || [-1 1 - 1]) : \
Rp1p10[180].Rz[-90].Rm1p10[\[Alpha]NV*180/\[Pi]].Rz[135];\
\>", "Subsubsection",
 CellChangeTimes->{{3.732256049585757*^9, 3.7322561503978157`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LNV3active", " ", "=", 
   RowBox[{"KNV3active", ".", "LNV1active"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV3active", ".", "xunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV3active", ".", "yunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV3active", ".", "zunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV3passive", " ", "=", " ", 
   RowBox[{"Inverse", "[", " ", "LNV3active", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7322561538178844`*^9, 3.7322561754783173`*^9}, {
  3.7322563194734945`*^9, 3.732256339813901*^9}, {3.732256513164372*^9, 
  3.7322565426449614`*^9}, {3.7343422226669216`*^9, 3.734342224556959*^9}, {
  3.7456493953701153`*^9, 3.7456494147235026`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.7322561764083366`*^9, 3.7322565451300116`*^9, 
  3.7322569231336837`*^9, 3.7322599979382844`*^9, 3.7322601300213957`*^9, 
  3.7322602308084173`*^9, 3.7330423129099646`*^9, 3.733129952863934*^9, 
  3.7337372213370886`*^9, 3.7337437060963106`*^9, 3.734064101684945*^9, 
  3.7342427070642786`*^9, 3.7343274526116123`*^9, 3.734327971649413*^9, 
  3.734342225986988*^9, 3.7343441304130163`*^9, 3.7348562106517534`*^9, 
  3.735623951506507*^9, 3.7365899971496086`*^9, 3.7366824407227545`*^9, 
  3.7368260050409803`*^9, 3.736829075646604*^9, 3.7368292529441557`*^9, 
  3.7456497248507137`*^9, 3.745649860035421*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["6"]], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["6"]]}], ",", 
   RowBox[{"-", 
    SqrtBox[
     FractionBox["2", "3"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7322561764083366`*^9, 3.7322565451300116`*^9, 
  3.7322569231336837`*^9, 3.7322599979382844`*^9, 3.7322601300213957`*^9, 
  3.7322602308084173`*^9, 3.7330423129099646`*^9, 3.733129952863934*^9, 
  3.7337372213370886`*^9, 3.7337437060963106`*^9, 3.734064101684945*^9, 
  3.7342427070642786`*^9, 3.7343274526116123`*^9, 3.734327971649413*^9, 
  3.734342225986988*^9, 3.7343441304130163`*^9, 3.7348562106517534`*^9, 
  3.735623951506507*^9, 3.7365899971496086`*^9, 3.7366824407227545`*^9, 
  3.7368260050409803`*^9, 3.736829075646604*^9, 3.7368292529441557`*^9, 
  3.7456497248507137`*^9, 3.745649860035421*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["3"]]}], ",", 
   FractionBox["1", 
    SqrtBox["3"]], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["3"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7322561764083366`*^9, 3.7322565451300116`*^9, 
  3.7322569231336837`*^9, 3.7322599979382844`*^9, 3.7322601300213957`*^9, 
  3.7322602308084173`*^9, 3.7330423129099646`*^9, 3.733129952863934*^9, 
  3.7337372213370886`*^9, 3.7337437060963106`*^9, 3.734064101684945*^9, 
  3.7342427070642786`*^9, 3.7343274526116123`*^9, 3.734327971649413*^9, 
  3.734342225986988*^9, 3.7343441304130163`*^9, 3.7348562106517534`*^9, 
  3.735623951506507*^9, 3.7365899971496086`*^9, 3.7366824407227545`*^9, 
  3.7368260050409803`*^9, 3.736829075646604*^9, 3.7368292529441557`*^9, 
  3.7456497248507137`*^9, 3.745649860045421*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
NV4 (XYZ into x || [-1 - 10], y || [-1 1 - 2], z || [1 - 1 - 1]) : \
Rp1p10[180].Rz[90].Rm1p10[\[Alpha]NV*180/\[Pi]].Rz[135];\
\>", "Subsubsection",
 CellChangeTimes->{{3.7322561910876713`*^9, 3.7322562335895224`*^9}, 
   3.7343276852694235`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LNV4active", " ", "=", 
   RowBox[{"KNV4active", ".", "LNV1active"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV4active", ".", "xunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV4active", ".", "yunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV4active", ".", "zunit"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV4passive", " ", "=", " ", 
   RowBox[{"Inverse", "[", " ", "LNV4active", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.732256264803201*^9, 3.7322562734233737`*^9}, {
   3.732256324783601*^9, 3.732256343903983*^9}, {3.7322565523801565`*^9, 
   3.732256575441618*^9}, 3.7343276759892335`*^9, {3.734339424286623*^9, 
   3.734339440969957*^9}, {3.734342237897229*^9, 3.734342240277277*^9}, {
   3.745649400802224*^9, 3.745649417373556*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["2"]]}], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["2"]]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7322562738733826`*^9, 3.7322565759316278`*^9, 3.7322569231636844`*^9, 
   3.732259997958285*^9, 3.7322601300513964`*^9, 3.7322602308584185`*^9, 
   3.7330423162500315`*^9, 3.7331299549539757`*^9, 3.7337372213670893`*^9, 
   3.7337437061263113`*^9, 3.734064101724946*^9, 3.7342427104543467`*^9, 
   3.734327452641613*^9, {3.7343276804803233`*^9, 3.734327688309484*^9}, 
   3.7343279718094163`*^9, {3.7343394352068415`*^9, 3.7343394417309723`*^9}, 
   3.734342242747326*^9, 3.734344130443017*^9, 3.734856210671754*^9, 
   3.7356239515365076`*^9, 3.736589997169609*^9, 3.7366824407657585`*^9, 
   3.736826005070981*^9, 3.7368290756766043`*^9, 3.7368292529741564`*^9, 
   3.745649724860714*^9, 3.745649860045421*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["6"]]}], ",", 
   FractionBox["1", 
    SqrtBox["6"]], ",", 
   RowBox[{"-", 
    SqrtBox[
     FractionBox["2", "3"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7322562738733826`*^9, 3.7322565759316278`*^9, 3.7322569231636844`*^9, 
   3.732259997958285*^9, 3.7322601300513964`*^9, 3.7322602308584185`*^9, 
   3.7330423162500315`*^9, 3.7331299549539757`*^9, 3.7337372213670893`*^9, 
   3.7337437061263113`*^9, 3.734064101724946*^9, 3.7342427104543467`*^9, 
   3.734327452641613*^9, {3.7343276804803233`*^9, 3.734327688309484*^9}, 
   3.7343279718094163`*^9, {3.7343394352068415`*^9, 3.7343394417309723`*^9}, 
   3.734342242747326*^9, 3.734344130443017*^9, 3.734856210671754*^9, 
   3.7356239515365076`*^9, 3.736589997169609*^9, 3.7366824407657585`*^9, 
   3.736826005070981*^9, 3.7368290756766043`*^9, 3.7368292529741564`*^9, 
   3.745649724860714*^9, 3.745649860055421*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["3"]], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["3"]]}], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["3"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7322562738733826`*^9, 3.7322565759316278`*^9, 3.7322569231636844`*^9, 
   3.732259997958285*^9, 3.7322601300513964`*^9, 3.7322602308584185`*^9, 
   3.7330423162500315`*^9, 3.7331299549539757`*^9, 3.7337372213670893`*^9, 
   3.7337437061263113`*^9, 3.734064101724946*^9, 3.7342427104543467`*^9, 
   3.734327452641613*^9, {3.7343276804803233`*^9, 3.734327688309484*^9}, 
   3.7343279718094163`*^9, {3.7343394352068415`*^9, 3.7343394417309723`*^9}, 
   3.734342242747326*^9, 3.734344130443017*^9, 3.734856210671754*^9, 
   3.7356239515365076`*^9, 3.736589997169609*^9, 3.7366824407657585`*^9, 
   3.736826005070981*^9, 3.7368290756766043`*^9, 3.7368292529741564`*^9, 
   3.745649724860714*^9, 3.745649860055421*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define passive rotations in Kelvin notation for NV1-4", "Subsubsection",
 CellChangeTimes->{{3.7322569912680492`*^9, 3.732257011051445*^9}, {
  3.7331293968198023`*^9, 3.7331293975098157`*^9}, {3.734242841647538*^9, 
  3.7342428434475737`*^9}, {3.74564942855378*^9, 3.7456494292537937`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"KNV2passive6x6", " ", "=", " ", 
   RowBox[{"Inverse", "[", 
    RowBox[{"Rz6x6", "[", "\[Pi]", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV3passive6x6", " ", "=", " ", 
   RowBox[{"Inverse", "[", 
    RowBox[{
     RowBox[{"Rp1p106x6", "[", "\[Pi]", "]"}], ".", 
     RowBox[{"Rz6x6", "[", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], "/", "2"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KNV4passive6x6", "=", 
   RowBox[{"Inverse", "[", 
    RowBox[{
     RowBox[{"Rp1p106x6", "[", "\[Pi]", "]"}], ".", 
     RowBox[{"Rz6x6", "[", 
      RowBox[{"\[Pi]", "/", "2"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7342663275242987`*^9, 3.7342663492507334`*^9}, {
  3.7342664055018606`*^9, 3.734266418192116*^9}, {3.734325699661029*^9, 
  3.7343257598613057`*^9}, {3.734327350281375*^9, 3.734327373754919*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"LNV1active6x6", " ", "=", " ", 
   RowBox[{
    RowBox[{"Rm1p106x6", "[", "\[Alpha]NV", "]"}], ".", 
    RowBox[{"Rz6x6", "[", 
     RowBox[{"3", 
      RowBox[{"\[Pi]", "/", "4"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV1passive6x6", "=", 
   RowBox[{"Inverse", "[", "LNV1active6x6", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV2active6x6", " ", "=", " ", 
   RowBox[{
    RowBox[{"Rz6x6", "[", "\[Pi]", "]"}], ".", 
    RowBox[{"Rm1p106x6", "[", "\[Alpha]NV", "]"}], ".", 
    RowBox[{"Rz6x6", "[", 
     RowBox[{"3", 
      RowBox[{"\[Pi]", "/", "4"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV2passive6x6", "=", 
   RowBox[{"Inverse", "[", "LNV2active6x6", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV3active6x6", " ", "=", " ", 
   RowBox[{
    RowBox[{"Rp1p106x6", "[", "\[Pi]", "]"}], ".", 
    RowBox[{"Rz6x6", "[", 
     RowBox[{
      RowBox[{"-", "\[Pi]"}], "/", "2"}], "]"}], ".", 
    RowBox[{"Rm1p106x6", "[", "\[Alpha]NV", "]"}], ".", 
    RowBox[{"Rz6x6", "[", 
     RowBox[{"3", 
      RowBox[{"\[Pi]", "/", "4"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV3passive6x6", "=", 
   RowBox[{"Inverse", "[", "LNV3active6x6", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV4active6x6", " ", "=", "  ", 
   RowBox[{
    RowBox[{"Rp1p106x6", "[", "\[Pi]", "]"}], ".", 
    RowBox[{"Rz6x6", "[", 
     RowBox[{"\[Pi]", "/", "2"}], "]"}], ".", 
    RowBox[{"Rm1p106x6", "[", "\[Alpha]NV", "]"}], ".", 
    RowBox[{"Rz6x6", "[", 
     RowBox[{"3", 
      RowBox[{"\[Pi]", "/", "4"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LNV4passive6x6", "=", 
   RowBox[{"Inverse", "[", "LNV4active6x6", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.732256967740577*^9, 3.7322569827378783`*^9}, {
   3.732257023356742*^9, 3.7322571588964596`*^9}, {3.732257641568213*^9, 
   3.732257756994527*^9}, 3.734327696050639*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Checking", " ", "whether", " ", "unitary"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "LNV1passive6x6", "]"}], ".", 
      "LNV1passive6x6"}], "//", "FullSimplify"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "LNV2passive6x6", "]"}], ".", 
      "LNV2passive6x6"}], "//", "FullSimplify"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "LNV3passive6x6", "]"}], ".", 
      "LNV3passive6x6"}], "//", "FullSimplify"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "LNV4passive6x6", "]"}], ".", 
      "LNV4passive6x6"}], "//", "FullSimplify"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.732257761734621*^9, 3.73225780514953*^9}, 
   3.732260097312741*^9, 3.7322602346884947`*^9, {3.7342427997691774`*^9, 
   3.7342428067383347`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.5.5 Express coupling amplitudes Mx, My, Mz, Nx, Ny in terms of strain \
\[Epsilon]xyz for NV1- reproduce Ludlow1968\
\>", "Subsection",
 CellChangeTimes->{{3.732257971987912*^9, 3.732258069306861*^9}, {
  3.733736486579485*^9, 3.7337365258553114`*^9}, {3.733743021731614*^9, 
  3.733743041915018*^9}, {3.733744433837323*^9, 3.733744438217411*^9}, {
  3.733745729615482*^9, 3.733745733775565*^9}, {3.734262499162259*^9, 
  3.7342624993022614`*^9}}],

Cell["\<\
Here, we are comparing two different approaches.

In the first approach, we perform the rotation in 3x3 notation and then \
replace the \[Sigma]IJ in the expressions for the coupling amplitudes Mi. \
Specifically, we:
1) rotate \[Epsilon]xyzNV1 (\[Epsilon]xyz defined in the reference frame of \
NV1) as a 3x3 matrix: \[Epsilon]XYZNV1 = \
Transpose[LNV1passive].\[Epsilon]xyzNV1.LNV1passive --> from xyzNV1 to XYZ
2) transform \[Epsilon]XYZNV1 --> \[Epsilon]XYZNV1Voigt
3) express stress vector \[Sigma]XYZNV1Voigt = CXYZVoigt*\[Epsilon]XYZNV1Voigt
4) get expressions of Mx,y,z for NV1

In the second approach, we peform all steps in the Kelvin notation. To that \
end, we
1) rotate \[Epsilon]xyz as a Kelvin vector : \[Epsilon]XYZNV1Kelvin = \
Transpose[LNV1passive].\[Epsilon]xyzNV1Kelvin
2) Express stress vector \[Sigma]XYZNV1Kelvin = \
CXYZKelvin*\[Epsilon]XYZNV1Kelvin
3) Get expressions of Mx, y, z for NV1\[LineSeparator]
In both cases, we replace the \[Sigma]IJ of the Mx,y,z for NV1 (as obtained \
in section 2.3).\[LineSeparator]
Both approaches yield similar results. We also find that the spin-stress \
coupling constants differ by a factor of 2 in the C44 terms from the \
relations given in Ludlow1968.\
\>", "Text",
 CellChangeTimes->{{3.7322580745989676`*^9, 3.732258142269323*^9}, 
   3.732258181983118*^9, {3.73312566837923*^9, 3.7331257825655174`*^9}, {
   3.7331260364168005`*^9, 3.733126047477021*^9}, {3.7331268305027266`*^9, 
   3.7331269865258555`*^9}, {3.7331278116634903`*^9, 3.733127845505169*^9}, {
   3.733473169774026*^9, 3.733473183324297*^9}, {3.7337444444975367`*^9, 
   3.733744471199071*^9}, {3.7342428574348607`*^9, 3.7342428992427177`*^9}, {
   3.734243003221245*^9, 3.734243013653466*^9}, {3.7342431544128942`*^9, 
   3.7342432092510414`*^9}, {3.734262111228194*^9, 3.7342624290857706`*^9}, {
   3.7342625866236525`*^9, 3.734262648825945*^9}, {3.7366833842370963`*^9, 
   3.7366834001226845`*^9}, {3.7368292290336776`*^9, 3.7368292439339757`*^9}}],

Cell[CellGroupData[{

Cell["Voigt notation", "Subsubsection",
 CellChangeTimes->{{3.7342627221057177`*^9, 3.7342627339949718`*^9}}],

Cell["\<\
\[Sigma]ijV \[Equal] \[Sigma]ij for i,j=x,y,z
\[Epsilon]iiV \[Equal] \[Epsilon]ii for i=x,y,z; \[Epsilon]ijV == 2 \
\[Epsilon]ij for i,j=x,y,z and i not j
C11V == C11, C12V == C12, C44V == C44\
\>", "Text",
 CellChangeTimes->{{3.7365985481516933`*^9, 3.7365985872185106`*^9}, {
  3.7365987226856318`*^9, 3.7365987525922856`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Epsilon]xx", ",", "\[Epsilon]xy", ",", "\[Epsilon]xz"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]xy", ",", "\[Epsilon]yy", ",", "\[Epsilon]yz"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]xz", ",", "\[Epsilon]yz", ",", "\[Epsilon]zz"}], 
      "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CXYZVoigt", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "C11V", ",", "C12V", ",", "C12V", ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "C12V", ",", "C11V", ",", "C12V", ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "C12V", ",", "C12V", ",", "C11V", ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "C44V", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "C44V", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "C44V"}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.736598544441619*^9, {3.736598592186614*^9, 3.7365985936366434`*^9}, {
   3.7366530930801153`*^9, 3.736653109303738*^9}, {3.7366536291827207`*^9, 
   3.7366536298087835`*^9}, 3.7366539993497334`*^9, 3.745649494836108*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Voigtnotation", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C11V", " ", "\[Rule]", " ", "C11"}], ",", " ", 
     RowBox[{"C12V", " ", "\[Rule]", "  ", "C12"}], ",", " ", 
     RowBox[{"C44V", " ", "\[Rule]", "  ", "C44"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7366541758083773`*^9, 3.7366541768084774`*^9}, 
   3.745649505326318*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CXYZVoigt", "/.", "Voigtnotation"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.7366529894897575`*^9, 3.7366530213989487`*^9}, {
  3.7366536471285152`*^9, 3.736653647559558*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C12", "0", "0", "0"},
     {"C12", "C11", "C12", "0", "0", "0"},
     {"C12", "C12", "C11", "0", "0", "0"},
     {"0", "0", "0", "C44", "0", "0"},
     {"0", "0", "0", "0", "C44", "0"},
     {"0", "0", "0", "0", "0", "C44"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7366529958253913`*^9, 3.7366530219280014`*^9}, {
   3.736653639947797*^9, 3.736653648059608*^9}, 3.7366824422539077`*^9, 
   3.7368260063910074`*^9, 3.7368290769166293`*^9, 3.7368292542441816`*^9, 
   3.745649726060738*^9, 3.7456498612154446`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]XYZNV1", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", "LNV1passive", "]"}], ".", "\[Epsilon]xyzNV1", 
     ".", "LNV1passive"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]XYZNV1Voigt", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]XYZNV1", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"\[Epsilon]XYZNV1", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"\[Epsilon]XYZNV1", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"2", 
      RowBox[{"\[Epsilon]XYZNV1", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "3"}], "]"}], "]"}]}], ",", 
     RowBox[{"2", 
      RowBox[{"\[Epsilon]XYZNV1", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", 
     RowBox[{"2", 
      RowBox[{"\[Epsilon]XYZNV1", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]XYZNV1Voigt", " ", "=", " ", 
   RowBox[{"CXYZVoigt", ".", "\[Epsilon]XYZNV1Voigt"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV1strainVoigt", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"\[Sigma]XYZNV1Voigt", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}]}], ")"}]}], "+", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
         "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "6", 
          "\[RightDoubleBracket]"}]}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "4", 
         "\[RightDoubleBracket]"}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "5", 
         "\[RightDoubleBracket]"}]}], ")"}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"MyNV1strainVoigt", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}]}], ")"}]}], "+", 
     RowBox[{
      SqrtBox["3"], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "4", 
         "\[RightDoubleBracket]"}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "5", 
         "\[RightDoubleBracket]"}]}], ")"}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"MzNV1strainVoigt", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], "+", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}], "+", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "3", 
         "\[RightDoubleBracket]"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "a2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "4", 
         "\[RightDoubleBracket]"}], "+", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "5", 
         "\[RightDoubleBracket]"}], "+", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "6", 
         "\[RightDoubleBracket]"}]}], ")"}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"NxNV1strainVoigt", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"d", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"\[Sigma]XYZNV1Voigt", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}]}], ")"}]}], "+", 
     RowBox[{"e", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
         "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "6", 
          "\[RightDoubleBracket]"}]}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "4", 
         "\[RightDoubleBracket]"}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "5", 
         "\[RightDoubleBracket]"}]}], ")"}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"NyNV1strainVoigt", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", "d", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}]}], ")"}]}], "+", 
     RowBox[{
      SqrtBox["3"], " ", "e", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "4", 
         "\[RightDoubleBracket]"}], "-", 
        RowBox[{
        "\[Sigma]XYZNV1Voigt", "\[LeftDoubleBracket]", "5", 
         "\[RightDoubleBracket]"}]}], ")"}]}]}], "//", "FullSimplify"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.736654018845683*^9, 3.736654144359233*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MxNV1strainVoigt", "/.", "Voigtnotation"}]], "Input",
 CellChangeTimes->{{3.736651433847209*^9, 3.736651436483473*^9}, {
  3.7366541516629634`*^9, 3.736654166619459*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "b"}], " ", 
   RowBox[{"(", 
    RowBox[{"C11", "-", "C12"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xx", "-", "\[Epsilon]yy", "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ")"}]}], "-", 
  RowBox[{"2", " ", "c", " ", "C44", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xx", "-", "\[Epsilon]yy", "+", 
     RowBox[{
      SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.736651437089533*^9, {3.7366541584056377`*^9, 3.7366541813889356`*^9}, 
   3.736682442719954*^9, 3.736826006901017*^9, 3.736829077406639*^9, 
   3.736829254734192*^9, 3.745649726560748*^9, 3.7456498617054543`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kelvin notation", "Subsubsection",
 CellChangeTimes->{{3.7342627365250225`*^9, 3.734262740697106*^9}, {
  3.7366831766873436`*^9, 3.736683177439419*^9}}],

Cell["\<\
\[Sigma]iiK == \[Sigma]ii for i = x, y, z; \[Sigma]ijK == Sqrt[2] \[Sigma]ij \
for i, j = x, y, z and i not j
\[Epsilon]iiK == \[Epsilon]ii for i = x, y, z; \[Epsilon]ijK == Sqrt[2] \
\[Epsilon]ij for i, j = x, y, z and i not j
C11K == C11, C12K == C12, C44K == 2 C44\
\>", "Text",
 CellChangeTimes->{{3.736598706426281*^9, 3.736598706426281*^9}, {
  3.7365987578023896`*^9, 3.7365988509235373`*^9}, {3.7366831987365484`*^9, 
  3.7366832233700113`*^9}},
 EmphasizeSyntaxErrors->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV1Kelvin", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "\[Epsilon]xxK", ",", "\[Epsilon]yyK", ",", "\[Epsilon]zzK", ",", 
     "\[Epsilon]yzK", ",", "\[Epsilon]xzK", ",", "\[Epsilon]xyK"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CXYZKelvin", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "C11K", ",", "C12K", ",", "C12K", ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "C12K", ",", "C11K", ",", "C12K", ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "C12K", ",", "C12K", ",", "C11K", ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "C44K", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "C44K", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "C44K"}], 
      "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7365988579906816`*^9, 3.736598862682875*^9}, {
   3.7366831815298276`*^9, 3.736683196943369*^9}, {3.7366832349851727`*^9, 
   3.7366832575704308`*^9}, {3.736683294042078*^9, 3.7366832945951333`*^9}, 
   3.7456495438680897`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Kelvinnotation", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C11K", " ", "\[Rule]", " ", "C11"}], ",", " ", 
     RowBox[{"C12K", " ", "\[Rule]", "  ", "C12"}], ",", " ", 
     RowBox[{"C44K", " ", "\[Rule]", " ", 
      RowBox[{"2", "C44"}]}], ",", 
     RowBox[{"\[Epsilon]xxK", "\[Rule]", " ", "\[Epsilon]xx"}], ",", 
     RowBox[{"\[Epsilon]yyK", "\[Rule]", " ", "\[Epsilon]yy"}], ",", 
     RowBox[{"\[Epsilon]zzK", "\[Rule]", " ", "\[Epsilon]zz"}], ",", 
     RowBox[{"\[Epsilon]yzK", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Epsilon]yz"}]}], ",", 
     RowBox[{"\[Epsilon]xzK", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Epsilon]xz"}]}], ",", 
     RowBox[{"\[Epsilon]xyK", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Epsilon]xy"}]}], ",", 
     RowBox[{"\[Sigma]XXK", "\[Rule]", " ", "\[Sigma]XX"}], ",", 
     RowBox[{"\[Sigma]YYK", "\[Rule]", " ", "\[Sigma]YY"}], ",", 
     RowBox[{"\[Sigma]ZZK", "\[Rule]", "\[Sigma]ZZ"}], ",", 
     RowBox[{"\[Sigma]YZK", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Sigma]YZ"}]}], ",", 
     RowBox[{"\[Sigma]XZK", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Sigma]XZ"}]}], ",", 
     RowBox[{"\[Sigma]XYK", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "\[Sigma]XY"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7365990154350123`*^9, 3.7365990166450367`*^9}, {
   3.7365991805423484`*^9, 3.7365991991367235`*^9}, {3.736650886446474*^9, 
   3.736650892353065*^9}, {3.736683229697644*^9, 3.7366832302727013`*^9}, {
   3.736683261320806*^9, 3.736683282682942*^9}, {3.7366836870083704`*^9, 
   3.736683710175687*^9}, {3.7366837459352627`*^9, 3.7366837828079495`*^9}, {
   3.7366844763853006`*^9, 3.7366844804107027`*^9}, 3.745649559598404*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]XYZKelvin", " ", "=", " ", 
   RowBox[{
    RowBox[{"CXYZKelvin", ".", 
     RowBox[{"Transpose", "[", "LNV1passive6x6", "]"}], ".", 
     "\[Epsilon]xyzNV1Kelvin"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV1strainKelvin", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"b", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], " ", "+", " ", 
     RowBox[{"c", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{
          RowBox[{"\[Sigma]XYZKelvin", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV1strainKelvin", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "b", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "c", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV1strainKelvin", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "+", 
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"2", "a2", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "6", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV1strainKelvin", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], " ", "+", " ", 
     RowBox[{"e", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{
          RowBox[{"\[Sigma]XYZKelvin", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NyNV1strainKelvin", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "d", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XYZKelvin", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "e", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XYZKelvin", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7331253539580865`*^9, 3.7331254058971276`*^9}, {
   3.733743871489621*^9, 3.733743900873209*^9}, 3.7340682096902037`*^9, 
   3.7342624600263934`*^9, {3.7354689999185524`*^9, 3.7354690176159086`*^9}, {
   3.735469163064942*^9, 3.7354691650549817`*^9}, {3.7365904164342575`*^9, 
   3.736590419754324*^9}, {3.736590500816967*^9, 3.7365905033670177`*^9}, {
   3.7365944929990644`*^9, 3.736594525521718*^9}, {3.7365980159517326`*^9, 
   3.7365980175617647`*^9}, {3.736598051958461*^9, 3.736598072993882*^9}, {
   3.73659824094427*^9, 3.7365982666677866`*^9}, {3.736598976872234*^9, 
   3.73659899346557*^9}, {3.736650786352466*^9, 3.736650786840515*^9}, {
   3.736650828147645*^9, 3.7366508589677267`*^9}, {3.7366510931671443`*^9, 
   3.73665110292312*^9}, {3.73668328696237*^9, 3.736683351404814*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Checking whether the two approaches give same results", "Subsubsection",
 CellChangeTimes->{{3.734262743537165*^9, 3.734262764291584*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV1strainKelvin", "/.", "Kelvinnotation"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV1strainVoigt", "/.", "Voigtnotation"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.736599300031803*^9, 3.7365993327124677`*^9}, {
  3.7366834120888815`*^9, 3.736683415084181*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "b"}], " ", 
   RowBox[{"(", 
    RowBox[{"C11", "-", "C12"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xx", "-", "\[Epsilon]yy", "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ")"}]}], "-", 
  RowBox[{"2", " ", "c", " ", "C44", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xx", "-", "\[Epsilon]yy", "+", 
     RowBox[{
      SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.736599312955064*^9, 3.736599333612486*^9}, 
   3.7366508665114813`*^9, 3.736650899388768*^9, 3.7366511075635843`*^9, 
   3.736654499412735*^9, 3.7366824435510373`*^9, 3.7366834459022627`*^9, 
   3.7368260077510347`*^9, 3.7368290782066555`*^9, 3.736829255344204*^9, 
   3.7456497273217635`*^9, 3.745649862335467*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "b"}], " ", 
   RowBox[{"(", 
    RowBox[{"C11", "-", "C12"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xx", "-", "\[Epsilon]yy", "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ")"}]}], "-", 
  RowBox[{"2", " ", "c", " ", "C44", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xx", "-", "\[Epsilon]yy", "+", 
     RowBox[{
      SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.736599312955064*^9, 3.736599333612486*^9}, 
   3.7366508665114813`*^9, 3.736650899388768*^9, 3.7366511075635843`*^9, 
   3.736654499412735*^9, 3.7366824435510373`*^9, 3.7366834459022627`*^9, 
   3.7368260077510347`*^9, 3.7368290782066555`*^9, 3.736829255344204*^9, 
   3.7456497273217635`*^9, 3.745649862345467*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MxNV1strainKelvin", "==", "MxNV1strainVoigt"}], "/.", 
    "Voigtnotation"}], "/.", "Kelvinnotation"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MyNV1strainKelvin", "==", "MyNV1strainVoigt"}], "/.", 
    "Voigtnotation"}], "/.", "Kelvinnotation"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MzNV1strainKelvin", "==", "MzNV1strainVoigt"}], "/.", 
    "Voigtnotation"}], "/.", "Kelvinnotation"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.733131582910247*^9, 3.7331315910904107`*^9}, {
  3.733131707109735*^9, 3.733131721522023*^9}, {3.7365981120976715`*^9, 
  3.7365981818410788`*^9}, {3.736683418499522*^9, 3.7366834328899612`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.733131587190333*^9, 3.7331315915904207`*^9}, 
   3.733131626349117*^9, {3.7331316917374277`*^9, 3.7331317226220455`*^9}, 
   3.7337414433990755`*^9, 3.7337439370689335`*^9, 3.7340641039049892`*^9, {
   3.734262464307479*^9, 3.734262470937622*^9}, 3.7343277139550157`*^9, 
   3.7343279742294645`*^9, 3.7343441324110565`*^9, 3.7348562189699607`*^9, 
   3.7348635885524807`*^9, 3.735623976537012*^9, 3.736590174417184*^9, 
   3.7365905101571536`*^9, 3.736594539961009*^9, {3.7365981221858745`*^9, 
   3.73659818237109*^9}, 3.736598303595538*^9, 3.7365992096829405`*^9, 
   3.7366545024680405`*^9, 3.736682443591041*^9, {3.7366834351241846`*^9, 
   3.736683448086481*^9}, 3.736826007791035*^9, 3.736829078246656*^9, 
   3.7368292553742046`*^9, 3.7456497273317633`*^9, 3.745649862345467*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.733131587190333*^9, 3.7331315915904207`*^9}, 
   3.733131626349117*^9, {3.7331316917374277`*^9, 3.7331317226220455`*^9}, 
   3.7337414433990755`*^9, 3.7337439370689335`*^9, 3.7340641039049892`*^9, {
   3.734262464307479*^9, 3.734262470937622*^9}, 3.7343277139550157`*^9, 
   3.7343279742294645`*^9, 3.7343441324110565`*^9, 3.7348562189699607`*^9, 
   3.7348635885524807`*^9, 3.735623976537012*^9, 3.736590174417184*^9, 
   3.7365905101571536`*^9, 3.736594539961009*^9, {3.7365981221858745`*^9, 
   3.73659818237109*^9}, 3.736598303595538*^9, 3.7365992096829405`*^9, 
   3.7366545024680405`*^9, 3.736682443591041*^9, {3.7366834351241846`*^9, 
   3.736683448086481*^9}, 3.736826007791035*^9, 3.736829078246656*^9, 
   3.7368292553742046`*^9, 3.7456497273317633`*^9, 3.7456498623654675`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.733131587190333*^9, 3.7331315915904207`*^9}, 
   3.733131626349117*^9, {3.7331316917374277`*^9, 3.7331317226220455`*^9}, 
   3.7337414433990755`*^9, 3.7337439370689335`*^9, 3.7340641039049892`*^9, {
   3.734262464307479*^9, 3.734262470937622*^9}, 3.7343277139550157`*^9, 
   3.7343279742294645`*^9, 3.7343441324110565`*^9, 3.7348562189699607`*^9, 
   3.7348635885524807`*^9, 3.735623976537012*^9, 3.736590174417184*^9, 
   3.7365905101571536`*^9, 3.736594539961009*^9, {3.7365981221858745`*^9, 
   3.73659818237109*^9}, 3.736598303595538*^9, 3.7365992096829405`*^9, 
   3.7366545024680405`*^9, 3.736682443591041*^9, {3.7366834351241846`*^9, 
   3.736683448086481*^9}, 3.736826007791035*^9, 3.736829078246656*^9, 
   3.7368292553742046`*^9, 3.7456497273317633`*^9, 3.7456498623654675`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notation of Ludlow1968", "Subsubsection",
 CellChangeTimes->{{3.7342627792598877`*^9, 3.7342627874050536`*^9}}],

Cell["\<\
Bring this in the form of Ludlow1968, i.e. introduce spin - strain coupling \
constants A1, A2, B, C as
\tA1 = a1 (C11+2C12) + 4 a2 C44
\tA2 = a1 (C11+2C12) - 2 a2 C44
\tB = -b (C11-C12) - 2 c C44
\tC = Sqrt[2] b (C11-C12) - Sqrt[2] c C44
\tD = -d (C11-C12) - 2 e C44
\tE = Sqrt[2] d (C11-C12) - Sqrt[2] e C44\
\>", "Text",
 CellChangeTimes->{{3.733743970531603*^9, 3.7337439920750346`*^9}, {
  3.733744383948325*^9, 3.733744385148349*^9}, {3.735623980551094*^9, 
  3.735623981961122*^9}, {3.736652608135626*^9, 3.7366526286526775`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"checking", " ", "Voigt", " ", "notation"}], "*)"}]], "Input",
 CellChangeTimes->{{3.73665122063789*^9, 3.736651227968623*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"factor", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV1strainVoigtcheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xx", " ", "-", " ", "\[Epsilon]yy"}], ")"}]}], " ",
       "+", " ", 
      RowBox[{"2", " ", "C", " ", "\[Epsilon]yz"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"B", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", " ", 
          RowBox[{"factor", "*", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"C", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{"factor", "*", "c", " ", 
          RowBox[{"C44", "/", 
           RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}]}], "}"}]}], "//", 
    "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MyNV1strainVoigtcheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "B", " ", "\[Epsilon]xy"}], " ", "-", " ", 
      RowBox[{"2", " ", "C", " ", "\[Epsilon]xz"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"B", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", " ", 
          RowBox[{"factor", "*", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"C", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{"factor", "*", "c", " ", 
          RowBox[{"C44", "/", 
           RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}]}], "}"}]}], "//", 
    "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MzNV1strainVoigtcheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"A1", " ", "\[Epsilon]zz"}], " ", "+", " ", 
      RowBox[{"A2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xx", " ", "+", " ", "\[Epsilon]yy"}], ")"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A1", "\[Rule]", " ", 
        RowBox[{
         RowBox[{"a1", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "C12"}]}], ")"}]}], "+", 
         RowBox[{"2", "*", "factor", "*", " ", "a2", " ", "C44"}]}]}], ",", 
       " ", 
       RowBox[{"A2", "\[Rule]", " ", 
        RowBox[{
         RowBox[{"a1", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "C12"}]}], ")"}]}], "-", 
         RowBox[{"factor", "*", " ", "a2", " ", "C44"}]}]}], ",", 
       RowBox[{"B", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
          RowBox[{"factor", "*", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"C", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{"factor", "*", " ", "c", " ", 
          RowBox[{"C44", "/", 
           RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}]}], "}"}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV1strainVoigtcheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"D", " ", "*", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xx", " ", "-", " ", "\[Epsilon]yy"}], ")"}]}], " ",
       "+", " ", 
      RowBox[{"2", "E", " ", "\[Epsilon]yz"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "d"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
          RowBox[{"factor", "*", "e", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"E", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "d", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{"factor", "*", "e", " ", 
          RowBox[{"C44", "/", 
           RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}]}], "}"}]}], "//", 
    "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"NyNV1strainVoigtcheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "D", " ", "\[Epsilon]xy"}], " ", "-", " ", 
      RowBox[{"2", "E", " ", "\[Epsilon]xz"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "d"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
          RowBox[{"factor", "*", "e", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"E", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "d", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{"factor", "*", "e", " ", 
          RowBox[{"C44", "/", 
           RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}]}], "}"}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MxNV1strainVoigtcheck", "==", "MxNV1strainVoigt"}], "/.", 
   "Voigtnotation"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MyNV1strainVoigtcheck", "==", "MyNV1strainVoigt"}], "/.", 
   "Voigtnotation"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MzNV1strainVoigtcheck", "==", "MzNV1strainVoigt"}], "/.", 
   "Voigtnotation"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NxNV1strainVoigtcheck", "\[Equal]", "NxNV1strainVoigt"}], "/.", 
   "Voigtnotation"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NyNV1strainVoigtcheck", "\[Equal]", "NyNV1strainVoigt"}], "/.", 
   "Voigtnotation"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7366512445692835`*^9, 3.736651316176443*^9}, {
   3.7366514726690907`*^9, 3.7366514753683605`*^9}, {3.736652165299347*^9, 
   3.7366521715859756`*^9}, {3.736652650469859*^9, 3.7366528801888285`*^9}, 
   3.74564957982181*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7366513201388392`*^9, 3.7366514869675207`*^9, 3.7366521773545523`*^9, 
   3.7366526513709493`*^9, {3.7366528370225124`*^9, 3.7366528808368936`*^9}, 
   3.736654194292226*^9, 3.7366824438300653`*^9, 3.7368260080410404`*^9, 
   3.7368290784666605`*^9, 3.7368292555842085`*^9, 3.7456497275717683`*^9, 
   3.7456498625554714`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7366513201388392`*^9, 3.7366514869675207`*^9, 3.7366521773545523`*^9, 
   3.7366526513709493`*^9, {3.7366528370225124`*^9, 3.7366528808368936`*^9}, 
   3.736654194292226*^9, 3.7366824438300653`*^9, 3.7368260080410404`*^9, 
   3.7368290784666605`*^9, 3.7368292555842085`*^9, 3.7456497275717683`*^9, 
   3.7456498625554714`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7366513201388392`*^9, 3.7366514869675207`*^9, 3.7366521773545523`*^9, 
   3.7366526513709493`*^9, {3.7366528370225124`*^9, 3.7366528808368936`*^9}, 
   3.736654194292226*^9, 3.7366824438300653`*^9, 3.7368260080410404`*^9, 
   3.7368290784666605`*^9, 3.7368292555842085`*^9, 3.7456497275717683`*^9, 
   3.7456498625554714`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7366513201388392`*^9, 3.7366514869675207`*^9, 3.7366521773545523`*^9, 
   3.7366526513709493`*^9, {3.7366528370225124`*^9, 3.7366528808368936`*^9}, 
   3.736654194292226*^9, 3.7366824438300653`*^9, 3.7368260080410404`*^9, 
   3.7368290784666605`*^9, 3.7368292555842085`*^9, 3.7456497275717683`*^9, 
   3.745649862585472*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7366513201388392`*^9, 3.7366514869675207`*^9, 3.7366521773545523`*^9, 
   3.7366526513709493`*^9, {3.7366528370225124`*^9, 3.7366528808368936`*^9}, 
   3.736654194292226*^9, 3.7366824438300653`*^9, 3.7368260080410404`*^9, 
   3.7368290784666605`*^9, 3.7368292555842085`*^9, 3.7456497275717683`*^9, 
   3.7456498625954723`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"checking", " ", "Kelvin", " ", "notation"}], "*)"}]], "Input",
 CellChangeTimes->{{3.736651233609187*^9, 3.7366512383656626`*^9}, {
  3.7366834582664986`*^9, 3.7366834589555674`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV1strainKelvincheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xx", " ", "-", " ", "\[Epsilon]yy"}], ")"}]}], " ",
       "+", " ", 
      RowBox[{"2", " ", "C", " ", "\[Epsilon]yz"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"B", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", " ", 
          RowBox[{"2", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"C", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{"2", "c", " ", 
          RowBox[{"C44", "/", 
           RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}]}], "}"}]}], "//", 
    "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MyNV1strainKelvincheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "B", " ", "\[Epsilon]xy"}], " ", "-", " ", 
      RowBox[{"2", " ", "C", " ", "\[Epsilon]xz"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"B", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
          RowBox[{"2", " ", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"C", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "c", " ", "C44"}]}]}]}], 
      "}"}]}], "//", "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MzNV1strainKelvincheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"A1", " ", "\[Epsilon]zz"}], " ", "+", " ", 
      RowBox[{"A2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xx", " ", "+", " ", "\[Epsilon]yy"}], ")"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A1", "\[Rule]", " ", 
        RowBox[{
         RowBox[{"a1", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "C12"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "a2", " ", "C44"}]}]}], ",", " ", 
       RowBox[{"A2", "\[Rule]", " ", 
        RowBox[{
         RowBox[{"a1", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "C12"}]}], ")"}]}], "-", 
         RowBox[{"2", " ", "a2", " ", "C44"}]}]}], ",", 
       RowBox[{"B", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "b"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
          RowBox[{"2", " ", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"C", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "c", " ", "C44"}]}]}]}], 
      "}"}]}], "//", "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NxNV1strainKelvincheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"D", " ", "*", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xx", " ", "-", " ", "\[Epsilon]yy"}], ")"}]}], " ",
       "+", " ", 
      RowBox[{"2", "E", " ", "\[Epsilon]yz"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "d"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
          RowBox[{"2", " ", "e", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"E", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "d", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "e", " ", "C44"}]}]}]}], 
      "}"}]}], "//", "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"NyNV1strainKelvincheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "D", " ", "\[Epsilon]xy"}], " ", "-", " ", 
      RowBox[{"2", "E", " ", "\[Epsilon]xz"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "d"}], " ", 
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
          RowBox[{"2", " ", "e", " ", "C44"}]}], ")"}]}], ",", " ", 
       RowBox[{"E", "\[Rule]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "d", " ", 
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], " ", "e", " ", "C44"}]}]}]}], 
      "}"}]}], "//", "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MxNV1strainKelvincheck", "==", "MxNV1strainKelvin"}], "/.", 
   "Kelvinnotation"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MyNV1strainKelvincheck", "==", "MyNV1strainKelvin"}], "/.", 
   "Kelvinnotation"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MzNV1strainKelvincheck", "==", "MzNV1strainKelvin"}], "/.", 
   "Kelvinnotation"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NxNV1strainKelvincheck", "\[Equal]", "NxNV1strainKelvin"}], "/.", 
   "Kelvinnotation"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NyNV1strainKelvincheck", "\[Equal]", "NyNV1strainKelvin"}], "/.", 
   "Kelvinnotation"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.734859525415086*^9, 3.7348595257850933`*^9}, {
   3.7348636010067325`*^9, 3.734863617567067*^9}, {3.7348652663979626`*^9, 
   3.734865283150303*^9}, {3.7354689068256354`*^9, 3.73546898095417*^9}, {
   3.735469025917077*^9, 3.7354690340082407`*^9}, {3.7354690736490393`*^9, 
   3.735469074119048*^9}, 3.7354691132518415`*^9, {3.736590846957082*^9, 
   3.7365908803337536`*^9}, {3.736591823335054*^9, 3.7365918273751345`*^9}, {
   3.7366511562654533`*^9, 3.7366511662034473`*^9}, {3.736683461886861*^9, 
   3.736683532955967*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7337444057047606`*^9, 3.73406410394499*^9, 3.7342624770307474`*^9, 
   3.734327713995016*^9, 3.7343279742594657`*^9, 3.7343441324610577`*^9, 
   3.734856218999961*^9, 3.734863618877093*^9, 3.734864847665679*^9, 
   3.7348650052614193`*^9, 3.7348652840003195`*^9, {3.735469023257024*^9, 
   3.735469034328247*^9}, 3.735469076769101*^9, 3.735469115731891*^9, 
   3.7354691741181655`*^9, 3.7356239839911623`*^9, 3.7365905281695166`*^9, 
   3.7365908066171355`*^9, 3.7365908811837707`*^9, 3.736591827975147*^9, {
   3.736651141807008*^9, 3.73665116702853*^9}, 3.736654481332927*^9, 
   3.7366824439220743`*^9, {3.7366835066823397`*^9, 3.736683534330104*^9}, 
   3.7366837932999983`*^9, 3.7368260081510425`*^9, 3.7368290785666623`*^9, 
   3.7368292557142115`*^9, 3.74564972767177*^9, 3.745649862665474*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7337444057047606`*^9, 3.73406410394499*^9, 3.7342624770307474`*^9, 
   3.734327713995016*^9, 3.7343279742594657`*^9, 3.7343441324610577`*^9, 
   3.734856218999961*^9, 3.734863618877093*^9, 3.734864847665679*^9, 
   3.7348650052614193`*^9, 3.7348652840003195`*^9, {3.735469023257024*^9, 
   3.735469034328247*^9}, 3.735469076769101*^9, 3.735469115731891*^9, 
   3.7354691741181655`*^9, 3.7356239839911623`*^9, 3.7365905281695166`*^9, 
   3.7365908066171355`*^9, 3.7365908811837707`*^9, 3.736591827975147*^9, {
   3.736651141807008*^9, 3.73665116702853*^9}, 3.736654481332927*^9, 
   3.7366824439220743`*^9, {3.7366835066823397`*^9, 3.736683534330104*^9}, 
   3.7366837932999983`*^9, 3.7368260081510425`*^9, 3.7368290785666623`*^9, 
   3.7368292557142115`*^9, 3.74564972767177*^9, 3.7456498626754737`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7337444057047606`*^9, 3.73406410394499*^9, 3.7342624770307474`*^9, 
   3.734327713995016*^9, 3.7343279742594657`*^9, 3.7343441324610577`*^9, 
   3.734856218999961*^9, 3.734863618877093*^9, 3.734864847665679*^9, 
   3.7348650052614193`*^9, 3.7348652840003195`*^9, {3.735469023257024*^9, 
   3.735469034328247*^9}, 3.735469076769101*^9, 3.735469115731891*^9, 
   3.7354691741181655`*^9, 3.7356239839911623`*^9, 3.7365905281695166`*^9, 
   3.7365908066171355`*^9, 3.7365908811837707`*^9, 3.736591827975147*^9, {
   3.736651141807008*^9, 3.73665116702853*^9}, 3.736654481332927*^9, 
   3.7366824439220743`*^9, {3.7366835066823397`*^9, 3.736683534330104*^9}, 
   3.7366837932999983`*^9, 3.7368260081510425`*^9, 3.7368290785666623`*^9, 
   3.7368292557142115`*^9, 3.74564972767177*^9, 3.7456498626754737`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7337444057047606`*^9, 3.73406410394499*^9, 3.7342624770307474`*^9, 
   3.734327713995016*^9, 3.7343279742594657`*^9, 3.7343441324610577`*^9, 
   3.734856218999961*^9, 3.734863618877093*^9, 3.734864847665679*^9, 
   3.7348650052614193`*^9, 3.7348652840003195`*^9, {3.735469023257024*^9, 
   3.735469034328247*^9}, 3.735469076769101*^9, 3.735469115731891*^9, 
   3.7354691741181655`*^9, 3.7356239839911623`*^9, 3.7365905281695166`*^9, 
   3.7365908066171355`*^9, 3.7365908811837707`*^9, 3.736591827975147*^9, {
   3.736651141807008*^9, 3.73665116702853*^9}, 3.736654481332927*^9, 
   3.7366824439220743`*^9, {3.7366835066823397`*^9, 3.736683534330104*^9}, 
   3.7366837932999983`*^9, 3.7368260081510425`*^9, 3.7368290785666623`*^9, 
   3.7368292557142115`*^9, 3.74564972767177*^9, 3.7456498626754737`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7337444057047606`*^9, 3.73406410394499*^9, 3.7342624770307474`*^9, 
   3.734327713995016*^9, 3.7343279742594657`*^9, 3.7343441324610577`*^9, 
   3.734856218999961*^9, 3.734863618877093*^9, 3.734864847665679*^9, 
   3.7348650052614193`*^9, 3.7348652840003195`*^9, {3.735469023257024*^9, 
   3.735469034328247*^9}, 3.735469076769101*^9, 3.735469115731891*^9, 
   3.7354691741181655`*^9, 3.7356239839911623`*^9, 3.7365905281695166`*^9, 
   3.7365908066171355`*^9, 3.7365908811837707`*^9, 3.736591827975147*^9, {
   3.736651141807008*^9, 3.73665116702853*^9}, 3.736654481332927*^9, 
   3.7366824439220743`*^9, {3.7366835066823397`*^9, 3.736683534330104*^9}, 
   3.7366837932999983`*^9, 3.7368260081510425`*^9, 3.7368290785666623`*^9, 
   3.7368292557142115`*^9, 3.74564972767177*^9, 3.7456498627054744`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Level shifts for B = 0", "Subsubsection",
 CellChangeTimes->{{3.735469894839608*^9, 3.7354699018437486`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"MzNV1strainKelvincheck", " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sqrt", "[", 
   RowBox[{
    RowBox[{"MxNV1strainKelvincheck", "^", "2"}], "+", 
    RowBox[{"MyNV1strainKelvincheck", "^", "2"}]}], "]"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7354699063468404`*^9, 3.7354699350544224`*^9}, {
  3.7366835402226934`*^9, 3.7366835457012415`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "a2", " ", "C44", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xx", "+", "\[Epsilon]yy", "-", 
     RowBox[{"2", " ", "\[Epsilon]zz"}]}], ")"}]}], "+", 
  RowBox[{"a1", " ", 
   RowBox[{"(", 
    RowBox[{"C11", "+", 
     RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xx", "+", "\[Epsilon]yy", "+", "\[Epsilon]zz"}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.735469937074463*^9, 3.7366824439700794`*^9, 
  3.7366835472613974`*^9, 3.736826008201043*^9, 3.736829078616663*^9, 
  3.7368292557742124`*^9, 3.7456497277317715`*^9, 3.745649862715474*^9}],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]xy", "-", 
          RowBox[{
           SqrtBox["2"], " ", "\[Epsilon]xz"}]}], ")"}]}], "+", 
       RowBox[{"c", " ", "C44", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Epsilon]xy"}], "+", 
          RowBox[{
           SqrtBox["2"], " ", "\[Epsilon]xz"}]}], ")"}]}]}], ")"}], "2"]}], 
   "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "-", "C12"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xx", "-", "\[Epsilon]yy", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "c", " ", "C44", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xx", "-", "\[Epsilon]yy", "+", 
         RowBox[{
          SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ")"}]}]}], ")"}], 
    "2"]}]]], "Output",
 CellChangeTimes->{3.735469937074463*^9, 3.7366824439700794`*^9, 
  3.7366835472613974`*^9, 3.736826008201043*^9, 3.736829078616663*^9, 
  3.7368292557742124`*^9, 3.7456497277317715`*^9, 3.7456498633154864`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
For paper : Write down \[Epsilon]xyzNV1, obtained from \[Sigma]XYZNV1 for \
different stresses\
\>", "Subsubsection",
 CellChangeTimes->{{3.7356240051777143`*^9, 3.735624020019017*^9}, {
  3.735624061841858*^9, 3.7356240723000684`*^9}, {3.735624136749963*^9, 
  3.7356241397890253`*^9}}],

Cell["Stress tensors for different directions", "Text",
 CellChangeTimes->{{3.735624792733671*^9, 3.735624811366048*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fixedpar100", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]XX", "\[Rule]", "P"}], ",", 
     RowBox[{"\[Sigma]XY", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]XZ", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]YX", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]YY", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]YZ", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZX", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZY", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZZ", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fixedpar110", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]XX", "\[Rule]", 
      RowBox[{"P", "/", "2"}]}], ",", 
     RowBox[{"\[Sigma]XY", "\[Rule]", 
      RowBox[{"P", "/", "2"}]}], ",", 
     RowBox[{"\[Sigma]XZ", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]YX", "\[Rule]", 
      RowBox[{"P", " ", "0.5"}]}], ",", 
     RowBox[{"\[Sigma]YY", "\[Rule]", 
      RowBox[{"P", " ", "0.5"}]}], ",", 
     RowBox[{"\[Sigma]YZ", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZX", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZY", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZZ", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fixedpar111", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]XX", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]XY", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]XZ", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]YX", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]YY", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]YZ", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]ZX", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]ZY", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]ZZ", "\[Rule]", 
      RowBox[{"P", "/", "3"}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.735624475288974*^9, 3.73562455090154*^9}, {
  3.7356453500096083`*^9, 3.7356453634228773`*^9}}],

Cell["Calculate \[Epsilon]xyzKelvinNV1 ", "Text",
 CellChangeTimes->{{3.735624820203268*^9, 3.7356248304024754`*^9}, {
  3.7366830944461203`*^9, 3.7366830960802836`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]XYZKelvinNV1", "=", 
   RowBox[{"{", 
    RowBox[{
    "\[Sigma]XXK", ",", "\[Sigma]YYK", ",", "\[Sigma]ZZK", ",", "\[Sigma]YZK",
      ",", " ", "\[Sigma]XZK", ",", " ", "\[Sigma]XYK"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]xyzKelvinNV1", "=", 
   RowBox[{
    RowBox[{"LNV1passive6x6", ".", 
     RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", 
     "\[Sigma]XYZKelvinNV1"}], "//", "FullSimplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7356241451291323`*^9, 3.7356243110516186`*^9}, {
  3.73668285801848*^9, 3.736682859026581*^9}, {3.7366831001516905`*^9, 
  3.736683156242299*^9}, {3.7366835609727683`*^9, 3.736683567899461*^9}}],

Cell["Substitute stress tensor components", "Text",
 CellChangeTimes->{{3.735624840032668*^9, 3.735624854651991*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Kelvinnotation"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C11K", "\[Rule]", "C11"}], ",", 
   RowBox[{"C12K", "\[Rule]", "C12"}], ",", 
   RowBox[{"C44K", "\[Rule]", 
    RowBox[{"2", " ", "C44"}]}], ",", 
   RowBox[{"\[Epsilon]xxK", "\[Rule]", "\[Epsilon]xx"}], ",", 
   RowBox[{"\[Epsilon]yyK", "\[Rule]", "\[Epsilon]yy"}], ",", 
   RowBox[{"\[Epsilon]zzK", "\[Rule]", "\[Epsilon]zz"}], ",", 
   RowBox[{"\[Epsilon]yzK", "\[Rule]", 
    RowBox[{
     SqrtBox["2"], " ", "\[Epsilon]yz"}]}], ",", 
   RowBox[{"\[Epsilon]xzK", "\[Rule]", 
    RowBox[{
     SqrtBox["2"], " ", "\[Epsilon]xz"}]}], ",", 
   RowBox[{"\[Epsilon]xyK", "\[Rule]", 
    RowBox[{
     SqrtBox["2"], " ", "\[Epsilon]xy"}]}], ",", 
   RowBox[{"\[Sigma]XXK", "\[Rule]", "\[Sigma]XX"}], ",", 
   RowBox[{"\[Sigma]YYK", "\[Rule]", "\[Sigma]YY"}], ",", 
   RowBox[{"\[Sigma]ZZK", "\[Rule]", "\[Sigma]ZZ"}], ",", 
   RowBox[{"\[Sigma]YZK", "\[Rule]", 
    RowBox[{
     SqrtBox["2"], " ", "\[Sigma]YZ"}]}], ",", 
   RowBox[{"\[Sigma]XZK", "\[Rule]", 
    RowBox[{
     SqrtBox["2"], " ", "\[Sigma]XZ"}]}], ",", 
   RowBox[{"\[Sigma]XYK", "\[Rule]", 
    RowBox[{
     SqrtBox["2"], " ", "\[Sigma]XY"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7366836379444647`*^9, 3.7366837235970287`*^9, 
  3.7366837985375223`*^9, 3.736826009971079*^9, 3.736829079786687*^9, 
  3.736829256904235*^9, 3.7456497295118074`*^9, 3.7456498644865103`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV1MatrixForm", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", 
       RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", "  ", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "  ", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ",", " ", 
       RowBox[{"\[Epsilon]xyzKelvinNV1", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Epsilon]xyzNV1100", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Epsilon]xyzNV1MatrixForm", "/.", "Kelvinnotation"}], "/.", 
    "fixedpar100"}], "//", "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Epsilon]xyzNV1110", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Epsilon]xyzNV1MatrixForm", "/.", "Kelvinnotation"}], "/.", 
    "fixedpar110"}], "//", "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Epsilon]xyzNV1111", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Epsilon]xyzNV1MatrixForm", "/.", "Kelvinnotation"}], "/.", 
    "fixedpar111"}], "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.735624325144904*^9, 3.735624438889241*^9}, {
  3.7356245591707463`*^9, 3.735624611127843*^9}, {3.7356255813213663`*^9, 
  3.7356255863295674`*^9}, {3.736683580615732*^9, 3.7366836251361837`*^9}, {
  3.736684658480508*^9, 3.7366847083304925`*^9}, {3.7366847634640055`*^9, 
  3.736684767349394*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C11", " ", "P"}], 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["C11", "2"]}], "+", 
       RowBox[{"2", " ", "C11", " ", "C12"}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["C12", "2"]}]}]], ",", 
     FractionBox["P", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "C11"}], "-", 
         RowBox[{"2", " ", "C12"}]}], ")"}]}]], ",", 
     RowBox[{"-", 
      FractionBox["P", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["P", 
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "C11"}], "-", 
         RowBox[{"2", " ", "C12"}]}], ")"}]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", 
         RowBox[{"4", " ", "C12"}]}], ")"}], " ", "P"}], 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "-", "C12"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}]}]], ",", 
     RowBox[{"-", 
      FractionBox["P", 
       RowBox[{"3", " ", 
        SqrtBox["2"], " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["P", 
       RowBox[{
        SqrtBox["6"], " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}]]}], ",", 
     RowBox[{"-", 
      FractionBox["P", 
       RowBox[{"3", " ", 
        SqrtBox["2"], " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}]]}], ",", 
     FractionBox["P", 
      RowBox[{
       RowBox[{"3", " ", "C11"}], "+", 
       RowBox[{"6", " ", "C12"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.735624490164276*^9, 3.7356245023795233`*^9}, {
   3.7356245667708983`*^9, 3.7356246115378513`*^9}, 3.7356255867595844`*^9, 
   3.7356453692029924`*^9, 3.736682445299212*^9, 3.736683598458516*^9, 
   3.7366836285605264`*^9, 3.736683732818951*^9, 3.7366838074324117`*^9, 
   3.736684486434305*^9, {3.7366846599136515`*^9, 3.736684712047864*^9}, {
   3.7366847578874474`*^9, 3.736684768566516*^9}, 3.736826010061081*^9, 
   3.7368290798666887`*^9, 3.736829256994237*^9, 3.7456497295818086`*^9, 
   3.7456498645665116`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.25`"}], " ", 
          SuperscriptBox["C11", "2"]}], "-", 
         RowBox[{"0.25`", " ", "C11", " ", "C12"}], "+", 
         RowBox[{"0.5`", " ", 
          SuperscriptBox["C12", "2"]}], "+", 
         RowBox[{"0.5`", " ", "C11", " ", "C44"}]}], ")"}], " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["C11", "2"], "+", 
         RowBox[{"C11", " ", "C12"}], "-", 
         RowBox[{"2.`", " ", 
          SuperscriptBox["C12", "2"]}]}], ")"}], " ", "C44"}]], ",", "0.`", 
     ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"0.08333333333333333`", " ", 
          SuperscriptBox["C11", "2"]}], "+", 
         RowBox[{"0.08333333333333333`", " ", "C11", " ", "C12"}], "-", 
         RowBox[{"0.16666666666666666`", " ", 
          SuperscriptBox["C12", "2"]}], "+", 
         RowBox[{"0.16666666666666666`", " ", "C11", " ", "C44"}], "-", 
         RowBox[{"0.6666666666666666`", " ", "C12", " ", "C44"}]}], ")"}], 
       " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", 
         RowBox[{"1.`", " ", "C12"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2.`", " ", "C12"}]}], ")"}], " ", "C44"}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.11785113019775792`"}], " ", "C11"}], "+", 
         RowBox[{"0.11785113019775792`", " ", "C12"}], "-", 
         RowBox[{"0.23570226039551584`", " ", "C44"}]}], ")"}], " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", 
         RowBox[{"1.`", " ", "C12"}]}], ")"}], " ", "C44"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.11785113019775792`"}], " ", "C11"}], "+", 
         RowBox[{"0.11785113019775792`", " ", "C12"}], "-", 
         RowBox[{"0.23570226039551584`", " ", "C44"}]}], ")"}], " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", 
         RowBox[{"1.`", " ", "C12"}]}], ")"}], " ", "C44"}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"0.16666666666666666`", " ", "C11"}], "+", 
         RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
         RowBox[{"0.3333333333333333`", " ", "C44"}]}], ")"}], " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2.`", " ", "C12"}]}], ")"}], " ", "C44"}]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.735624490164276*^9, 3.7356245023795233`*^9}, {
   3.7356245667708983`*^9, 3.7356246115378513`*^9}, 3.7356255867595844`*^9, 
   3.7356453692029924`*^9, 3.736682445299212*^9, 3.736683598458516*^9, 
   3.7366836285605264`*^9, 3.736683732818951*^9, 3.7366838074324117`*^9, 
   3.736684486434305*^9, {3.7366846599136515`*^9, 3.736684712047864*^9}, {
   3.7366847578874474`*^9, 3.736684768566516*^9}, 3.736826010061081*^9, 
   3.7368290798666887`*^9, 3.736829256994237*^9, 3.7456497295818086`*^9, 
   3.7456498646165123`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", " ", "C12"}], "-", 
          RowBox[{"2", " ", "C44"}]}], ")"}], " ", "P"}], 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]]}], ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", " ", "C12"}], "-", 
          RowBox[{"2", " ", "C44"}]}], ")"}], " ", "P"}], 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}], "+", "C44"}], ")"}], " ", "P"}], 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.735624490164276*^9, 3.7356245023795233`*^9}, {
   3.7356245667708983`*^9, 3.7356246115378513`*^9}, 3.7356255867595844`*^9, 
   3.7356453692029924`*^9, 3.736682445299212*^9, 3.736683598458516*^9, 
   3.7366836285605264`*^9, 3.736683732818951*^9, 3.7366838074324117`*^9, 
   3.736684486434305*^9, {3.7366846599136515`*^9, 3.736684712047864*^9}, {
   3.7366847578874474`*^9, 3.736684768566516*^9}, 3.736826010061081*^9, 
   3.7368290798666887`*^9, 3.736829256994237*^9, 3.7456497295818086`*^9, 
   3.745649864646513*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV1100Paper", "=", " ", 
   RowBox[{
    RowBox[{"epsilon", "*", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Nu]"}], ")"}], "/", "2"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "\[Nu]"}], ")"}], "/", 
          RowBox[{"Sqrt", "[", "12", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "/", 
          RowBox[{"Sqrt", "[", "6", "]"}]}]}], " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "\[Nu]"}], ")"}], "/", 
          RowBox[{"Sqrt", "[", "12", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"5", "\[Nu]"}]}], ")"}], "/", "6"}], ",", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "/", 
          RowBox[{"Sqrt", "[", "18", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "/", 
          RowBox[{"Sqrt", "[", "6", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "/", 
          RowBox[{"Sqrt", "[", "18", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", "\[Nu]"}]}], ")"}], "/", "3"}]}], "}"}]}], "}"}]}], "//",
     "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV1110Paper", " ", "=", " ", 
   RowBox[{
    RowBox[{"epsilon", "*", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[Gamma]"}], 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", "\[Nu]"}]}], ")"}]}], "+", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", "\[Nu]"}], ")"}]}]}], ")"}], "/", "4"}], ",", 
         "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Gamma]", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", "\[Nu]"}]}], ")"}]}], "+", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"5", "\[Nu]"}]}], ")"}]}]}], ")"}], "/", "12"}], ",", 
         " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Gamma]", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", "\[Nu]"}]}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}]}], "*", 
          RowBox[{
           RowBox[{"Sqrt", "[", "2", "]"}], "/", "12"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Gamma]", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", "\[Nu]"}]}], ")"}]}], "+", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}]}], "*", 
          RowBox[{
           RowBox[{"Sqrt", "[", "2", "]"}], "/", "12"}]}], ",", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Gamma]", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", "\[Nu]"}]}], ")"}]}], "+", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", "\[Nu]"}]}], ")"}]}]}], ")"}], "/", "6"}]}], 
        "}"}]}], "}"}]}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV1111Paper", " ", "=", " ", 
   RowBox[{
    RowBox[{"epsilon", "*", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Gamma]", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", "\[Nu]"}]}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", "\[Nu]"}]}], ")"}]}]}], ")"}]}], "/", "6"}], ",",
          "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Gamma]", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", "\[Nu]"}]}], ")"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", "\[Nu]"}]}], ")"}]}]}], ")"}]}], "/", "6"}], ",",
          "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Gamma]", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", "\[Nu]"}]}], ")"}]}], "+", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", "\[Nu]"}]}], ")"}]}], ")"}], "/", "3"}]}], "}"}]}],
       "}"}]}], "//", "FullSimplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7356243547505016`*^9, 3.735624355240512*^9}, {
   3.7356250459488525`*^9, 3.7356250482091913`*^9}, {3.7356255741160765`*^9, 
   3.735625592784827*^9}, {3.735626650616691*^9, 3.735626656636845*^9}, {
   3.735626710153311*^9, 3.7356269330591393`*^9}, {3.7356269749049845`*^9, 
   3.7356270546736956`*^9}, {3.7356270920044465`*^9, 3.735627179278262*^9}, {
   3.735627215321992*^9, 3.735627224396174*^9}, {3.7356273415766816`*^9, 
   3.735627343526724*^9}, {3.735631709313425*^9, 3.735631713816518*^9}, {
   3.735631766503579*^9, 3.7356317672535944`*^9}, {3.735645249740595*^9, 
   3.735645263907879*^9}, {3.7356474038561287`*^9, 3.7356476312906847`*^9}, {
   3.735647829844802*^9, 3.735647850103207*^9}, {3.7356479089913883`*^9, 
   3.7356479110974307`*^9}, {3.735648126988796*^9, 3.7356482025863495`*^9}, {
   3.735648281546932*^9, 3.7356482849069996`*^9}, {3.73564833834807*^9, 
   3.7356483405781145`*^9}, 3.7356485364856496`*^9, {3.7366841491665816`*^9, 
   3.736684161232788*^9}}],

Cell["Checking expressions", "Text",
 CellChangeTimes->{{3.7356273471518*^9, 3.7356273522649064`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzNV1100", "==", "\[Epsilon]xyzNV1100Paper"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"epsilon", "\[Rule]", 
      RowBox[{"P", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"E", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", "C12"}], ")"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", " ", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzNV1110", "==", "\[Epsilon]xyzNV1110Paper"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"epsilon", "\[Rule]", 
      RowBox[{"P", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"E", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", "C12"}], ")"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", " ", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzNV1111", "==", "\[Epsilon]xyzNV1111Paper"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"epsilon", "\[Rule]", 
      RowBox[{"P", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"E", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", "C12"}], ")"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", " ", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.735645278971182*^9, 3.735645280767218*^9}, {
   3.735647638304865*^9, 3.7356476437959747`*^9}, {3.7356477080233035`*^9, 
   3.735647762041443*^9}, 3.7356479238756866`*^9, {3.7356482096394906`*^9, 
   3.735648238433067*^9}, {3.735648298177265*^9, 3.7356482982972674`*^9}, {
   3.73564851250417*^9, 3.7356485428877788`*^9}, {3.736684165000165*^9, 
   3.7366841721688814`*^9}, {3.736684202775942*^9, 3.7366842114628105`*^9}, {
   3.736684506898351*^9, 3.7366845151321745`*^9}, 3.7366845758772483`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7356452828972607`*^9, 3.7356476445159893`*^9, {3.73564771882652*^9, 
   3.735647762301448*^9}, {3.7356478343348913`*^9, 3.7356478528832636`*^9}, {
   3.735647913777484*^9, 3.7356479251757126`*^9}, {3.735648213901576*^9, 
   3.7356482387330728`*^9}, {3.735648290017102*^9, 3.7356482988072777`*^9}, 
   3.7356483440861855`*^9, {3.7356485158942375`*^9, 3.7356485441478043`*^9}, 
   3.7366824460082827`*^9, {3.7366841729269576`*^9, 3.736684206312296*^9}, {
   3.7366844949801598`*^9, 3.7366845101116724`*^9}, 3.7366848104387026`*^9, 
   3.736826010331086*^9, 3.7368290801066933`*^9, 3.7368292572342415`*^9, 
   3.7456497298118134`*^9, 3.745649864776516*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7356452828972607`*^9, 3.7356476445159893`*^9, {3.73564771882652*^9, 
   3.735647762301448*^9}, {3.7356478343348913`*^9, 3.7356478528832636`*^9}, {
   3.735647913777484*^9, 3.7356479251757126`*^9}, {3.735648213901576*^9, 
   3.7356482387330728`*^9}, {3.735648290017102*^9, 3.7356482988072777`*^9}, 
   3.7356483440861855`*^9, {3.7356485158942375`*^9, 3.7356485441478043`*^9}, 
   3.7366824460082827`*^9, {3.7366841729269576`*^9, 3.736684206312296*^9}, {
   3.7366844949801598`*^9, 3.7366845101116724`*^9}, 3.7366848104387026`*^9, 
   3.736826010331086*^9, 3.7368290801066933`*^9, 3.7368292572342415`*^9, 
   3.7456497298118134`*^9, 3.7456498648065166`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7356452828972607`*^9, 3.7356476445159893`*^9, {3.73564771882652*^9, 
   3.735647762301448*^9}, {3.7356478343348913`*^9, 3.7356478528832636`*^9}, {
   3.735647913777484*^9, 3.7356479251757126`*^9}, {3.735648213901576*^9, 
   3.7356482387330728`*^9}, {3.735648290017102*^9, 3.7356482988072777`*^9}, 
   3.7356483440861855`*^9, {3.7356485158942375`*^9, 3.7356485441478043`*^9}, 
   3.7366824460082827`*^9, {3.7366841729269576`*^9, 3.736684206312296*^9}, {
   3.7366844949801598`*^9, 3.7366845101116724`*^9}, 3.7366848104387026`*^9, 
   3.736826010331086*^9, 3.7368290801066933`*^9, 3.7368292572342415`*^9, 
   3.7456497298118134`*^9, 3.745649864816517*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.5.6 Strain - induced level shifts (in terms of stress tensor components \
\[Sigma]IJ)\
\>", "Subsection",
 CellChangeTimes->{{3.733745746542821*^9, 3.733745764637183*^9}, {
   3.734327938449674*^9, 3.7343279385696764`*^9}, {3.73434412174684*^9, 
   3.734344121856842*^9}, {3.734345973215615*^9, 3.734345985611868*^9}, 
   3.73434688983347*^9, {3.7348482172013607`*^9, 3.734848217461366*^9}, {
   3.734858451601791*^9, 3.7348584516717925`*^9}, {3.7368252977463813`*^9, 
   3.7368252978663836`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "\[Sigma]XYZKelvin", "]"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]XYZKelvin", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "\[Sigma]XXK", ",", "\[Sigma]YYK", ",", "\[Sigma]ZZK", ",", "\[Sigma]YZK",
      ",", "\[Sigma]XZK", ",", "\[Sigma]XYK"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fixedpar100", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]XX", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Sigma]XY", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]XZ", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]YX", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]YY", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]YZ", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZX", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZY", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZZ", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fixedpar110", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]XX", "\[Rule]", "0.5"}], ",", 
     RowBox[{"\[Sigma]XY", "\[Rule]", "0.5"}], ",", 
     RowBox[{"\[Sigma]XZ", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]YX", "\[Rule]", "0.5"}], ",", 
     RowBox[{"\[Sigma]YY", "\[Rule]", "0.5"}], ",", 
     RowBox[{"\[Sigma]YZ", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZX", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZY", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Sigma]ZZ", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fixedpar111", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]XX", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]XY", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]XZ", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]YX", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]YY", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]YZ", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]ZX", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]ZY", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"\[Sigma]ZZ", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7337461883087044`*^9, 3.7337462726153936`*^9}, {
  3.733746332415632*^9, 3.733746334226668*^9}, {3.7337466140864067`*^9, 
  3.7337466143464117`*^9}, {3.733747456236519*^9, 3.7337474927003093`*^9}, {
  3.7340665209916244`*^9, 3.7340665354369164`*^9}, {3.7343262517434196`*^9, 
  3.734326254303471*^9}, {3.7343262958853254`*^9, 3.7343262976653605`*^9}, {
  3.734326509346695*^9, 3.734326515213827*^9}, {3.7343265646728244`*^9, 
  3.73432658371122*^9}, {3.73432694277956*^9, 3.734326946937645*^9}, {
  3.7343314407335606`*^9, 3.7343314778103437`*^9}, {3.7343316566010113`*^9, 
  3.7343316629181433`*^9}, {3.734331852703031*^9, 3.7343318554830866`*^9}, {
  3.734344009719591*^9, 3.7343440101796002`*^9}, {3.7367424804435654`*^9, 
  3.7367425062660832`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Approach: NV1 - 4 (starting with Mxyz with \[Epsilon]xyzNV1 and replacing \
\[Epsilon]ij = L_NVk.Inverse[CXYZMandel].\[Sigma]XYZ)\
\>", "Subsubsection",
 CellChangeTimes->{{3.7340622899585466`*^9, 3.734062301902787*^9}, {
  3.7340634373685617`*^9, 3.7340634774363656`*^9}, {3.7340640173482103`*^9, 
  3.7340640647171645`*^9}, {3.7343489626808805`*^9, 3.734348966200951*^9}, {
  3.736825505601539*^9, 3.7368255063415537`*^9}}],

Cell["\<\
Approach: Same as for \[Sigma]IJNVk in 2.3
1) Calculate \[Epsilon]xyzNV1-4 from \[Sigma]XYZ by using \
LNVkpassive6x6.Inverse[CXYZKelvin].\[Sigma]XYZKelvin
2) Replace \[Epsilon]ij in Mx,My,Mz from NV1 (see 2.5.5)
3) Obtain strain-induced level shifts in terms of spin-strain coupling \
constants and strain amplitude \[Epsilon]\
\>", "Text",
 CellChangeTimes->{{3.734065695627016*^9, 3.7340657737675834`*^9}, {
  3.734847872664012*^9, 3.7348479288872967`*^9}, {3.7348481134042287`*^9, 
  3.734848132956622*^9}, {3.7367425226964116`*^9, 3.7367425281055202`*^9}}],

Cell["NV1", "Text",
 CellChangeTimes->{{3.734064067611262*^9, 3.7340640700113096`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"LNV1passive6x6", ".", 
     RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", "\[Sigma]XYZKelvin"}], 
    "/.", "Kelvinnotation"}], "//", "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"MxNV1calc", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"B", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", 
       RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], " ", "+", " ", 
    RowBox[{"2", " ", "C", " ", 
     RowBox[{
      RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "[", 
       RowBox[{"[", "4", "]"}], "]"}], "/", 
      RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//", "FullSimplify"}]}], "\n", 
 RowBox[{"MyNV1calc", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "B", " ", 
     RowBox[{
      RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "[", 
       RowBox[{"[", "6", "]"}], "]"}], "/", 
      RowBox[{"Sqrt", "[", "2", "]"}]}]}], "-", " ", 
    RowBox[{"2", " ", "C", " ", 
     RowBox[{
      RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "/", 
      RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//", "FullSimplify"}]}], "\n", 
 RowBox[{"MzNV1calc", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"A1", " ", 
     RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], " ", "+", " ", 
    RowBox[{"A2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "  ", "+", " ", 
       RowBox[{"\[Epsilon]xyzNV1Kelvincalc2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}]}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.734064162030156*^9, 3.7340641875387096`*^9}, {
  3.734064223772436*^9, 3.7340642470399036`*^9}, {3.7340642795055532`*^9, 
  3.7340643150902667`*^9}, {3.73434403094702*^9, 3.7343440731528673`*^9}, {
  3.734344156099533*^9, 3.734344183684086*^9}, {3.7343461937966843`*^9, 
  3.734346198936787*^9}, {3.7348594136867647`*^9, 3.7348594281610703`*^9}, {
  3.7367425481259212`*^9, 3.736742591655794*^9}, {3.73674263832873*^9, 
  3.736742641588795*^9}, {3.736742699506956*^9, 3.7367427025270166`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"C11", " ", "C44", " ", "\[Sigma]XX"}], "-", 
     RowBox[{
      SuperscriptBox["C11", "2"], " ", "\[Sigma]XY"}], "-", 
     RowBox[{"C11", " ", "C12", " ", "\[Sigma]XY"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["C12", "2"], " ", "\[Sigma]XY"}], "+", 
     RowBox[{"C11", " ", "C44", " ", "\[Sigma]YY"}], "-", 
     RowBox[{"2", " ", "C12", " ", "C44", " ", "\[Sigma]ZZ"}]}], 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["C11", "2"], " ", "C44"}], "+", 
     RowBox[{"2", " ", "C11", " ", "C12", " ", "C44"}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["C12", "2"], " ", "C44"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["C11", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XY", "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "C12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C12", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XY"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"C44", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY"}], ")"}]}], "+", 
           "\[Sigma]ZZ"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"C11", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C12", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XY", "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"C44", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", 
           RowBox[{"4", " ", "\[Sigma]ZZ"}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{"C11", "-", "C12"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"C11", "+", 
       RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"C11", "+", 
        RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XY", "+", "\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}], 
     "+", 
     RowBox[{"C44", " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
       ")"}]}]}], 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"C11", "+", 
       RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", "C12"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "-", 
         "\[Sigma]YZ"}], ")"}]}], "+", 
      RowBox[{"2", " ", "C44", " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "-", 
         RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}], 
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{"C11", "-", "C12"}], ")"}], " ", "C44"}]]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], 
       RowBox[{"C11", "-", "C12"}]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "\[Sigma]XZ"}], "+", "\[Sigma]YZ"}], "C44"]}], 
    RowBox[{"2", " ", 
     SqrtBox["3"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], 
      RowBox[{"C11", "-", "C12"}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "\[Sigma]XZ"}], "+", "\[Sigma]YZ"}], "C44"]}], 
    SqrtBox["6"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.734859414103775*^9, 3.7348594286310797`*^9}, 
   3.7366824540960913`*^9, {3.736742610858178*^9, 3.7367426420588045`*^9}, {
   3.736742690646777*^9, 3.7367427126282196`*^9}, 3.7368260110411005`*^9, 
   3.736829080746706*^9, 3.7368292578942547`*^9, 3.745649730481827*^9, 
   3.745649865336527*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "B"}], "+", 
         RowBox[{
          SqrtBox["2"], " ", "C"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "-", 
         "\[Sigma]YZ"}], ")"}]}], "C44"]}], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"B", "-", 
        RowBox[{
         SqrtBox["2"], " ", "C"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "-", 
        RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}], 
     RowBox[{"C11", "-", "C12"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.734859414103775*^9, 3.7348594286310797`*^9}, 
   3.7366824540960913`*^9, {3.736742610858178*^9, 3.7367426420588045`*^9}, {
   3.736742690646777*^9, 3.7367427126282196`*^9}, 3.7368260110411005`*^9, 
   3.736829080746706*^9, 3.7368292578942547`*^9, 3.745649730481827*^9, 
   3.7456498658065367`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"C", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], 
         RowBox[{"C11", "-", "C12"}]]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "\[Sigma]XZ"}], "+", "\[Sigma]YZ"}], "C44"]}], ")"}]}], 
    SqrtBox["6"]]}], "-", 
  FractionBox[
   RowBox[{"B", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], 
       RowBox[{"C11", "-", "C12"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "\[Sigma]XZ"}], "+", "\[Sigma]YZ"}], "C44"]}], ")"}]}], 
   SqrtBox["3"]]}]], "Output",
 CellChangeTimes->{{3.734859414103775*^9, 3.7348594286310797`*^9}, 
   3.7366824540960913`*^9, {3.736742610858178*^9, 3.7367426420588045`*^9}, {
   3.736742690646777*^9, 3.7367427126282196`*^9}, 3.7368260110411005`*^9, 
   3.736829080746706*^9, 3.7368292578942547`*^9, 3.745649730481827*^9, 
   3.7456498661465435`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"A1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]XY", "+", "\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}],
       "+", 
      RowBox[{"C44", " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
        ")"}]}]}], ")"}]}], "+", 
   RowBox[{"A2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", " ", "C12"}]}], ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]XY", "+", "\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}],
       "+", 
      RowBox[{"2", " ", "C44", " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
        ")"}]}]}], ")"}]}]}], 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"C11", "+", 
     RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]]], "Output",
 CellChangeTimes->{{3.734859414103775*^9, 3.7348594286310797`*^9}, 
   3.7366824540960913`*^9, {3.736742610858178*^9, 3.7367426420588045`*^9}, {
   3.736742690646777*^9, 3.7367427126282196`*^9}, 3.7368260110411005`*^9, 
   3.736829080746706*^9, 3.7368292578942547`*^9, 3.745649730481827*^9, 
   3.7456498663165464`*^9}]
}, Open  ]],

Cell["NV2", "Text",
 CellChangeTimes->{{3.7340643239184837`*^9, 3.7340643349297047`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"LNV1passive6x6", ".", "KNV2passive6x6"}], " ", "\[Equal]", " ", 
   "LNV2passive6x6"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.734342514174773*^9, 3.7343425195008802`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7343425200808916`*^9, 3.734344133871086*^9, 
  3.734858401292725*^9, 3.736682454723154*^9, 3.7368260120611205`*^9, 
  3.7368290817667265`*^9, 3.736829258944276*^9, 3.745649731601849*^9, 
  3.7456498663565474`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"LNV1passive6x6", ".", "KNV2passive6x6", ".", 
      RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", "\[Sigma]XYZKelvin"}],
      "/.", "Kelvinnotation"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV2calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"B", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "[", 
         RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", 
        RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], " ", "+", " ", 
     RowBox[{"2", " ", "C", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"MyNV2calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "B", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "[", 
        RowBox[{"[", "6", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}], "-", " ", 
     RowBox[{"2", " ", "C", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "[", 
        RowBox[{"[", "5", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"MzNV2calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"A1", " ", 
      RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], " ", "+", " ", 
     RowBox[{"A2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "  ", "+", " ", 
        RowBox[{"\[Epsilon]xyzNV2Kelvincalc2", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7340643467709413`*^9, 3.734064364364295*^9}, {
   3.7343424718509245`*^9, 3.734342492806345*^9}, {3.734344185701127*^9, 
   3.7343441900122137`*^9}, 3.7343465339207354`*^9, 3.7343489276801753`*^9, {
   3.736742759668163*^9, 3.736742790027771*^9}}],

Cell["NV3", "Text",
 CellChangeTimes->{{3.7340643267385406`*^9, 3.734064336610738*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"LNV3passive6x6", ".", 
      RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", "\[Sigma]XYZKelvin"}],
      "/.", "Kelvinnotation"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV3calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"B", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "[", 
         RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", 
        RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], " ", "+", " ", 
     RowBox[{"2", " ", "C", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"MyNV3calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "B", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "[", 
        RowBox[{"[", "6", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}], "-", " ", 
     RowBox[{"2", " ", "C", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "[", 
        RowBox[{"[", "5", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"MzNV3calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"A1", " ", 
      RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], " ", "+", " ", 
     RowBox[{"A2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "  ", "+", " ", 
        RowBox[{"\[Epsilon]xyzNV3Kelvincalc2", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7340643666343403`*^9, 3.734064381417638*^9}, 
   3.734331817995329*^9, {3.734344191292239*^9, 3.7343441929422736`*^9}, 
   3.7343489298302183`*^9, {3.7367427984189386`*^9, 3.736742823913449*^9}, 
   3.736742861163195*^9}],

Cell["NV4", "Text",
 CellChangeTimes->{{3.7340643284385743`*^9, 3.7340643373807535`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"LNV4passive6x6", ".", 
      RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", "\[Sigma]XYZKelvin"}],
      "/.", "Kelvinnotation"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MxNV4calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"B", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "[", 
         RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", 
        RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], " ", "+", " ", 
     RowBox[{"2", " ", "C", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"MyNV4calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "B", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "[", 
        RowBox[{"[", "6", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}], "-", " ", 
     RowBox[{"2", " ", "C", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "[", 
        RowBox[{"[", "5", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"MzNV4calc", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"A1", " ", 
      RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], " ", "+", " ", 
     RowBox[{"A2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "  ", "+", " ", 
        RowBox[{"\[Epsilon]xyzNV4Kelvincalc2", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7340643847877054`*^9, 3.7340644017700453`*^9}, {
   3.73433181003517*^9, 3.7343318172453136`*^9}, {3.7343441954783263`*^9, 
   3.734344196684351*^9}, 3.7343489309702406`*^9, {3.73485967876031*^9, 
   3.734859684805435*^9}, {3.7367428315116014`*^9, 3.7367428626432247`*^9}}],

Cell["Calculate level shifts", "Text",
 CellChangeTimes->{{3.733746659702319*^9, 3.7337466692325096`*^9}, {
  3.7343489695520215`*^9, 3.7343489750071306`*^9}, {3.7343493781744366`*^9, 
  3.734349385714587*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"comp100calc", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"P", "*", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV1calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV1calc", "^", "2"}]}], "]"}], ",", " ", "MzNV1calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV2calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV2calc", "^", "2"}]}], "]"}], ",", " ", "MzNV2calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV3calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV3calc", "^", "2"}]}], "]"}], ",", " ", "MzNV3calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV4calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV4calc", "^", "2"}]}], "]"}], ",", " ", "MzNV4calc"}],
          "}"}]}], "}"}]}], "/.", "fixedpar100"}], "//", "FullSimplify"}], "//",
    "TableForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"comp110calc", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"P", "*", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV1calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV1calc", "^", "2"}]}], "]"}], ",", " ", "MzNV1calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV2calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV2calc", "^", "2"}]}], "]"}], ",", " ", "MzNV2calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV3calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV3calc", "^", "2"}]}], "]"}], ",", " ", "MzNV3calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV4calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV4calc", "^", "2"}]}], "]"}], ",", " ", "MzNV4calc"}],
          "}"}]}], "}"}]}], "/.", "fixedpar110"}], "//", "FullSimplify"}], "//",
    "TableForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"comp111calc", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"P", "*", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV1calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV1calc", "^", "2"}]}], "]"}], ",", " ", "MzNV1calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV2calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV2calc", "^", "2"}]}], "]"}], ",", " ", "MzNV2calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV3calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV3calc", "^", "2"}]}], "]"}], ",", " ", "MzNV3calc"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"MxNV4calc", "^", "2"}], "+", " ", 
            RowBox[{"MyNV4calc", "^", "2"}]}], "]"}], ",", " ", "MzNV4calc"}],
          "}"}]}], "}"}]}], "/.", "fixedpar111"}], "//", "FullSimplify"}], "//",
    "TableForm"}]}]}], "Input",
 CellChangeTimes->{{3.734064514718357*^9, 3.734064552057106*^9}, {
  3.7343442066665516`*^9, 3.7343442358811398`*^9}, {3.7343493122970915`*^9, 
  3.734349315308153*^9}, {3.734690183714966*^9, 3.734690190958118*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      FractionBox["2", "3"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["B", "2"], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "B", " ", "C"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["C", "2"]}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], "2"]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"A1", "+", 
         RowBox[{"2", " ", "A2"}]}], ")"}], " ", "P"}], 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}]}]]},
    {
     RowBox[{
      FractionBox["2", "3"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["B", "2"], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "B", " ", "C"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["C", "2"]}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], "2"]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"A1", "+", 
         RowBox[{"2", " ", "A2"}]}], ")"}], " ", "P"}], 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}]}]]},
    {
     RowBox[{
      FractionBox["2", "3"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["B", "2"], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "B", " ", "C"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["C", "2"]}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], "2"]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"A1", "+", 
         RowBox[{"2", " ", "A2"}]}], ")"}], " ", "P"}], 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}]}]]},
    {
     RowBox[{
      FractionBox["2", "3"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["B", "2"], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "B", " ", "C"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["C", "2"]}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], "2"]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"A1", "+", 
         RowBox[{"2", " ", "A2"}]}], ")"}], " ", "P"}], 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}]}]]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.733746729204711*^9, 3.7337471386891055`*^9, 
  3.7337477878643255`*^9, 3.7340644930118837`*^9, 3.734064554697159*^9, 
  3.7343317045400143`*^9, 3.7343318807536073`*^9, 3.7343319957775707`*^9, 
  3.7343425004364977`*^9, 3.734344136990149*^9, 3.734344237071163*^9, 
  3.7343493157381616`*^9, 3.7346901921781425`*^9, 3.7348584034407787`*^9, 
  3.736682459270609*^9, 3.736742876595504*^9, 3.736826015791195*^9, 
  3.736829085386799*^9, 3.7368292624873466`*^9, 3.745649735441926*^9, 
  3.745649869936619*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      FractionBox["1", "6"], " ", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"2.`", " ", "B"}], "-", 
            RowBox[{"2.8284271247461903`", " ", "C"}]}], 
           RowBox[{"C11", "-", 
            RowBox[{"1.`", " ", "C12"}]}]], "+", 
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "2.`"}], " ", "B"}], "-", 
            RowBox[{"1.4142135623730951`", " ", "C"}]}], "C44"]}], ")"}], 
        "2"]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"0.16666666666666666`", " ", "C11"}], "+", 
            RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
            RowBox[{"0.3333333333333333`", " ", "C44"}]}], ")"}]}], "+", 
         RowBox[{"A2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.16666666666666666`"}], " ", "C11"}], "-", 
            RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
            RowBox[{"0.6666666666666666`", " ", "C44"}]}], ")"}]}]}], ")"}], 
       " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2.`", " ", "C12"}]}], ")"}], " ", "C44"}]]},
    {
     RowBox[{"0.3333333333333333`", " ", 
      SqrtBox[
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1.`", " ", "B", " ", "C11"}], "+", 
           RowBox[{"0.7071067811865476`", " ", "C", " ", "C11"}], "-", 
           RowBox[{"1.`", " ", "B", " ", "C12"}], "-", 
           RowBox[{"0.7071067811865476`", " ", "C", " ", "C12"}], "-", 
           RowBox[{"1.`", " ", "B", " ", "C44"}], "+", 
           RowBox[{"1.4142135623730951`", " ", "C", " ", "C44"}]}], ")"}], 
         "2"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"C11", "-", 
            RowBox[{"1.`", " ", "C12"}]}], ")"}], "2"], " ", 
         SuperscriptBox["C44", "2"]}]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"0.16666666666666666`", " ", "C11"}], "+", 
            RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
            RowBox[{"0.3333333333333333`", " ", "C44"}]}], ")"}]}], "+", 
         RowBox[{"A2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.16666666666666666`"}], " ", "C11"}], "-", 
            RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
            RowBox[{"0.6666666666666666`", " ", "C44"}]}], ")"}]}]}], ")"}], 
       " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2.`", " ", "C12"}]}], ")"}], " ", "C44"}]]},
    {
     RowBox[{"0.3333333333333333`", " ", 
      SqrtBox[
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1.`", " ", "B", " ", "C11"}], "+", 
           RowBox[{"0.7071067811865476`", " ", "C", " ", "C11"}], "-", 
           RowBox[{"1.`", " ", "B", " ", "C12"}], "-", 
           RowBox[{"0.7071067811865476`", " ", "C", " ", "C12"}], "+", 
           RowBox[{"1.`", " ", "B", " ", "C44"}], "-", 
           RowBox[{"1.4142135623730951`", " ", "C", " ", "C44"}]}], ")"}], 
         "2"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"C11", "-", 
            RowBox[{"1.`", " ", "C12"}]}], ")"}], "2"], " ", 
         SuperscriptBox["C44", "2"]}]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.16666666666666666`"}], " ", "C11"}], "-", 
            RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
            RowBox[{"0.3333333333333333`", " ", "C44"}]}], ")"}]}], "+", 
         RowBox[{"A2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"0.16666666666666666`", " ", "C11"}], "+", 
            RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
            RowBox[{"0.6666666666666666`", " ", "C44"}]}], ")"}]}]}], ")"}], 
       " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2.`", " ", "C12"}]}], ")"}], " ", "C44"}]]},
    {
     RowBox[{"0.3333333333333333`", " ", 
      SqrtBox[
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1.`", " ", "B", " ", "C11"}], "+", 
           RowBox[{"0.7071067811865476`", " ", "C", " ", "C11"}], "-", 
           RowBox[{"1.`", " ", "B", " ", "C12"}], "-", 
           RowBox[{"0.7071067811865476`", " ", "C", " ", "C12"}], "+", 
           RowBox[{"1.`", " ", "B", " ", "C44"}], "-", 
           RowBox[{"1.4142135623730951`", " ", "C", " ", "C44"}]}], ")"}], 
         "2"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"C11", "-", 
            RowBox[{"1.`", " ", "C12"}]}], ")"}], "2"], " ", 
         SuperscriptBox["C44", "2"]}]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.16666666666666666`"}], " ", "C11"}], "-", 
            RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
            RowBox[{"0.3333333333333333`", " ", "C44"}]}], ")"}]}], "+", 
         RowBox[{"A2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"0.16666666666666666`", " ", "C11"}], "+", 
            RowBox[{"0.3333333333333333`", " ", "C12"}], "+", 
            RowBox[{"0.6666666666666666`", " ", "C44"}]}], ")"}]}]}], ")"}], 
       " ", "P"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2.`", " ", "C12"}]}], ")"}], " ", "C44"}]]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.733746729204711*^9, 3.7337471386891055`*^9, 
  3.7337477878643255`*^9, 3.7340644930118837`*^9, 3.734064554697159*^9, 
  3.7343317045400143`*^9, 3.7343318807536073`*^9, 3.7343319957775707`*^9, 
  3.7343425004364977`*^9, 3.734344136990149*^9, 3.734344237071163*^9, 
  3.7343493157381616`*^9, 3.7346901921781425`*^9, 3.7348584034407787`*^9, 
  3.736682459270609*^9, 3.736742876595504*^9, 3.736826015791195*^9, 
  3.736829085386799*^9, 3.7368292624873466`*^9, 3.745649735441926*^9, 
  3.745649870126623*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"0", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"A1", "-", "A2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", " ", "C12"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"A1", "+", 
            RowBox[{"2", " ", "A2"}]}], ")"}], " ", "C44"}]}], ")"}], " ", 
       "P"}], 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]]},
    {
     RowBox[{
      FractionBox["2", "9"], " ", 
      SqrtBox["2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["B", "2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "B", " ", "C"}], "+", 
         SuperscriptBox["C", "2"]}], 
        SuperscriptBox["C44", "2"]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"A1", "-", "A2"}], ")"}]}], " ", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", " ", "C12"}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"A1", "+", 
            RowBox[{"2", " ", "A2"}]}], ")"}], " ", "C44"}]}], ")"}], " ", 
       "P"}], 
      RowBox[{"9", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]]},
    {
     RowBox[{
      FractionBox["2", "9"], " ", 
      SqrtBox["2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["B", "2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "B", " ", "C"}], "+", 
         SuperscriptBox["C", "2"]}], 
        SuperscriptBox["C44", "2"]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"A1", "-", "A2"}], ")"}]}], " ", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", " ", "C12"}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"A1", "+", 
            RowBox[{"2", " ", "A2"}]}], ")"}], " ", "C44"}]}], ")"}], " ", 
       "P"}], 
      RowBox[{"9", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]]},
    {
     RowBox[{
      FractionBox["2", "9"], " ", 
      SqrtBox["2"], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["B", "2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "B", " ", "C"}], "+", 
         SuperscriptBox["C", "2"]}], 
        SuperscriptBox["C44", "2"]]], " ", "P"}], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"A1", "-", "A2"}], ")"}]}], " ", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", " ", "C12"}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"A1", "+", 
            RowBox[{"2", " ", "A2"}]}], ")"}], " ", "C44"}]}], ")"}], " ", 
       "P"}], 
      RowBox[{"9", " ", 
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.733746729204711*^9, 3.7337471386891055`*^9, 
  3.7337477878643255`*^9, 3.7340644930118837`*^9, 3.734064554697159*^9, 
  3.7343317045400143`*^9, 3.7343318807536073`*^9, 3.7343319957775707`*^9, 
  3.7343425004364977`*^9, 3.734344136990149*^9, 3.734344237071163*^9, 
  3.7343493157381616`*^9, 3.7346901921781425`*^9, 3.7348584034407787`*^9, 
  3.736682459270609*^9, 3.736742876595504*^9, 3.736826015791195*^9, 
  3.736829085386799*^9, 3.7368292624873466`*^9, 3.745649735441926*^9, 
  3.7456498702366247`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Checking expessions for level shifts for paper", "Subsubsection",
 CellChangeTimes->{{3.7346901578204346`*^9, 3.734690168884657*^9}, {
  3.7348481817856255`*^9, 3.7348481889367685`*^9}, {3.734856354180772*^9, 
  3.734856356410816*^9}, {3.7368255073215733`*^9, 3.736825510523638*^9}}],

Cell["\<\
Definitions:
E = (C11 - C12)(C11 + 2*C12)/(C11+C12)
\[Nu] = C12/(C11 + C12)
\[Gamma] = (C11 + 2*C12)/C44\
\>", "Text",
 CellChangeTimes->{{3.7346902783509884`*^9, 3.7346902817510567`*^9}, {
  3.73469031873382*^9, 3.734690367922826*^9}}],

Cell["[100] for NV1-4 (all NVs show the same reaction)", "Text",
 CellChangeTimes->{{3.734690214753637*^9, 3.7346902181487074`*^9}, {
  3.7346908859624596`*^9, 3.7346908943566313`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Mz100", "=", 
   RowBox[{"\[Epsilon]", "*", 
    RowBox[{"1", "/", "3"}], "*", 
    RowBox[{"(", 
     RowBox[{"A1", "+", 
      RowBox[{"2", "A2"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "\[Nu]"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mperp100", "=", 
   RowBox[{"\[Epsilon]", "*", 
    RowBox[{"2", "/", "3"}], "*", 
    RowBox[{"(", 
     RowBox[{"B", "-", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "C"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"comp100calc", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], "==", "Mz100"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", " ", 
      RowBox[{"P", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", " ", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"comp100calc", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}], "==", "Mperp100"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", " ", 
      RowBox[{"P", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", " ", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.734690230704015*^9, 3.734690270899836*^9}, {
  3.7346904186748505`*^9, 3.7346904532245607`*^9}, {3.7346904857642326`*^9, 
  3.7346905905143957`*^9}, {3.7346906249021006`*^9, 3.7346906305022125`*^9}, {
  3.7346907362163715`*^9, 3.7346907444925394`*^9}, {3.734690796772607*^9, 
  3.7346908299123125`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7346905183819084`*^9, 3.7346905921454287`*^9}, 
   3.73469062588212*^9, {3.7346907453835573`*^9, 3.7346908313063436`*^9}, 
   3.7348584037027845`*^9, 3.7366824597636585`*^9, 3.736742905795089*^9, 
   3.7367435163562803`*^9, 3.736826016191203*^9, 3.736829085646804*^9, 
   3.736829262757352*^9, 3.745649735851934*^9, 3.745649870246625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["2", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     SqrtBox[
      FractionBox[
       RowBox[{
        SuperscriptBox["B", "2"], "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"], " ", "B", " ", "C"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["C", "2"]}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}], "2"]]], "+", 
     FractionBox[
      RowBox[{"B", "-", 
       RowBox[{
        SqrtBox["2"], " ", "C"}]}], 
      RowBox[{
       RowBox[{"-", "C11"}], "+", "C12"}]]}], ")"}], " ", "P"}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7346905183819084`*^9, 3.7346905921454287`*^9}, 
   3.73469062588212*^9, {3.7346907453835573`*^9, 3.7346908313063436`*^9}, 
   3.7348584037027845`*^9, 3.7366824597636585`*^9, 3.736742905795089*^9, 
   3.7367435163562803`*^9, 3.736826016191203*^9, 3.736829085646804*^9, 
   3.736829262757352*^9, 3.745649735851934*^9, 3.7456498707466354`*^9}]
}, Open  ]],

Cell["\<\
[110] for NV1 - 2 (true, even though Mathematica cannot solve the perp case)\
\>", "Text",
 CellChangeTimes->{{3.734691173587963*^9, 3.734691183119157*^9}, {
  3.734694653915168*^9, 3.734694667150442*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Mz110NV12", "=", 
   RowBox[{"\[Epsilon]", "*", 
    RowBox[{"1", "/", "6"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "\[Nu]"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A1", "*", 
       RowBox[{"(", 
        RowBox[{"2", "+", "\[Gamma]"}], ")"}]}], "-", 
      RowBox[{"A2", "*", 
       RowBox[{"(", 
        RowBox[{"\[Gamma]", "-", "4"}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mperp110NV12", "=", 
   RowBox[{"\[Epsilon]", "*", 
    RowBox[{"1", "/", "3"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", "\[Nu]"}]}], ")"}], "\[Gamma]"}], "-", 
         RowBox[{"(", 
          RowBox[{"1", "+", "\[Nu]"}], ")"}]}], ")"}]}], "+", 
      RowBox[{"C", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", "\[Nu]"}]}], ")"}], "\[Gamma]"}], "+", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"comp110calc", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], "==", "Mz110NV12"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", " ", 
      RowBox[{"P", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", " ", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "*", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"comp110calc", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}], "==", "Mperp110NV12"}],
    "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", " ", 
      RowBox[{"P", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", " ", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "*", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7346911926813917`*^9, 3.7346913953345733`*^9}, {
   3.734691445286594*^9, 3.7346914469506297`*^9}, {3.734691488532485*^9, 
   3.734691499633709*^9}, {3.7346915584919124`*^9, 3.734691681938428*^9}, {
   3.734692303281744*^9, 3.7346923371114264`*^9}, {3.7346930820986705`*^9, 
   3.734693082668682*^9}, {3.7346931646174154`*^9, 3.7346931685374937`*^9}, {
   3.734693247856126*^9, 3.7346932591763525`*^9}, 3.7367435491879377`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7346913964845963`*^9, 3.734691447770646*^9, {3.734691489957514*^9, 
   3.734691500033717*^9}, 3.7346915594219313`*^9, {3.734691642843642*^9, 
   3.734691682488439*^9}, {3.7346923222041254`*^9, 3.734692337491434*^9}, 
   3.734693084658722*^9, {3.7346931654574327`*^9, 3.7346931688575*^9}, {
   3.734693252906227*^9, 3.7346932601863728`*^9}, 3.734858404762806*^9, 
   3.736682461489831*^9, 3.7367429472319183`*^9, 3.736743446129874*^9, 
   3.7368260173912272`*^9, 3.736829085706805*^9, 3.7368292628173532`*^9, 
   3.7456497369419556`*^9, 3.7456498707866364`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"B", "-", 
         RowBox[{
          SqrtBox["2"], " ", "C"}]}], ")"}]}], 
      RowBox[{"C11", "-", "C12"}]], "+", 
     SqrtBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"2.`", " ", "B"}], "-", 
           RowBox[{"2.8284271247461903`", " ", "C"}]}], 
          RowBox[{"C11", "-", 
           RowBox[{"1.`", " ", "C12"}]}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2.`"}], " ", "B"}], "-", 
           RowBox[{"1.4142135623730951`", " ", "C"}]}], "C44"]}], ")"}], 
       "2"]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "B"}], "+", 
       RowBox[{
        SqrtBox["2"], " ", "C"}]}], "C44"]}], ")"}], " ", "P"}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.7346913964845963`*^9, 3.734691447770646*^9, {3.734691489957514*^9, 
   3.734691500033717*^9}, 3.7346915594219313`*^9, {3.734691642843642*^9, 
   3.734691682488439*^9}, {3.7346923222041254`*^9, 3.734692337491434*^9}, 
   3.734693084658722*^9, {3.7346931654574327`*^9, 3.7346931688575*^9}, {
   3.734693252906227*^9, 3.7346932601863728`*^9}, 3.734858404762806*^9, 
   3.736682461489831*^9, 3.7367429472319183`*^9, 3.736743446129874*^9, 
   3.7368260173912272`*^9, 3.736829085706805*^9, 3.7368292628173532`*^9, 
   3.7456497369419556`*^9, 3.7456498714366493`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"comp110calc", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "3", ",", "1"}], "]"}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.734693340099094*^9, 3.7346933411491146`*^9}, {
  3.7346936890512996`*^9, 3.734693689171302*^9}, {3.7367434763724794`*^9, 
  3.736743477754507*^9}}],

Cell[BoxData[
 RowBox[{"0.3333333333333333`", " ", 
  SqrtBox[
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1.`", " ", "B", " ", "C11"}], "+", 
       RowBox[{"0.7071067811865476`", " ", "C", " ", "C11"}], "-", 
       RowBox[{"1.`", " ", "B", " ", "C12"}], "-", 
       RowBox[{"0.7071067811865476`", " ", "C", " ", "C12"}], "+", 
       RowBox[{"1.`", " ", "B", " ", "C44"}], "-", 
       RowBox[{"1.4142135623730951`", " ", "C", " ", "C44"}]}], ")"}], "2"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"C11", "-", 
        RowBox[{"1.`", " ", "C12"}]}], ")"}], "2"], " ", 
     SuperscriptBox["C44", "2"]}]]], " ", "P"}]], "Output",
 CellChangeTimes->{
  3.7346916881425667`*^9, 3.734693342099134*^9, 3.734693689791314*^9, 
   3.7348584048128066`*^9, 3.73668246238492*^9, {3.7367434722123957`*^9, 
   3.7367434781145144`*^9}, 3.7368260186012516`*^9, 3.7368290862068157`*^9, 
   3.736829263117359*^9, 3.7456497382819824`*^9, 3.7456498715366507`*^9}]
}, Open  ]],

Cell["\<\
[110] for NV3 - 4 (true, even though Mathematica cannot solve the perp case)\
\>", "Text",
 CellChangeTimes->{{3.734693300287197*^9, 3.7346933094093933`*^9}, {
  3.7346946730525675`*^9, 3.734694673345578*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Mz110NV34", "=", 
   RowBox[{"\[Epsilon]", "*", 
    RowBox[{"1", "/", "6"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "\[Nu]"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A1", "*", 
       RowBox[{"(", 
        RowBox[{"2", "-", "\[Gamma]"}], ")"}]}], "+", 
      RowBox[{"A2", "*", 
       RowBox[{"(", 
        RowBox[{"\[Gamma]", "+", "4"}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mperp110NV34", "=", 
   RowBox[{"\[Epsilon]", "*", 
    RowBox[{"1", "/", "3"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", "\[Nu]"}]}], ")"}], "\[Gamma]"}], "+", 
         RowBox[{"(", 
          RowBox[{"1", "+", "\[Nu]"}], ")"}]}], ")"}]}], "+", 
      RowBox[{"C", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", "\[Nu]"}]}], ")"}], "\[Gamma]"}], "-", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"comp110calc", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "3", ",", "2"}], "]"}], "]"}], "==", "Mz110NV34"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", " ", 
      RowBox[{"P", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", " ", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "*", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"comp110calc", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "3", ",", "1"}], "]"}], "]"}], "\[Equal]", 
    "Mperp110NV34"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", " ", 
      RowBox[{"P", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", " ", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "*", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "Together"}]}], "Input",
 CellChangeTimes->{{3.734693316866623*^9, 3.734693319906684*^9}, {
  3.7346936661528234`*^9, 3.7346936714429293`*^9}, {3.7346940148079424`*^9, 
  3.7346940538487396`*^9}, {3.7346945250944796`*^9, 3.7346945312746034`*^9}, {
  3.734694588412812*^9, 3.7346945951829476`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.73469403445335*^9, 3.734694054238747*^9}, {
   3.7346945265145082`*^9, 3.7346945317346125`*^9}, {3.7346945901628475`*^9, 
   3.734694595702958*^9}, 3.7348584048428073`*^9, 3.736682462911973*^9, 
   3.736742974163457*^9, 3.736743621241596*^9, 3.7368260186612525`*^9, 
   3.736829086256817*^9, 3.7368292631673603`*^9, 3.745649738311983*^9, 
   3.7456498715666513`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.3333333333333333`", " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1.`", " ", "B", " ", "C11"}], "+", 
        RowBox[{"0.7071067811865476`", " ", "C", " ", "C11"}], "-", 
        RowBox[{"1.`", " ", "B", " ", "C12"}], "-", 
        RowBox[{"0.7071067811865476`", " ", "C", " ", "C12"}], "+", 
        RowBox[{"1.`", " ", "B", " ", "C44"}], "-", 
        RowBox[{"1.4142135623730951`", " ", "C", " ", "C44"}]}], ")"}], "2"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"C11", "-", 
         RowBox[{"1.`", " ", "C12"}]}], ")"}], "2"], " ", 
      SuperscriptBox["C44", "2"]}]]], " ", "P"}], "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "B", " ", "C11"}], "+", 
      RowBox[{
       SqrtBox["2"], " ", "C", " ", "C11"}], "-", 
      RowBox[{"2", " ", "B", " ", "C12"}], "-", 
      RowBox[{
       SqrtBox["2"], " ", "C", " ", "C12"}], "+", 
      RowBox[{"2", " ", "B", " ", "C44"}], "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"], " ", "C", " ", "C44"}]}], ")"}], " ", "P"}], 
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{"C11", "-", "C12"}], ")"}], " ", "C44"}]]}]], "Output",
 CellChangeTimes->{{3.73469403445335*^9, 3.734694054238747*^9}, {
   3.7346945265145082`*^9, 3.7346945317346125`*^9}, {3.7346945901628475`*^9, 
   3.734694595702958*^9}, 3.7348584048428073`*^9, 3.736682462911973*^9, 
   3.736742974163457*^9, 3.736743621241596*^9, 3.7368260186612525`*^9, 
   3.736829086256817*^9, 3.7368292631673603`*^9, 3.745649738311983*^9, 
   3.7456498715666513`*^9}]
}, Open  ]],

Cell["[111] for NV1", "Text",
 CellChangeTimes->{{3.734777923960701*^9, 3.7347779358428893`*^9}, 
   3.7347784409999046`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Mz111NV1", "=", 
   RowBox[{"\[Epsilon]", "*", 
    RowBox[{"1", "/", "3"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "\[Nu]"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"A1", "-", "A2"}], ")"}], "*", "\[Gamma]"}], "+", "A1", "+", 
      RowBox[{"2", "A2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"comp111calc", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], "==", "Mz111NV1"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", " ", 
      RowBox[{"P", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", " ", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "*", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.734777940501355*^9, 3.7347780013894434`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.734778002369541*^9, 3.7348584048828077`*^9, 
  3.7366824636480465`*^9, 3.736743618661545*^9, 3.736826018691253*^9, 
  3.7368290862868176`*^9, 3.736829263197361*^9, 3.745649738351984*^9, 
  3.7456498716066523`*^9}]
}, Open  ]],

Cell["\<\
[111] for NV2 - 4 (true, but Mathematica cannot solve the sqrt ...)\
\>", "Text",
 CellChangeTimes->{{3.7347784447269864`*^9, 3.7347784496070843`*^9}, {
  3.734778714248914*^9, 3.7347787248481407`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Mz111NV234", "=", 
   RowBox[{"\[Epsilon]", "*", 
    RowBox[{"1", "/", "9"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "\[Nu]"}]}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"A1", "-", "A2"}], ")"}]}], "*", "\[Gamma]"}], "+", 
      RowBox[{"3", 
       RowBox[{"(", 
        RowBox[{"A1", "+", 
         RowBox[{"2", "A2"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mperp111NV234", "=", 
   RowBox[{"\[Epsilon]", "*", "2", 
    RowBox[{
     RowBox[{"Sqrt", "[", "2", "]"}], "/", "9"}], "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", "\[Nu]"}]}], ")"}], "\[Gamma]", "*", 
    RowBox[{"(", 
     RowBox[{"C", "+", 
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "B"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"comp111calc", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2", ",", "2"}], "]"}], "]"}], "==", "Mz111NV234"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "\[Rule]", " ", 
      RowBox[{"P", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"C11", "+", 
            RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
     RowBox[{"\[Nu]", "\[Rule]", " ", 
      RowBox[{"C12", "/", 
       RowBox[{"(", 
        RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "+", 
         RowBox[{"2", "*", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"comp111calc", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2", ",", "1"}], "]"}], "]"}], "==", 
     "Mperp111NV234"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Epsilon]", "\[Rule]", " ", 
       RowBox[{"P", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C11", "+", "C12"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"C11", "-", "C12"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"C11", "+", 
             RowBox[{"2", "*", "C12"}]}], ")"}]}], ")"}]}]}]}], ",", " ", 
      RowBox[{"\[Nu]", "\[Rule]", " ", 
       RowBox[{"C12", "/", 
        RowBox[{"(", 
         RowBox[{"C11", "+", "C12"}], ")"}]}]}], ",", 
      RowBox[{"\[Gamma]", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "*", "C12"}]}], ")"}], "/", "C44"}]}]}], "}"}]}], "//",
    "Together"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7347784561082163`*^9, 3.734778478528669*^9}, {
  3.734778614896895*^9, 3.7347786865423536`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7347784801287007`*^9, {3.734778667516971*^9, 3.73477868687236*^9}, 
   3.7348584049228086`*^9, 3.7366824644001217`*^9, 3.736743647461122*^9, 
   3.736826018741254*^9, 3.736829086346819*^9, 3.736829263247362*^9, 
   3.7456497383819847`*^9, 3.745649871636653*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "B"}], "+", 
      RowBox[{
       SqrtBox["2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "C"}], "+", 
         RowBox[{
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["B", "2"]}], "+", 
             RowBox[{"2", " ", 
              SqrtBox["2"], " ", "B", " ", "C"}], "+", 
             SuperscriptBox["C", "2"]}], 
            SuperscriptBox["C44", "2"]]], " ", "C44"}]}], ")"}]}]}], ")"}], 
    " ", "P"}], "C44"], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.7347784801287007`*^9, {3.734778667516971*^9, 3.73477868687236*^9}, 
   3.7348584049228086`*^9, 3.7366824644001217`*^9, 3.736743647461122*^9, 
   3.736826018741254*^9, 3.736829086346819*^9, 3.736829263247362*^9, 
   3.7456497383819847`*^9, 3.7456498718866577`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Miscellaneous", "Title",
 CellChangeTimes->{{3.6932864917439137`*^9, 3.693286499997739*^9}, 
   3.693289632981123*^9, {3.6933031024469447`*^9, 3.693303113607061*^9}, {
   3.693303423884085*^9, 3.6933034282285194`*^9}, {3.69374054392634*^9, 
   3.693740578375785*^9}, {3.709874625312827*^9, 3.709874626822857*^9}, {
   3.709874798462291*^9, 3.709874800512332*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"clearing", " ", "all", " ", "variables"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.7098251989043055`*^9, 3.7098252217816143`*^9}}],

Cell[CellGroupData[{

Cell["\<\
3.1 Converting stress tensor in crystal coordinates XYZ to strain in NV \
coordinates xyz for two different NV orientations\
\>", "Section",
 CellChangeTimes->{{3.709875855525675*^9, 3.70987591481686*^9}, {
  3.7368256208838453`*^9, 3.736825628894006*^9}}],

Cell[CellGroupData[{

Cell["Definitions", "Subsection",
 CellChangeTimes->{{3.7356168007908053`*^9, 3.735616806592923*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PKelvin", "[", 
    RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "0", ",", " ", "0", ",", " ", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p2"}], ",", " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", " ", "0", ",", " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p1"}], ",", "0", ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p1"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p2"}], ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p1"}], ",", " ", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p1"}], ",", "0", ",", "p3", 
       ",", 
       RowBox[{"-", "p2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p2"}], ",", "0", ",", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p2"}], ",", 
       RowBox[{"-", "p3"}], ",", "0", ",", "p1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "p3"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "*", "p3"}], ",", "0", ",", "p2", 
       ",", 
       RowBox[{"-", "p1"}], ",", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RotMat", "[", 
     RowBox[{"p1_", ",", "p2_", ",", "p3_", ",", "\[Theta]_"}], "]"}], ":=", 
    " ", 
    RowBox[{
     RowBox[{"IdentityMatrix", "[", "6", "]"}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "*", 
      RowBox[{"PKelvin", "[", 
       RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], 
      RowBox[{
       RowBox[{"PKelvin", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
       RowBox[{"PKelvin", "[", 
        RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"PKelvin", "[", 
          RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], "+", 
         RowBox[{
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}]}], ")"}], "/", 
       "3"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], "^", "2"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}], ".", 
          RowBox[{"PKelvin", "[", 
           RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}]}], ")"}], "/", 
       "6"}]}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"rotation", " ", "matrix", " ", "as", " ", "in", " ", 
    RowBox[{"eq", ".", 
     RowBox[{"(", "4", ")"}]}], " ", "from", " ", "Mehrabadi1995"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rm1p106x6", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{"RotMat", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "0", ",", "\[Theta]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rp1p106x6", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{"RotMat", "[", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "0", ",", "\[Theta]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rz6x6", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{"RotMat", "[", 
   RowBox[{"0", ",", "0", ",", "1", ",", "\[Theta]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LBarsonpassive", "=", 
    RowBox[{
     RowBox[{"Rz6x6", "[", 
      RowBox[{
       RowBox[{"-", "5"}], 
       RowBox[{"\[Pi]", "/", "4"}]}], "]"}], ".", 
     RowBox[{"Rm1p106x6", "[", 
      RowBox[{"-", 
       RowBox[{"ArcCos", "[", 
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], "]"}]}], "]"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"passive", " ", "rotation", " ", 
     RowBox[{"XYZ", " ", "--"}]}], ">", " ", "xyzBarson"}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.693653771027669*^9, 3.6936539027898436`*^9}, {
   3.6936539467272367`*^9, 3.693653947207285*^9}, 3.6936558378893347`*^9, {
   3.6976994985563774`*^9, 3.6976995168864098`*^9}, {3.697724647314017*^9, 
   3.697724655613231*^9}, {3.6992712872436647`*^9, 3.6992712919936714`*^9}, {
   3.6992718981137*^9, 3.699271915682705*^9}, {3.7098759748211555`*^9, 
   3.7098759906814723`*^9}, {3.7356160617874594`*^9, 3.735616073987707*^9}, {
   3.7356161563883753`*^9, 3.7356161610114717`*^9}, {3.735616287158297*^9, 
   3.735616287388302*^9}, {3.735616651975553*^9, 3.7356166836902356`*^9}, {
   3.7356167624599915`*^9, 3.735616778293313*^9}, {3.7368256352641335`*^9, 
   3.736825659936627*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CXYZKelvin", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"C11", ",", "C12", ",", "C12", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"C12", ",", "C11", ",", "C12", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"C12", ",", "C12", ",", "C11", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"2", "C44"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"2", "C44"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"2", "C44"}]}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]XYZKelvin", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]XX", ",", "\[Sigma]YY", ",", "\[Sigma]ZZ", ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Sigma]YZ"}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Sigma]XZ"}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Sigma]XY"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]xyzKelvinBarson", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]xxb", ",", "\[Epsilon]yyb", ",", "\[Epsilon]zzb", ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Epsilon]yzb"}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Epsilon]xzb"}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Epsilon]xyb"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]xyzKelvinNV1", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]xxa", ",", "\[Epsilon]yya", ",", "\[Epsilon]zza", ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Epsilon]yza"}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Epsilon]xza"}], ",", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "\[Epsilon]xya"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.693654003451909*^9, 3.693654126651228*^9}, {
   3.6936541567522373`*^9, 3.693654160189581*^9}, {3.6936544016987295`*^9, 
   3.6936544507326326`*^9}, {3.6936547034899054`*^9, 3.69365479033959*^9}, 
   3.6936548399735527`*^9, {3.6936578739229174`*^9, 3.693657927045229*^9}, {
   3.6936579718237066`*^9, 3.6936579719837227`*^9}, {3.6936581689044123`*^9, 
   3.6936581772552476`*^9}, {3.6936583315116715`*^9, 3.693658345327053*^9}, {
   3.693658581659684*^9, 3.693658583233841*^9}, {3.6936587200795245`*^9, 
   3.693658753769893*^9}, {3.6936589035288677`*^9, 3.693658930208535*^9}, {
   3.693659091152628*^9, 3.693659141135626*^9}, {3.6936594811056194`*^9, 
   3.6936594812656355`*^9}, {3.697189934057757*^9, 3.6971899608430037`*^9}, {
   3.69718999293226*^9, 3.697190004710281*^9}, {3.6971900426963477`*^9, 
   3.697190043632349*^9}, {3.6976995291636314`*^9, 3.6976996497050433`*^9}, {
   3.6976998184193397`*^9, 3.697699879134646*^9}, {3.697700026228901*^9, 
   3.6977000325332613`*^9}, {3.697701580802986*^9, 3.697701607010485*^9}, {
   3.6977017122598915`*^9, 3.6977017829899907`*^9}, 3.697718076140789*^9, {
   3.697718172822405*^9, 3.697718174507208*^9}, {3.6977246649732475`*^9, 
   3.697724675394066*^9}, 3.7020983416371984`*^9, {3.7098760695830507`*^9, 
   3.709876077451302*^9}, {3.735616090074031*^9, 3.7356160908240457`*^9}, {
   3.7356161752957997`*^9, 3.735616255150603*^9}, {3.73561631347983*^9, 
   3.735616358580784*^9}, {3.735616404455714*^9, 3.7356165227794147`*^9}, {
   3.7356166562546415`*^9, 3.7356166929224634`*^9}, {3.735617833209426*^9, 
   3.7356178594220123`*^9}, {3.736825669256813*^9, 3.736825682327074*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Inverse", "[", "LBarsonpassive", "]"}], "\[Equal]", 
   RowBox[{"Transpose", "[", "LBarsonpassive", "]"}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7356167109778285`*^9, 3.7356167258121276`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7356167211720347`*^9, 3.7356167733322144`*^9, 
  3.736826019401267*^9, 3.736829087006832*^9, 3.7368292638773746`*^9, 
  3.745649878676794*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV orientation Barson2017", "Subsection",
 CellChangeTimes->{{3.7356168107630067`*^9, 3.735616841329624*^9}, {
  3.735616877812464*^9, 3.7356168952848163`*^9}, {3.7356192394958286`*^9, 
  3.7356192580966883`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]xyzKelvinBarsonCalc", " ", "=", 
   RowBox[{
    RowBox[{"LBarsonpassive", ".", 
     RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", "\[Sigma]XYZKelvin"}], 
    "//", "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "=", 
  RowBox[{
   RowBox[{"CXYZKelvin", ".", 
    RowBox[{"Transpose", "[", "LBarsonpassive", "]"}], ".", 
    "\[Epsilon]xyzKelvinBarson"}], " ", "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{
  3.7356166963025312`*^9, {3.735616843539668*^9, 3.735616860201005*^9}, {
   3.735617025923539*^9, 3.735617027285568*^9}, {3.73561710780331*^9, 
   3.735617118934535*^9}, {3.7368256937273026`*^9, 3.7368257080275884`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C11", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xxb", "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "\[Epsilon]xyb"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]xzb"}], "+", 
         RowBox[{"3", " ", "\[Epsilon]yyb"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["6"], " ", "\[Epsilon]yzb"}], "+", 
         RowBox[{"2", " ", "\[Epsilon]zzb"}]}], ")"}]}], "+", 
      RowBox[{"C12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", " ", "\[Epsilon]xxb"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "\[Epsilon]xyb"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]xzb"}], "+", 
         RowBox[{"3", " ", "\[Epsilon]yyb"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["6"], " ", "\[Epsilon]yzb"}], "+", 
         RowBox[{"4", " ", "\[Epsilon]zzb"}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C11", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xxb", "+", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "\[Epsilon]xyb"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]xzb"}], "+", 
         RowBox[{"3", " ", "\[Epsilon]yyb"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["6"], " ", "\[Epsilon]yzb"}], "+", 
         RowBox[{"2", " ", "\[Epsilon]zzb"}]}], ")"}]}], "+", 
      RowBox[{"C12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", " ", "\[Epsilon]xxb"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "\[Epsilon]xyb"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]xzb"}], "+", 
         RowBox[{"3", " ", "\[Epsilon]yyb"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["6"], " ", "\[Epsilon]yzb"}], "+", 
         RowBox[{"4", " ", "\[Epsilon]zzb"}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C11", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Epsilon]xxb"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]xzb"}], "+", "\[Epsilon]zzb"}], 
        ")"}]}], "+", 
      RowBox[{"C12", " ", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]xxb", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]xzb"}], "+", 
         RowBox[{"3", " ", "\[Epsilon]yyb"}], "+", 
         RowBox[{"2", " ", "\[Epsilon]zzb"}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["2", "3"]}], " ", "C44", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]xxb"}], "+", 
      RowBox[{
       SqrtBox["6"], " ", "\[Epsilon]xyb"}], "-", "\[Epsilon]xzb", "+", 
      RowBox[{
       SqrtBox["3"], " ", "\[Epsilon]yzb"}], "-", 
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]zzb"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["2", "3"], " ", "C44", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox["2"]}], " ", "\[Epsilon]xxb"}], "+", 
      RowBox[{
       SqrtBox["6"], " ", "\[Epsilon]xyb"}], "+", "\[Epsilon]xzb", "+", 
      RowBox[{
       SqrtBox["3"], " ", "\[Epsilon]yzb"}], "+", 
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]zzb"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", "C44", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]xxb"}], "-", 
      RowBox[{"4", " ", "\[Epsilon]xzb"}], "+", 
      RowBox[{
       SqrtBox["2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", "\[Epsilon]yyb"}], "+", 
         RowBox[{"2", " ", "\[Epsilon]zzb"}]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.73561684413968*^9, 3.735616862941063*^9}, 
   3.735617033335689*^9, 3.735617121744591*^9, 3.7356178650421247`*^9, 
   3.7368260204642887`*^9, 3.736829087816848*^9, 3.7368292646773906`*^9, 
   3.745649879776816*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxBarson", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{
          RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{"MyBarson", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"MzBarson", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a1", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"2", "*", "a2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinBarsonCalc", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.6936548073462906`*^9, 3.6936548273912945`*^9}, {
   3.693655312777828*^9, 3.6936553156271133`*^9}, {3.693655378412391*^9, 
   3.6936553820537553`*^9}, {3.6936554206616154`*^9, 3.693655434136963*^9}, {
   3.693655464569006*^9, 3.693655499054454*^9}, {3.6936558444009857`*^9, 
   3.6936558793154764`*^9}, {3.6936559579343376`*^9, 
   3.6936560020407476`*^9}, {3.6936560449470377`*^9, 
   3.6936560824527884`*^9}, {3.693656143358878*^9, 3.6936561703535776`*^9}, {
   3.6936562205876007`*^9, 3.6936562558451257`*^9}, {3.6936571456761*^9, 
   3.6936571878783197`*^9}, {3.6936572965661874`*^9, 3.693657311553686*^9}, {
   3.693657450986628*^9, 3.693657460290558*^9}, {3.6936582079003115`*^9, 
   3.693658212835805*^9}, {3.69365843660618*^9, 3.6936584410356226`*^9}, {
   3.69365848061458*^9, 3.693658482221741*^9}, {3.6936586663051476`*^9, 
   3.6936586823447514`*^9}, {3.6936588085313687`*^9, 3.693658808822398*^9}, {
   3.6936590083343472`*^9, 3.6936590807665896`*^9}, {3.6971883301233397`*^9, 
   3.6971883518229775`*^9}, {3.6971886686439342`*^9, 
   3.6971886810927563`*^9}, {3.6976996643378687`*^9, 
   3.6976997103423495`*^9}, {3.697718038732268*^9, 3.697718055471097*^9}, 
   3.702098381367993*^9, {3.705057060891658*^9, 3.7050570618357115`*^9}, {
   3.735616898115873*^9, 3.735616987102752*^9}, {3.7356170439079022`*^9, 
   3.735617047477974*^9}, {3.736828712304908*^9, 3.7368287254281707`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "c", " ", "C44", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxb", "-", 
     RowBox[{
      SqrtBox["2"], " ", "\[Epsilon]xzb"}], "-", "\[Epsilon]yyb"}], ")"}]}], 
  "+", 
  RowBox[{"b", " ", 
   RowBox[{"(", 
    RowBox[{"C11", "-", "C12"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxb", "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"], " ", "\[Epsilon]xzb"}], "-", "\[Epsilon]yyb"}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.6936548104886045`*^9, 3.6936548452020755`*^9}, {
   3.6936554933868876`*^9, 3.693655499477496*^9}, 3.693655886630208*^9, 
   3.693656003146858*^9, 3.693656083141857*^9, 3.6936561763141737`*^9, 
   3.693656256406182*^9, {3.693657154923024*^9, 3.6936571892324553`*^9}, 
   3.6936573133908696`*^9, 3.6936574613926687`*^9, 3.6936577917457004`*^9, 
   3.693657894184943*^9, 3.6936579350370283`*^9, 3.693657975294053*^9, {
   3.693658181413663*^9, 3.6936582136268845`*^9}, 3.6936583508356037`*^9, 
   3.6936584422097406`*^9, 3.6936584830778265`*^9, 3.6936585878763056`*^9, {
   3.6936586735618734`*^9, 3.6936586829768143`*^9}, 3.693658809710487*^9, {
   3.6936589078442993`*^9, 3.6936589345609703`*^9}, 3.693659035452059*^9, {
   3.693659068249338*^9, 3.693659143567869*^9}, 3.6936594848359923`*^9, {
   3.6971883581565886`*^9, 3.6971883647086*^9}, 3.697188683058359*^9, {
   3.6971900226035123`*^9, 3.697190048327957*^9}, 3.6976990425207767`*^9, 
   3.6976996811234984`*^9, 3.697699711137951*^9, {3.697699842209381*^9, 
   3.6976998579030085`*^9}, 3.6977000361354675`*^9, 3.6977180670619173`*^9, 
   3.6977181779392138`*^9, 3.699257571394184*^9, 3.6992712989836807`*^9, 
   3.6992715442240243`*^9, {3.6993743948840218`*^9, 3.699374400094431*^9}, 
   3.7003200588882723`*^9, 3.700380102618251*^9, 3.7003972532791457`*^9, {
   3.7020983600475664`*^9, 3.70209838474806*^9}, 3.7044697578988795`*^9, 
   3.704518254962613*^9, 3.705057073394373*^9, 3.708173404896965*^9, 
   3.709876692423603*^9, 3.7356169918928504`*^9, 3.735617050488034*^9, 
   3.7356171248856544`*^9, 3.7356178675341763`*^9, 3.736826020784295*^9, 
   3.7368287268992004`*^9, 3.73682908791685*^9, 3.7368292647873926`*^9, 
   3.745649879886818*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{"C11", "-", "C12"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]xyb", "-", 
       RowBox[{
        SqrtBox["2"], " ", "\[Epsilon]yzb"}]}], ")"}]}], "+", 
    RowBox[{"c", " ", "C44", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "\[Epsilon]xyb"}], "+", 
       RowBox[{
        SqrtBox["2"], " ", "\[Epsilon]yzb"}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.6936548104886045`*^9, 3.6936548452020755`*^9}, {
   3.6936554933868876`*^9, 3.693655499477496*^9}, 3.693655886630208*^9, 
   3.693656003146858*^9, 3.693656083141857*^9, 3.6936561763141737`*^9, 
   3.693656256406182*^9, {3.693657154923024*^9, 3.6936571892324553`*^9}, 
   3.6936573133908696`*^9, 3.6936574613926687`*^9, 3.6936577917457004`*^9, 
   3.693657894184943*^9, 3.6936579350370283`*^9, 3.693657975294053*^9, {
   3.693658181413663*^9, 3.6936582136268845`*^9}, 3.6936583508356037`*^9, 
   3.6936584422097406`*^9, 3.6936584830778265`*^9, 3.6936585878763056`*^9, {
   3.6936586735618734`*^9, 3.6936586829768143`*^9}, 3.693658809710487*^9, {
   3.6936589078442993`*^9, 3.6936589345609703`*^9}, 3.693659035452059*^9, {
   3.693659068249338*^9, 3.693659143567869*^9}, 3.6936594848359923`*^9, {
   3.6971883581565886`*^9, 3.6971883647086*^9}, 3.697188683058359*^9, {
   3.6971900226035123`*^9, 3.697190048327957*^9}, 3.6976990425207767`*^9, 
   3.6976996811234984`*^9, 3.697699711137951*^9, {3.697699842209381*^9, 
   3.6976998579030085`*^9}, 3.6977000361354675`*^9, 3.6977180670619173`*^9, 
   3.6977181779392138`*^9, 3.699257571394184*^9, 3.6992712989836807`*^9, 
   3.6992715442240243`*^9, {3.6993743948840218`*^9, 3.699374400094431*^9}, 
   3.7003200588882723`*^9, 3.700380102618251*^9, 3.7003972532791457`*^9, {
   3.7020983600475664`*^9, 3.70209838474806*^9}, 3.7044697578988795`*^9, 
   3.704518254962613*^9, 3.705057073394373*^9, 3.708173404896965*^9, 
   3.709876692423603*^9, 3.7356169918928504`*^9, 3.735617050488034*^9, 
   3.7356171248856544`*^9, 3.7356178675341763`*^9, 3.736826020784295*^9, 
   3.7368287268992004`*^9, 3.73682908791685*^9, 3.7368292647873926`*^9, 
   3.745649879936819*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "a2", " ", "C44", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxb", "+", "\[Epsilon]yyb", "-", 
     RowBox[{"2", " ", "\[Epsilon]zzb"}]}], ")"}]}], "+", 
  RowBox[{"a1", " ", 
   RowBox[{"(", 
    RowBox[{"C11", "+", 
     RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxb", "+", "\[Epsilon]yyb", "+", "\[Epsilon]zzb"}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.6936548104886045`*^9, 3.6936548452020755`*^9}, {
   3.6936554933868876`*^9, 3.693655499477496*^9}, 3.693655886630208*^9, 
   3.693656003146858*^9, 3.693656083141857*^9, 3.6936561763141737`*^9, 
   3.693656256406182*^9, {3.693657154923024*^9, 3.6936571892324553`*^9}, 
   3.6936573133908696`*^9, 3.6936574613926687`*^9, 3.6936577917457004`*^9, 
   3.693657894184943*^9, 3.6936579350370283`*^9, 3.693657975294053*^9, {
   3.693658181413663*^9, 3.6936582136268845`*^9}, 3.6936583508356037`*^9, 
   3.6936584422097406`*^9, 3.6936584830778265`*^9, 3.6936585878763056`*^9, {
   3.6936586735618734`*^9, 3.6936586829768143`*^9}, 3.693658809710487*^9, {
   3.6936589078442993`*^9, 3.6936589345609703`*^9}, 3.693659035452059*^9, {
   3.693659068249338*^9, 3.693659143567869*^9}, 3.6936594848359923`*^9, {
   3.6971883581565886`*^9, 3.6971883647086*^9}, 3.697188683058359*^9, {
   3.6971900226035123`*^9, 3.697190048327957*^9}, 3.6976990425207767`*^9, 
   3.6976996811234984`*^9, 3.697699711137951*^9, {3.697699842209381*^9, 
   3.6976998579030085`*^9}, 3.6977000361354675`*^9, 3.6977180670619173`*^9, 
   3.6977181779392138`*^9, 3.699257571394184*^9, 3.6992712989836807`*^9, 
   3.6992715442240243`*^9, {3.6993743948840218`*^9, 3.699374400094431*^9}, 
   3.7003200588882723`*^9, 3.700380102618251*^9, 3.7003972532791457`*^9, {
   3.7020983600475664`*^9, 3.70209838474806*^9}, 3.7044697578988795`*^9, 
   3.704518254962613*^9, 3.705057073394373*^9, 3.708173404896965*^9, 
   3.709876692423603*^9, 3.7356169918928504`*^9, 3.735617050488034*^9, 
   3.7356171248856544`*^9, 3.7356178675341763`*^9, 3.736826020784295*^9, 
   3.7368287268992004`*^9, 3.73682908791685*^9, 3.7368292647873926`*^9, 
   3.74564987996682*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Checking expression for paper", "Subsubsection",
 CellChangeTimes->{{3.735617365190424*^9, 3.7356173737895985`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxBarsonCheck", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "B"}], 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]xxb", "-", "\[Epsilon]yyb"}], ")"}]}], "+", 
    RowBox[{"2", "C", " ", "\[Epsilon]xzb"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyBarsonCheck", "=", 
   RowBox[{
    RowBox[{"2", "B", " ", "\[Epsilon]xyb"}], "+", 
    RowBox[{"2", " ", "C", " ", "\[Epsilon]yzb"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzBarsonCheck", "=", 
   RowBox[{
    RowBox[{"A1", " ", "\[Epsilon]zzb"}], " ", "+", " ", 
    RowBox[{"A2", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]xxb", "+", "\[Epsilon]yyb"}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MxBarson", "==", "MxBarsonCheck"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
        RowBox[{"2", " ", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
     RowBox[{"C", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "c", " ", "C44"}]}]}], ",", 
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", "a2", " ", "C44"}]}]}], ",", " ", 
     RowBox[{"A2", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "a2", " ", "C44"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MyBarson", "==", "MyBarsonCheck"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
        RowBox[{"2", " ", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
     RowBox[{"C", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "c", " ", "C44"}]}]}], ",", 
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", "a2", " ", "C44"}]}]}], ",", " ", 
     RowBox[{"A2", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "a2", " ", "C44"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MzBarson", "==", "MzBarsonCheck"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
        RowBox[{"2", " ", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
     RowBox[{"C", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "c", " ", "C44"}]}]}], ",", 
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", "a2", " ", "C44"}]}]}], ",", " ", 
     RowBox[{"A2", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "a2", " ", "C44"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.735617376939661*^9, 3.735617478879832*^9}, {
  3.73561752566284*^9, 3.7356175926772394`*^9}, {3.7356176417792335`*^9, 
  3.7356176452443037`*^9}, {3.735617870054227*^9, 3.735617878387394*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7356175737038145`*^9, 3.735617593347253*^9}, 
   3.7356176486243715`*^9, 3.7356178802774315`*^9, 3.7368260221843233`*^9, 
   3.736828729539253*^9, 3.736829088056853*^9, 3.736829264937396*^9, 
   3.7456498800068207`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7356175737038145`*^9, 3.735617593347253*^9}, 
   3.7356176486243715`*^9, 3.7356178802774315`*^9, 3.7368260221843233`*^9, 
   3.736828729539253*^9, 3.736829088056853*^9, 3.736829264937396*^9, 
   3.7456498800068207`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7356175737038145`*^9, 3.735617593347253*^9}, 
   3.7356176486243715`*^9, 3.7356178802774315`*^9, 3.7368260221843233`*^9, 
   3.736828729539253*^9, 3.736829088056853*^9, 3.736829264937396*^9, 
   3.745649880036821*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NV orientation from Hughes1967 (NV1 in paper)", "Subsection",
 CellChangeTimes->{{3.699258008911208*^9, 3.699258038820919*^9}, {
  3.6992581464390745`*^9, 3.699258147383128*^9}, {3.6992618489962225`*^9, 
  3.6992618760762606`*^9}, {3.699270079554326*^9, 3.699270083934333*^9}, {
  3.7098759350202646`*^9, 3.7098759491605473`*^9}, {3.709876607591906*^9, 
  3.709876608091916*^9}, {3.7356176610306664`*^9, 3.735617664962745*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"LNV1passive", "=", 
   RowBox[{
    RowBox[{"Rz6x6", "[", 
     RowBox[{
      RowBox[{"-", "3"}], 
      RowBox[{"\[Pi]", "/", "4"}]}], "]"}], ".", 
    RowBox[{"Rm1p106x6", "[", 
     RowBox[{"-", 
      RowBox[{"ArcCos", "[", 
       RowBox[{"1", "/", 
        RowBox[{"Sqrt", "[", "3", "]"}]}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]XZYKelvinNV1Calc", "=", 
  RowBox[{
   RowBox[{"CXYZKelvin", ".", 
    RowBox[{"Transpose", "[", "LNV1passive", "]"}], ".", 
    "\[Epsilon]xyzKelvinNV1"}], "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.699258382122555*^9, 3.6992583821235547`*^9}, {
   3.699258413697361*^9, 3.699258470264596*^9}, 3.6992601305155573`*^9, {
   3.6992601745520763`*^9, 3.699260183789604*^9}, {3.699271394853815*^9, 
   3.699271398733821*^9}, {3.6992715121739793`*^9, 3.699271517693987*^9}, 
   3.6992725414180393`*^9, 3.699272946789607*^9, {3.699273072149783*^9, 
   3.699273115889844*^9}, {3.705057161434408*^9, 3.7050572171995983`*^9}, {
   3.7050572598920403`*^9, 3.705057265748375*^9}, {3.709876166023073*^9, 
   3.709876167323099*^9}, {3.7356177618249006`*^9, 3.7356178121139984`*^9}, {
   3.735617884795523*^9, 3.7356179042749543`*^9}, {3.7368257303020344`*^9, 
   3.7368257379021864`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C11", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Epsilon]xxa"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "\[Epsilon]xya"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["6"], " ", "\[Epsilon]xza"}], "+", "\[Epsilon]yya", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]yza"}], "+", 
         RowBox[{"2", " ", "\[Epsilon]zza"}]}], ")"}]}], "+", 
      RowBox[{"C12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Epsilon]xxa"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "\[Epsilon]xya"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["6"], " ", "\[Epsilon]xza"}], "+", 
         RowBox[{"5", " ", "\[Epsilon]yya"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]yza"}], "+", 
         RowBox[{"4", " ", "\[Epsilon]zza"}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C11", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Epsilon]xxa"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "\[Epsilon]xya"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["6"], " ", "\[Epsilon]xza"}], "+", "\[Epsilon]yya", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]yza"}], "+", 
         RowBox[{"2", " ", "\[Epsilon]zza"}]}], ")"}]}], "+", 
      RowBox[{"C12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Epsilon]xxa"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "\[Epsilon]xya"}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["6"], " ", "\[Epsilon]xza"}], "+", 
         RowBox[{"5", " ", "\[Epsilon]yya"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]yza"}], "+", 
         RowBox[{"4", " ", "\[Epsilon]zza"}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C11", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Epsilon]yya"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]yza"}], "+", "\[Epsilon]zza"}], 
        ")"}]}], "+", 
      RowBox[{"C12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Epsilon]xxa"}], "+", "\[Epsilon]yya", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Epsilon]yza"}], "+", 
         RowBox[{"2", " ", "\[Epsilon]zza"}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["2", "3"], " ", "C44", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["6"], " ", "\[Epsilon]xya"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", "\[Epsilon]xza"}], "-", 
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]yya"}], "+", "\[Epsilon]yza", "+", 
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]zza"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["2", "3"]}], " ", "C44", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["6"], " ", "\[Epsilon]xya"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", "\[Epsilon]xza"}], "+", 
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]yya"}], "-", "\[Epsilon]yza", "-", 
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]zza"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", "C44", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SqrtBox["2"], " ", "\[Epsilon]xxa"}], "+", 
      RowBox[{
       SqrtBox["2"], " ", "\[Epsilon]yya"}], "-", 
      RowBox[{"4", " ", "\[Epsilon]yza"}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"], " ", "\[Epsilon]zza"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.735617906997014*^9, 3.7356179101090775`*^9}, 
   3.736826024864377*^9, 3.7368290884668612`*^9, 3.736829265337404*^9, 
   3.745649880637833*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"b", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "-", 
        RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"c", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{
          RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", "2", "]"}]}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
        RowBox[{
         RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
    "FullSimplify"}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{"MyNV1", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "b", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", 
       RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "3", "]"}], "*", "c", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"MzNV1", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a1", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "+", 
       RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"2", "*", "a2", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
         RowBox[{"[", "4", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Sigma]XZYKelvinNV1Calc", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}], ")"}]}]}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.6992600810737295`*^9, 3.699260101208881*^9}, {
  3.699271406103831*^9, 3.6992714214538527`*^9}, {3.699271494553955*^9, 
  3.699271497793959*^9}, {3.6992715895440874`*^9, 3.6992715942640944`*^9}, {
  3.7020984043484526`*^9, 3.7020984044884553`*^9}, {3.7050571541249905`*^9, 
  3.7050571579162073`*^9}, {3.735617914960178*^9, 3.735617949537878*^9}, {
  3.736825744632321*^9, 3.7368257583125944`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "b"}], " ", 
   RowBox[{"(", 
    RowBox[{"C11", "-", "C12"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxa", "-", "\[Epsilon]yya", "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"], " ", "\[Epsilon]yza"}]}], ")"}]}], "-", 
  RowBox[{"2", " ", "c", " ", "C44", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxa", "-", "\[Epsilon]yya", "+", 
     RowBox[{
      SqrtBox["2"], " ", "\[Epsilon]yza"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.6992601029479804`*^9, 3.6992601867167716`*^9, 3.699271376003789*^9, 
   3.699271423473855*^9, {3.6992714707839217`*^9, 3.6992715456540265`*^9}, 
   3.6992715951140957`*^9, 3.6992729512096133`*^9, 3.6992730779197907`*^9, {
   3.699273109519835*^9, 3.6992731283598614`*^9}, {3.6993743962412243`*^9, 
   3.699374400843232*^9}, 3.700320060261074*^9, 3.7003801033973293`*^9, 
   3.7003972541132293`*^9, 3.7020983605475764`*^9, 3.702098405028466*^9, 
   3.7044697625164876`*^9, 3.7045182598808947`*^9, 3.705057074623443*^9, 
   3.7081734069705687`*^9, 3.7098766932636194`*^9, 3.735617951067909*^9, 
   3.736826024954379*^9, 3.7368290885468626`*^9, 3.736829265417405*^9, 
   3.7456498806978345`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"b", " ", 
     RowBox[{"(", 
      RowBox[{"C11", "-", "C12"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]xya", "-", 
       RowBox[{
        SqrtBox["2"], " ", "\[Epsilon]xza"}]}], ")"}]}], "+", 
    RowBox[{"c", " ", "C44", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "\[Epsilon]xya"}], "+", 
       RowBox[{
        SqrtBox["2"], " ", "\[Epsilon]xza"}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6992601029479804`*^9, 3.6992601867167716`*^9, 3.699271376003789*^9, 
   3.699271423473855*^9, {3.6992714707839217`*^9, 3.6992715456540265`*^9}, 
   3.6992715951140957`*^9, 3.6992729512096133`*^9, 3.6992730779197907`*^9, {
   3.699273109519835*^9, 3.6992731283598614`*^9}, {3.6993743962412243`*^9, 
   3.699374400843232*^9}, 3.700320060261074*^9, 3.7003801033973293`*^9, 
   3.7003972541132293`*^9, 3.7020983605475764`*^9, 3.702098405028466*^9, 
   3.7044697625164876`*^9, 3.7045182598808947`*^9, 3.705057074623443*^9, 
   3.7081734069705687`*^9, 3.7098766932636194`*^9, 3.735617951067909*^9, 
   3.736826024954379*^9, 3.7368290885468626`*^9, 3.736829265417405*^9, 
   3.7456498807578354`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "a2", " ", "C44", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxa", "+", "\[Epsilon]yya", "-", 
     RowBox[{"2", " ", "\[Epsilon]zza"}]}], ")"}]}], "+", 
  RowBox[{"a1", " ", 
   RowBox[{"(", 
    RowBox[{"C11", "+", 
     RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxa", "+", "\[Epsilon]yya", "+", "\[Epsilon]zza"}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.6992601029479804`*^9, 3.6992601867167716`*^9, 3.699271376003789*^9, 
   3.699271423473855*^9, {3.6992714707839217`*^9, 3.6992715456540265`*^9}, 
   3.6992715951140957`*^9, 3.6992729512096133`*^9, 3.6992730779197907`*^9, {
   3.699273109519835*^9, 3.6992731283598614`*^9}, {3.6993743962412243`*^9, 
   3.699374400843232*^9}, 3.700320060261074*^9, 3.7003801033973293`*^9, 
   3.7003972541132293`*^9, 3.7020983605475764`*^9, 3.702098405028466*^9, 
   3.7044697625164876`*^9, 3.7045182598808947`*^9, 3.705057074623443*^9, 
   3.7081734069705687`*^9, 3.7098766932636194`*^9, 3.735617951067909*^9, 
   3.736826024954379*^9, 3.7368290885468626`*^9, 3.736829265417405*^9, 
   3.7456498807978363`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MxNV1Check", " ", "=", " ", 
   RowBox[{
    RowBox[{"B", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]xxa", "-", "\[Epsilon]yya"}], ")"}]}], "+", 
    RowBox[{"2", "C", " ", "\[Epsilon]yza"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyNV1Check", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], "B", " ", "\[Epsilon]xya"}], "-", 
    RowBox[{"2", " ", "C", " ", "\[Epsilon]xza"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MzNV1Check", "=", 
   RowBox[{
    RowBox[{"A1", " ", "\[Epsilon]zza"}], " ", "+", " ", 
    RowBox[{"A2", 
     RowBox[{"(", 
      RowBox[{"\[Epsilon]xxa", "+", "\[Epsilon]yya"}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MxNV1", "==", "MxNV1Check"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
        RowBox[{"2", " ", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
     RowBox[{"C", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "c", " ", "C44"}]}]}], ",", 
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", "a2", " ", "C44"}]}]}], ",", " ", 
     RowBox[{"A2", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "a2", " ", "C44"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MyNV1", "==", "MyNV1Check"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
        RowBox[{"2", " ", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
     RowBox[{"C", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "c", " ", "C44"}]}]}], ",", 
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", "a2", " ", "C44"}]}]}], ",", " ", 
     RowBox[{"A2", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "a2", " ", "C44"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MzNV1", "==", "MzNV1Check"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", 
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
        RowBox[{"2", " ", "c", " ", "C44"}]}], ")"}]}], ",", " ", 
     RowBox[{"C", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], " ", "c", " ", "C44"}]}]}], ",", 
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", "a2", " ", "C44"}]}]}], ",", " ", 
     RowBox[{"A2", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"C11", "+", 
          RowBox[{"2", "C12"}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "a2", " ", "C44"}]}]}]}], "}"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.735617968412259*^9, 3.735618012243148*^9}, {
  3.7356188271746855`*^9, 3.7356188415511227`*^9}, {3.7356188736483326`*^9, 
  3.735618888256793*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7356188091498833`*^9, 3.735618846688637*^9, {3.7356188788618536`*^9, 
   3.7356188899639635`*^9}, 3.736826025114382*^9, 3.7368290886668653`*^9, 
   3.736829265547408*^9, 3.745649880887838*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7356188091498833`*^9, 3.735618846688637*^9, {3.7356188788618536`*^9, 
   3.7356188899639635`*^9}, 3.736826025114382*^9, 3.7368290886668653`*^9, 
   3.736829265547408*^9, 3.7456498808978386`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7356188091498833`*^9, 3.735618846688637*^9, {3.7356188788618536`*^9, 
   3.7356188899639635`*^9}, 3.736826025114382*^9, 3.7368290886668653`*^9, 
   3.736829265547408*^9, 3.7456498808978386`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Comparison of strain tensor elements for NVs with same quantization axis, but \
different x and y axes\
\>", "Subsection",
 CellChangeTimes->{{3.709876173803229*^9, 3.709876209913951*^9}, {
  3.7098765540408354`*^9, 3.7098765599509535`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Epsilon]xyzKelvinNV1calc", "=", 
  RowBox[{
   RowBox[{"LNV1passive", ".", 
    RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", "\[Sigma]XYZKelvin"}], 
   " ", "//", "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Epsilon]xyzKelvinBarsoncalc", " ", "=", 
  RowBox[{
   RowBox[{"LBarsonpassive", ".", 
    RowBox[{"Inverse", "[", "CXYZKelvin", "]"}], ".", "\[Sigma]XYZKelvin"}], "//",
    "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.7098761715431833`*^9, 3.709876172313199*^9}, {
  3.735620923512967*^9, 3.73562098709225*^9}, {3.735621026239041*^9, 
  3.7356210300111165`*^9}, {3.735621114003051*^9, 3.7356211216932044`*^9}, {
  3.736825766852765*^9, 3.7368257855411396`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"C11", " ", "C44", " ", "\[Sigma]XX"}], "-", 
     RowBox[{
      SuperscriptBox["C11", "2"], " ", "\[Sigma]XY"}], "-", 
     RowBox[{"C11", " ", "C12", " ", "\[Sigma]XY"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["C12", "2"], " ", "\[Sigma]XY"}], "+", 
     RowBox[{"C11", " ", "C44", " ", "\[Sigma]YY"}], "-", 
     RowBox[{"2", " ", "C12", " ", "C44", " ", "\[Sigma]ZZ"}]}], 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["C11", "2"], " ", "C44"}], "+", 
     RowBox[{"2", " ", "C11", " ", "C12", " ", "C44"}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["C12", "2"], " ", "C44"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["C11", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XY", "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "C12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C12", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XY"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"C44", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY"}], ")"}]}], "+", 
           "\[Sigma]ZZ"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"C11", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C12", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XY", "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"C44", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", 
           RowBox[{"4", " ", "\[Sigma]ZZ"}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{"C11", "-", "C12"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"C11", "+", 
       RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"C11", "+", 
        RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XY", "+", "\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}], 
     "+", 
     RowBox[{"C44", " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
       ")"}]}]}], 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"C11", "+", 
       RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", "C12"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "-", 
         "\[Sigma]YZ"}], ")"}]}], "+", 
      RowBox[{"2", " ", "C44", " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "-", 
         RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}], 
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{"C11", "-", "C12"}], ")"}], " ", "C44"}]]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], 
       RowBox[{"C11", "-", "C12"}]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "\[Sigma]XZ"}], "+", "\[Sigma]YZ"}], "C44"]}], 
    RowBox[{"2", " ", 
     SqrtBox["3"]}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], 
      RowBox[{"C11", "-", "C12"}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "\[Sigma]XZ"}], "+", "\[Sigma]YZ"}], "C44"]}], 
    SqrtBox["6"]]}], "}"}]], "Output",
 CellChangeTimes->{3.7098766952136583`*^9, 3.7356209900643125`*^9, 
  3.7356210323211627`*^9, 3.735621123057234*^9, 3.7368260256643925`*^9, 
  3.7368290891268744`*^9, 3.7368292659774165`*^9, 3.7456498814178486`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["C11", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XY", "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "C12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C12", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Sigma]XY"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"C44", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY"}], ")"}]}], "+", 
           "\[Sigma]ZZ"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"C11", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C12", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XY", "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"C44", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", 
           RowBox[{"4", " ", "\[Sigma]ZZ"}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{"C11", "-", "C12"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"C11", "+", 
       RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"C11", " ", "C44", " ", "\[Sigma]XX"}], "-", 
     RowBox[{
      SuperscriptBox["C11", "2"], " ", "\[Sigma]XY"}], "-", 
     RowBox[{"C11", " ", "C12", " ", "\[Sigma]XY"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["C12", "2"], " ", "\[Sigma]XY"}], "+", 
     RowBox[{"C11", " ", "C44", " ", "\[Sigma]YY"}], "-", 
     RowBox[{"2", " ", "C12", " ", "C44", " ", "\[Sigma]ZZ"}]}], 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["C11", "2"], " ", "C44"}], "+", 
     RowBox[{"2", " ", "C11", " ", "C12", " ", "C44"}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["C12", "2"], " ", "C44"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"C11", "+", 
        RowBox[{"2", " ", "C12"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XY", "+", "\[Sigma]XZ", "+", "\[Sigma]YZ"}], ")"}]}], 
     "+", 
     RowBox[{"C44", " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "+", "\[Sigma]ZZ"}], 
       ")"}]}]}], 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"C11", "+", 
       RowBox[{"2", " ", "C12"}]}], ")"}], " ", "C44"}]], ",", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]XX", "-", "\[Sigma]YY"}], ")"}]}], 
      RowBox[{"C11", "-", "C12"}]], "+", 
     FractionBox[
      RowBox[{"\[Sigma]XZ", "-", "\[Sigma]YZ"}], "C44"]}], 
    RowBox[{"2", " ", 
     SqrtBox["3"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"C11", "-", "C12"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Sigma]XY"}], "-", "\[Sigma]XZ", "-", 
         "\[Sigma]YZ"}], ")"}]}], "+", 
      RowBox[{"2", " ", "C44", " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]XX", "+", "\[Sigma]YY", "-", 
         RowBox[{"2", " ", "\[Sigma]ZZ"}]}], ")"}]}]}], 
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{"C11", "-", "C12"}], ")"}], " ", "C44"}]]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"C44", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[Sigma]XX"}], "+", "\[Sigma]YY"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"C11", "-", "C12"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]XZ", "-", "\[Sigma]YZ"}], ")"}]}]}], 
    RowBox[{
     SqrtBox["6"], " ", 
     RowBox[{"(", 
      RowBox[{"C11", "-", "C12"}], ")"}], " ", "C44"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.7098766952136583`*^9, 3.7356209900643125`*^9, 
  3.7356210323211627`*^9, 3.735621123057234*^9, 3.7368260256643925`*^9, 
  3.7368290891268744`*^9, 3.7368292659774165`*^9, 3.7456498816578536`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzKelvinBarsoncalc", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "==", 
   RowBox[{"\[Epsilon]xyzKelvinNV1calc", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzKelvinBarsoncalc", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "==", 
   RowBox[{"\[Epsilon]xyzKelvinNV1calc", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzKelvinBarsoncalc", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "==", 
   RowBox[{"\[Epsilon]xyzKelvinNV1calc", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzKelvinBarsoncalc", "[", 
    RowBox[{"[", "4", "]"}], "]"}], "\[Equal]", 
   RowBox[{"-", 
    RowBox[{"\[Epsilon]xyzKelvinNV1calc", "[", 
     RowBox[{"[", "5", "]"}], "]"}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzKelvinBarsoncalc", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "==", 
   RowBox[{"\[Epsilon]xyzKelvinNV1calc", "[", 
    RowBox[{"[", "4", "]"}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]xyzKelvinBarsoncalc", "[", 
    RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", 
   RowBox[{"-", 
    RowBox[{"\[Epsilon]xyzKelvinNV1calc", "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7356210136617856`*^9, 3.735621062078961*^9}, {
  3.7356210932935944`*^9, 3.7356210980806913`*^9}, {3.7356211289093943`*^9, 
  3.735621168937253*^9}, {3.7368257927512836`*^9, 3.736825805463538*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.73562102171495*^9, 3.7356210628529797`*^9}, {
   3.735621094474618*^9, 3.7356211252572775`*^9}, 3.7356211695272646`*^9, 
   3.736826025924398*^9, 3.736829089446881*^9, 3.736829266237422*^9, 
   3.7456498816678534`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.73562102171495*^9, 3.7356210628529797`*^9}, {
   3.735621094474618*^9, 3.7356211252572775`*^9}, 3.7356211695272646`*^9, 
   3.736826025924398*^9, 3.736829089446881*^9, 3.736829266237422*^9, 
   3.7456498816678534`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.73562102171495*^9, 3.7356210628529797`*^9}, {
   3.735621094474618*^9, 3.7356211252572775`*^9}, 3.7356211695272646`*^9, 
   3.736826025924398*^9, 3.736829089446881*^9, 3.736829266237422*^9, 
   3.7456498816678534`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.73562102171495*^9, 3.7356210628529797`*^9}, {
   3.735621094474618*^9, 3.7356211252572775`*^9}, 3.7356211695272646`*^9, 
   3.736826025924398*^9, 3.736829089446881*^9, 3.736829266237422*^9, 
   3.7456498817078543`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.73562102171495*^9, 3.7356210628529797`*^9}, {
   3.735621094474618*^9, 3.7356211252572775`*^9}, 3.7356211695272646`*^9, 
   3.736826025924398*^9, 3.736829089446881*^9, 3.736829266237422*^9, 
   3.7456498817078543`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.73562102171495*^9, 3.7356210628529797`*^9}, {
   3.735621094474618*^9, 3.7356211252572775`*^9}, 3.7356211695272646`*^9, 
   3.736826025924398*^9, 3.736829089446881*^9, 3.736829266237422*^9, 
   3.7456498817078543`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison of level shifts", "Subsection",
 CellChangeTimes->{{3.735621189891849*^9, 3.7356211977280083`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[CapitalDelta]NV1plus", " ", "=", " ", 
  RowBox[{"MzNV1Check", "+", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"MxNV1Check", "^", "2"}], "+", 
     RowBox[{"MyNV1Check", "^", "2"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[CapitalDelta]Barsonplus", " ", "=", " ", 
  RowBox[{"MzBarsonCheck", "+", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"MxBarsonCheck", "^", "2"}], "+", 
     RowBox[{"MyBarsonCheck", "^", "2"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
   "\[CapitalDelta]NV1plus", " ", "\[Equal]", " ", 
    "\[CapitalDelta]Barsonplus"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]xxb", "\[Rule]", "\[Epsilon]yya"}], ",", " ", 
     RowBox[{"\[Epsilon]yyb", "\[Rule]", "\[Epsilon]xxa"}], ",", " ", 
     RowBox[{"\[Epsilon]zzb", "\[Rule]", "\[Epsilon]zza"}], ",", " ", 
     RowBox[{"\[Epsilon]yzb", "\[Rule]", 
      RowBox[{"-", "\[Epsilon]xza"}]}], ",", " ", 
     RowBox[{"\[Epsilon]xzb", "\[Rule]", "\[Epsilon]yza"}], ",", " ", 
     RowBox[{"\[Epsilon]xyb", "\[Rule]", 
      RowBox[{"-", "\[Epsilon]xya"}]}]}], "}"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7356212041511374`*^9, 3.7356212719325438`*^9}, {
  3.735621303338262*^9, 3.735621466288596*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"A2", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxa", "+", "\[Epsilon]yya"}], ")"}]}], "+", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "B", " ", "\[Epsilon]xya"}], "-", 
       RowBox[{"2", " ", "C", " ", "\[Epsilon]xza"}]}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B", " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]xxa", "-", "\[Epsilon]yya"}], ")"}]}], "+", 
       RowBox[{"2", " ", "C", " ", "\[Epsilon]yza"}]}], ")"}], "2"]}]], "+", 
  RowBox[{"A1", " ", "\[Epsilon]zza"}]}]], "Output",
 CellChangeTimes->{{3.7356212374418097`*^9, 3.7356212785376787`*^9}, {
   3.735621313578468*^9, 3.735621336711935*^9}, {3.7356214547323627`*^9, 
   3.735621466588602*^9}, 3.7368260260043993`*^9, 3.736829089516882*^9, 
   3.7368292663174233`*^9, 3.7456498817178545`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"A2", " ", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]xxb", "+", "\[Epsilon]yyb"}], ")"}]}], "+", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "C", " ", "\[Epsilon]xzb"}], "-", 
       RowBox[{"B", " ", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]xxb", "-", "\[Epsilon]yyb"}], ")"}]}]}], ")"}], 
     "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "B", " ", "\[Epsilon]xyb"}], "+", 
       RowBox[{"2", " ", "C", " ", "\[Epsilon]yzb"}]}], ")"}], "2"]}]], "+", 
  RowBox[{"A1", " ", "\[Epsilon]zzb"}]}]], "Output",
 CellChangeTimes->{{3.7356212374418097`*^9, 3.7356212785376787`*^9}, {
   3.735621313578468*^9, 3.735621336711935*^9}, {3.7356214547323627`*^9, 
   3.735621466588602*^9}, 3.7368260260043993`*^9, 3.736829089516882*^9, 
   3.7368292663174233`*^9, 3.7456498817178545`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7356212374418097`*^9, 3.7356212785376787`*^9}, {
   3.735621313578468*^9, 3.735621336711935*^9}, {3.7356214547323627`*^9, 
   3.735621466588602*^9}, 3.7368260260043993`*^9, 3.736829089516882*^9, 
   3.7368292663174233`*^9, 3.745649881787856*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 1158},
WindowMargins->{{1912, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.1999999999999, 841.8}},
Magnification:>1.1 Inherited,
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Report"}, "StandardReport.nb", CharacterEncoding -> 
       "UTF-8"]]], 
   Cell[
    StyleData["Title"]], 
   Cell[
    StyleData["Subsubsection"]], 
   Cell[
    StyleData["ItemParagraph"]]}, Visible -> False, FrontEndVersion -> 
  "10.4 for Microsoft Windows (64-bit) (April 11, 2016)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 933, 18, 910, "Title"],
Cell[1516, 42, 243, 3, 109, "Title"],
Cell[1762, 47, 245, 5, 42, "Input"],
Cell[CellGroupData[{
Cell[2032, 56, 169, 2, 39, "Subsection"],
Cell[2204, 60, 450, 13, 83, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2691, 78, 218, 4, 39, "Subsection"],
Cell[2912, 84, 245, 6, 42, "Input"],
Cell[CellGroupData[{
Cell[3182, 94, 3103, 83, 183, "Input"],
Cell[6288, 179, 1130, 31, 100, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7467, 216, 244, 3, 39, "Subsection"],
Cell[7714, 221, 1891, 54, 143, "Input"],
Cell[CellGroupData[{
Cell[9630, 279, 2085, 56, 103, "Input"],
Cell[11718, 337, 838, 22, 57, "Output"],
Cell[12559, 361, 838, 22, 57, "Output"],
Cell[13400, 385, 838, 22, 57, "Output"],
Cell[14241, 409, 838, 22, 57, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15140, 438, 266, 5, 130, "Title"],
Cell[CellGroupData[{
Cell[15431, 447, 402, 7, 33, "Item"],
Cell[15836, 456, 343, 6, 33, "Item"]
}, Open  ]],
Cell[16194, 465, 245, 5, 55, "Input"],
Cell[CellGroupData[{
Cell[16464, 474, 168, 2, 105, "Section"],
Cell[16635, 478, 414, 7, 41, "Text"],
Cell[CellGroupData[{
Cell[17074, 489, 111, 1, 50, "Subsection"],
Cell[17188, 492, 6012, 175, 322, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23237, 672, 322, 6, 50, "Subsection"],
Cell[23562, 680, 7374, 210, 642, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30973, 895, 276, 5, 50, "Subsection"],
Cell[CellGroupData[{
Cell[31274, 904, 4131, 80, 721, "Input"],
Cell[35408, 986, 4809, 78, 997, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40266, 1070, 234, 5, 50, "Subsection"],
Cell[CellGroupData[{
Cell[40525, 1079, 2030, 47, 110, "Input"],
Cell[42558, 1128, 2658, 47, 574, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45277, 1182, 234, 3, 105, "Section"],
Cell[45514, 1187, 894, 14, 96, "Text"],
Cell[CellGroupData[{
Cell[46433, 1205, 245, 3, 50, "Subsection"],
Cell[46681, 1210, 2013, 64, 215, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48731, 1279, 323, 4, 50, "Subsection"],
Cell[49057, 1285, 1160, 23, 162, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50254, 1313, 340, 6, 50, "Subsection"],
Cell[50597, 1321, 1193, 25, 162, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51827, 1351, 338, 6, 50, "Subsection"],
Cell[52168, 1359, 983, 22, 162, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[53200, 1387, 590, 9, 167, "Section"],
Cell[53793, 1398, 1132, 21, 258, "Text"],
Cell[CellGroupData[{
Cell[54950, 1423, 243, 5, 50, "Subsection"],
Cell[55196, 1430, 635, 16, 55, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55868, 1451, 151, 2, 50, "Subsection"],
Cell[56022, 1455, 152, 2, 41, "Text"],
Cell[CellGroupData[{
Cell[56199, 1461, 250, 3, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[56474, 1468, 5291, 152, 243, "Input"],
Cell[61768, 1622, 1655, 32, 122, "Output"],
Cell[63426, 1656, 3367, 87, 189, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[66842, 1749, 170, 2, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[67037, 1755, 5195, 152, 243, "Input"],
Cell[72235, 1909, 1687, 35, 122, "Output"],
Cell[73925, 1946, 3257, 84, 189, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[77231, 2036, 198, 3, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[77454, 2043, 5109, 151, 243, "Input"],
Cell[82566, 2196, 1641, 35, 122, "Output"],
Cell[84210, 2233, 3349, 89, 189, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[87608, 2328, 172, 2, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[87805, 2334, 5110, 151, 243, "Input"],
Cell[92918, 2487, 1615, 34, 122, "Output"],
Cell[94536, 2523, 3267, 86, 189, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97864, 2616, 269, 5, 50, "Subsection"],
Cell[CellGroupData[{
Cell[98158, 2625, 309, 6, 49, "Subsubsection"],
Cell[98470, 2633, 3222, 74, 136, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101729, 2712, 231, 4, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[101985, 2720, 2734, 73, 110, "Input"],
Cell[104722, 2795, 1839, 52, 177, "Output"],
Cell[106564, 2849, 2547, 72, 146, "Output"],
Cell[109114, 2923, 2343, 69, 188, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[111506, 2998, 468, 8, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[111999, 3010, 3633, 109, 110, "Input"],
Cell[115635, 3121, 1782, 43, 182, "Output"],
Cell[117420, 3166, 2816, 75, 182, "Output"],
Cell[120239, 3243, 2084, 54, 217, "Output"]
}, Open  ]],
Cell[122338, 3300, 360, 9, 150, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[122759, 3316, 373, 7, 167, "Section"],
Cell[123135, 3325, 1570, 28, 284, "Text"],
Cell[CellGroupData[{
Cell[124730, 3357, 384, 6, 50, "Subsection"],
Cell[125117, 3365, 2218, 52, 110, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127372, 3422, 202, 3, 50, "Subsection"],
Cell[127577, 3427, 189, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[127791, 3435, 93, 1, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[127909, 3440, 7636, 205, 269, "Input"],
Cell[135548, 3647, 3324, 91, 189, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[138921, 3744, 96, 1, 49, "Subsubsection"],
Cell[139020, 3747, 461, 8, 96, "Text"],
Cell[CellGroupData[{
Cell[139506, 3759, 5217, 150, 189, "Input"],
Cell[144726, 3911, 3121, 85, 189, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[147896, 4002, 96, 1, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[148017, 4007, 3241, 93, 136, "Input"],
Cell[151261, 4102, 2238, 61, 133, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[153548, 4169, 96, 1, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[153669, 4174, 3187, 91, 136, "Input"],
Cell[156859, 4267, 2228, 61, 133, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[159148, 4335, 239, 3, 50, "Subsection"],
Cell[159390, 4340, 790, 16, 177, "Text"],
Cell[CellGroupData[{
Cell[160205, 4360, 149, 2, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[160379, 4366, 5557, 150, 223, "Input"],
Cell[165939, 4518, 1068, 29, 118, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[167056, 4553, 94, 1, 49, "Subsubsection"],
Cell[167153, 4556, 2967, 85, 116, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170157, 4646, 96, 1, 49, "Subsubsection"],
Cell[170256, 4649, 2930, 86, 116, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[173223, 4740, 94, 1, 49, "Subsubsection"],
Cell[173320, 4743, 2933, 86, 116, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176290, 4834, 397, 6, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[176712, 4844, 6025, 159, 269, "Input"],
Cell[182740, 5005, 1319, 37, 182, "Output"],
Cell[184062, 5044, 2299, 65, 182, "Output"],
Cell[186364, 5111, 1621, 48, 217, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[188058, 5167, 238, 4, 105, "Section"],
Cell[188299, 5173, 556, 10, 123, "Text"],
Cell[188858, 5185, 175, 4, 55, "Input"],
Cell[CellGroupData[{
Cell[189058, 5193, 219, 3, 50, "Subsection"],
Cell[189280, 5198, 735, 19, 136, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190052, 5222, 279, 6, 50, "Subsection"],
Cell[190334, 5230, 1987, 57, 269, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192358, 5292, 381, 7, 50, "Subsection"],
Cell[192742, 5301, 7080, 188, 348, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[199859, 5494, 534, 9, 50, "Subsection"],
Cell[CellGroupData[{
Cell[200418, 5507, 337, 6, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[200780, 5517, 1166, 26, 162, "Input"],
Cell[201949, 5545, 902, 18, 88, "Output"],
Cell[202854, 5565, 959, 21, 101, "Output"],
Cell[203816, 5588, 917, 19, 88, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[204782, 5613, 309, 6, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[205116, 5623, 994, 21, 162, "Input"],
Cell[206113, 5646, 466, 11, 88, "Output"],
Cell[206582, 5659, 481, 12, 101, "Output"],
Cell[207066, 5673, 523, 14, 88, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[207638, 5693, 223, 4, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[207886, 5701, 838, 19, 162, "Input"],
Cell[208727, 5722, 785, 15, 88, "Output"],
Cell[209515, 5739, 863, 19, 101, "Output"],
Cell[210381, 5760, 863, 19, 88, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[211293, 5785, 256, 5, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[211574, 5794, 905, 20, 162, "Input"],
Cell[212482, 5816, 934, 19, 88, "Output"],
Cell[213419, 5837, 970, 21, 101, "Output"],
Cell[214392, 5860, 970, 21, 88, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[215411, 5887, 297, 3, 49, "Subsubsection"],
Cell[215711, 5892, 922, 24, 110, "Input"],
Cell[216636, 5918, 2025, 54, 243, "Input"],
Cell[218664, 5974, 1046, 31, 162, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[219759, 6011, 459, 8, 50, "Subsection"],
Cell[220221, 6021, 1996, 35, 447, "Text"],
Cell[CellGroupData[{
Cell[222242, 6060, 109, 1, 49, "Subsubsection"],
Cell[222354, 6063, 339, 7, 96, "Text"],
Cell[222696, 6072, 1521, 42, 82, "Input"],
Cell[224220, 6116, 387, 9, 55, "Input"],
Cell[CellGroupData[{
Cell[224632, 6129, 224, 4, 55, "Input"],
Cell[224859, 6135, 1067, 25, 193, "Output"]
}, Open  ]],
Cell[225941, 6163, 5911, 177, 257, "Input"],
Cell[CellGroupData[{
Cell[231877, 6344, 194, 3, 55, "Input"],
Cell[232074, 6349, 715, 18, 63, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[232838, 6373, 159, 2, 49, "Subsubsection"],
Cell[233000, 6377, 493, 10, 96, "Text"],
Cell[233496, 6389, 1345, 36, 82, "Input"],
Cell[234844, 6427, 1925, 39, 82, "Input"],
Cell[236772, 6468, 5969, 159, 189, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[242778, 6632, 144, 1, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[242947, 6637, 354, 8, 82, "Input"],
Cell[243304, 6647, 816, 19, 63, "Output"],
Cell[244123, 6668, 816, 19, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[244976, 6692, 822, 21, 110, "Input"],
Cell[245801, 6715, 840, 11, 56, "Output"],
Cell[246644, 6728, 842, 11, 56, "Output"],
Cell[247489, 6741, 842, 11, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[248380, 6758, 117, 1, 49, "Subsubsection"],
Cell[248500, 6761, 547, 12, 203, "Text"],
Cell[249050, 6775, 167, 3, 55, "Input"],
Cell[CellGroupData[{
Cell[249242, 6782, 6672, 186, 348, "Input"],
Cell[255917, 6970, 382, 6, 56, "Output"],
Cell[256302, 6978, 382, 6, 56, "Output"],
Cell[256687, 6986, 382, 6, 56, "Output"],
Cell[257072, 6994, 380, 6, 56, "Output"],
Cell[257455, 7002, 382, 6, 56, "Output"]
}, Open  ]],
Cell[257852, 7011, 224, 4, 55, "Input"],
Cell[CellGroupData[{
Cell[258101, 7019, 6695, 183, 295, "Input"],
Cell[264799, 7204, 857, 12, 56, "Output"],
Cell[265659, 7218, 859, 12, 56, "Output"],
Cell[266521, 7232, 859, 12, 56, "Output"],
Cell[267383, 7246, 859, 12, 56, "Output"],
Cell[268245, 7260, 859, 12, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[269153, 7278, 115, 1, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[269293, 7283, 402, 9, 82, "Input"],
Cell[269698, 7294, 653, 16, 56, "Output"],
Cell[270354, 7312, 1357, 39, 97, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[271760, 7357, 297, 6, 49, "Subsubsection"],
Cell[272060, 7365, 121, 1, 41, "Text"],
Cell[272184, 7368, 2138, 54, 110, "Input"],
Cell[274325, 7424, 170, 2, 41, "Text"],
Cell[274498, 7428, 722, 16, 82, "Input"],
Cell[275223, 7446, 117, 1, 41, "Text"],
Cell[CellGroupData[{
Cell[275365, 7451, 40, 0, 55, "Input"],
Cell[275408, 7453, 1397, 33, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[276842, 7491, 2487, 61, 162, "Input"],
Cell[279332, 7554, 2514, 77, 89, "Output"],
Cell[281849, 7633, 3386, 90, 140, "Output"],
Cell[285238, 7725, 1788, 50, 81, "Output"]
}, Open  ]],
Cell[287041, 7778, 6799, 190, 110, "Input"],
Cell[293843, 7970, 102, 1, 41, "Text"],
Cell[CellGroupData[{
Cell[293970, 7975, 4080, 118, 110, "Input"],
Cell[298053, 8095, 709, 10, 56, "Output"],
Cell[298765, 8107, 711, 10, 56, "Output"],
Cell[299479, 8119, 709, 10, 56, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[300249, 8136, 509, 9, 50, "Subsection"],
Cell[300761, 8147, 3045, 69, 162, "Input"],
Cell[CellGroupData[{
Cell[303831, 8220, 435, 7, 49, "Subsubsection"],
Cell[304269, 8229, 571, 10, 123, "Text"],
Cell[304843, 8241, 87, 1, 41, "Text"],
Cell[CellGroupData[{
Cell[304955, 8246, 2349, 56, 136, "Input"],
Cell[307307, 8304, 4315, 127, 160, "Output"],
Cell[311625, 8433, 1095, 31, 99, "Output"],
Cell[312723, 8466, 1106, 32, 99, "Output"],
Cell[313832, 8500, 1395, 40, 81, "Output"]
}, Open  ]],
Cell[315242, 8543, 89, 1, 41, "Text"],
Cell[CellGroupData[{
Cell[315356, 8548, 236, 5, 55, "Input"],
Cell[315595, 8555, 266, 4, 56, "Output"]
}, Open  ]],
Cell[315876, 8562, 2252, 60, 136, "Input"],
Cell[318131, 8624, 87, 1, 41, "Text"],
Cell[318221, 8627, 2203, 60, 136, "Input"],
Cell[320427, 8689, 89, 1, 41, "Text"],
Cell[320519, 8692, 2255, 60, 136, "Input"],
Cell[322777, 8754, 210, 3, 41, "Text"],
Cell[CellGroupData[{
Cell[323012, 8761, 3919, 111, 189, "Input"],
Cell[326934, 8874, 3723, 114, 326, "Output"],
Cell[330660, 8990, 7109, 189, 326, "Output"],
Cell[337772, 9181, 4580, 141, 295, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[342401, 9328, 289, 3, 49, "Subsubsection"],
Cell[342693, 9333, 246, 7, 123, "Text"],
Cell[342942, 9342, 185, 2, 41, "Text"],
Cell[CellGroupData[{
Cell[343152, 9348, 2536, 75, 136, "Input"],
Cell[345691, 9425, 392, 5, 56, "Output"],
Cell[346086, 9432, 1006, 28, 124, "Output"]
}, Open  ]],
Cell[347107, 9463, 215, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[347347, 9471, 3709, 111, 136, "Input"],
Cell[351059, 9584, 616, 9, 56, "Output"],
Cell[351678, 9595, 1536, 42, 102, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353251, 9642, 331, 8, 55, "Input"],
Cell[353585, 9652, 1018, 23, 96, "Output"]
}, Open  ]],
Cell[354618, 9678, 219, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[354862, 9686, 3535, 109, 136, "Input"],
Cell[358400, 9797, 420, 6, 56, "Output"],
Cell[358823, 9805, 1660, 41, 96, "Output"]
}, Open  ]],
Cell[360498, 9849, 125, 2, 41, "Text"],
Cell[CellGroupData[{
Cell[360648, 9855, 1445, 44, 82, "Input"],
Cell[362096, 9901, 266, 4, 56, "Output"]
}, Open  ]],
Cell[362377, 9908, 212, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[362614, 9916, 3037, 95, 136, "Input"],
Cell[365654, 10013, 317, 5, 56, "Output"],
Cell[365974, 10020, 968, 28, 126, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[367027, 10057, 372, 5, 143, "Title"],
Cell[367402, 10064, 245, 5, 55, "Input"],
Cell[CellGroupData[{
Cell[367672, 10073, 266, 5, 105, "Section"],
Cell[CellGroupData[{
Cell[367963, 10082, 101, 1, 50, "Subsection"],
Cell[368067, 10085, 6358, 174, 295, "Input"],
Cell[374428, 10261, 3809, 77, 136, "Input"],
Cell[CellGroupData[{
Cell[378262, 10342, 262, 6, 55, "Input"],
Cell[378527, 10350, 195, 3, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[378771, 10359, 219, 3, 50, "Subsection"],
Cell[CellGroupData[{
Cell[379015, 10366, 734, 15, 82, "Input"],
Cell[379752, 10383, 4187, 119, 177, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[383976, 10507, 4467, 103, 162, "Input"],
Cell[388446, 10612, 2201, 39, 63, "Output"],
Cell[390650, 10653, 2246, 41, 63, "Output"],
Cell[392899, 10696, 2176, 37, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[395112, 10738, 122, 1, 49, "Subsubsection"],
Cell[CellGroupData[{
Cell[395259, 10743, 4500, 134, 189, "Input"],
Cell[399762, 10879, 273, 4, 56, "Output"],
Cell[400038, 10885, 273, 4, 56, "Output"],
Cell[400314, 10891, 271, 4, 56, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[400646, 10902, 433, 5, 50, "Subsection"],
Cell[CellGroupData[{
Cell[401104, 10911, 1298, 28, 82, "Input"],
Cell[402405, 10941, 4043, 114, 177, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406485, 11060, 3411, 89, 110, "Input"],
Cell[409899, 11151, 1201, 25, 63, "Output"],
Cell[411103, 11178, 1217, 27, 63, "Output"],
Cell[412323, 11207, 1166, 24, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[413526, 11236, 4428, 134, 189, "Input"],
Cell[417957, 11372, 248, 4, 56, "Output"],
Cell[418208, 11378, 250, 4, 56, "Output"],
Cell[418461, 11384, 250, 4, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[418760, 11394, 251, 5, 50, "Subsection"],
Cell[CellGroupData[{
Cell[419036, 11403, 721, 14, 82, "Input"],
Cell[419760, 11419, 4213, 125, 160, "Output"],
Cell[423976, 11546, 4348, 129, 160, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[428361, 11680, 1772, 46, 189, "Input"],
Cell[430136, 11728, 272, 4, 56, "Output"],
Cell[430411, 11734, 272, 4, 56, "Output"],
Cell[430686, 11740, 272, 4, 56, "Output"],
Cell[430961, 11746, 272, 4, 56, "Output"],
Cell[431236, 11752, 272, 4, 56, "Output"],
Cell[431511, 11758, 272, 4, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[431832, 11768, 116, 1, 50, "Subsection"],
Cell[CellGroupData[{
Cell[431973, 11773, 1290, 30, 110, "Input"],
Cell[433266, 11805, 942, 24, 70, "Output"],
Cell[434211, 11831, 924, 24, 70, "Output"],
Cell[435138, 11857, 299, 4, 56, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

